locale = {
--      ["!!!"] = "",
--      ["..."] = "",
--      ["011101000"] = "", -- A_Classic_Fairytale:dragon
--      ["011101001"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["10 weapon schemes"] = "", -- Continental_supplies
--      ["15+%d damage, %d invulnerable left"] = "", -- Continental_supplies
--      ["1-5, Precise + 1-4: Choose structure type"] = "", -- Construction_Mode
--      ["+1 barrel!"] = "", -- Tumbler
      ["%.1f seconds were remaining."] = "%.1f секунд еще оставалось.", -- Basic_Training_-_Bazooka      
--      ["%.1fs"] = "", -- Racer, TechRacer
--      ["+1 Grenade"] = "", -- Basic_Training_-_Flying_Saucer
--      ["+1 mine!"] = "", -- Tumbler
--      ["+1 point"] = "", -- Mutant
--      ["-1 point"] = "", -- Mutant
      ["-1 to anyone for a suicide"] = "-1 за самоубийство", -- Mutant
--      ["+1 to the Bottom Feeder for killing anyone"] = "", -- Mutant
--      ["+1 to the Mutant for killing anyone"] = "", -- Mutant
--      ["+2 for becoming the Mutant"] = "", -- Mutant
--      ["30 minutes later..."] = "", -- A_Classic_Fairytale:shadow
--      ["%.3fs"] = "", -- A_Space_Adventure:ice02
--      ["5 additional enemies will be spawned during the game."] = "", -- A_Space_Adventure:fruit01
--      ["5 Deadly Hogs"] = "", -- A_Space_Adventure:death02
--      ["6 more seconds added to the clock"] = "", -- A_Space_Adventure:ice02
--      ["About a month ago, a cyborg came and told us that you're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
      ["Above-average pilot"] = "Пилот выше среднего", -- User_Mission_-_RCPlane_Challenge
--      ["Accuracy Bonus! +15 points"] = "", -- Space_Invasion
      ["Accuracy bonus: +%d points"] = "Бонус за точность: +%d очков", -- Basic_Training_-_Sniper_Rifle
--      ["Achievement gotten: %s"] = "", -- User_Mission_-_RCPlane_Challenge, User_Mission_-_That_Sinking_Feeling, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, Basic_Training_-_Rope, Tumbler
--      ["A Classic Fairytale"] = "", -- A_Classic_Fairytale:first_blood
--      ["A crate critical to this mission has been destroyed."] = "", -- SimpleMission
--      ["Actually, you aren't worthy of life! Take this..."] = "", -- A_Classic_Fairytale:shadow
--      ["A cy-what?"] = "", -- A_Classic_Fairytale:enemy
--      ["Add %d"] = "", -- HedgeEditor
--      ["Admit what?"] = "", -- A_Classic_Fairytale:queen
--      ["Adventurous"] = "", -- A_Classic_Fairytale:journey
--      ["A frenetic Hedgewars mini-game"] = "", -- Frenzy
--      ["Africa"] = "", -- Continental_supplies
--      ["A frozen adventure"] = "", -- A_Space_Adventure:ice01
--      ["After Leaks A Lot betrayed his tribe, he joined the cannibals..."] = "", -- A_Classic_Fairytale:first_blood
--      ["After that incident he went underground and started working on his plan to steal the device."] = "", -- A_Space_Adventure:moon02
--      ["After the shock caused by the enemy spy, Leaks A Lot and Dense Cloud went hunting to relax."] = "", -- A_Classic_Fairytale:shadow
--      ["After you killed an enemy, you'll lose the weapon that he is named after."] = "", -- A_Space_Adventure:death02
--      ["After you left the moon, my other loyal minions came and resurrected me so I could complete my master plan."] = "", -- A_Space_Adventure:death01
--      ["Again with the 'cannibals' thing!"] = "", -- A_Classic_Fairytale:enemy
--      ["A Hedgewars minigame"] = "", -- Capture_the_Flag
--      ["A Hedgewars mini-game"] = "", -- Racer, Space_Invasion, TechRacer, Tumbler
--      ["A Hedgewars tag game"] = "", -- Mutant
--      ["Ahhh, home, sweet home. Made it in %d seconds."] = "", -- ClimbHome
--      ["Aim at the ceiling and hold [Attack] pressed until the rope attaches."] = "", -- Basic_Training_-_Rope
      ["Aiming Practice"] = "Упражнение на точность", --Bazooka, Shotgun, SniperRifle
      ["Aiming practice"] = "Упражнение на точность", -- TargetPractice
--      ["Aim: [Up]/[Down]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Rope
      ["Air Attack"] = "Воздушная атака", -- Construction_Mode
--      ["Air General"] = "", -- Battalion
--      ["Air Mine Placement Mode"] = "", -- HedgeEditor
--      ["AIR MINE PLACEMENT MODE"] = "", -- HedgeEditor
--      ["A leap in a leap"] = "", -- A_Classic_Fairytale:first_blood
--      ["Alex"] = "", -- 
--      ["Alien! I wish to be moved!"] = "", -- A_Classic_Fairytale:queen
--      ["A little gift from the cyborgs"] = "", -- A_Classic_Fairytale:shadow
--      ["Al.Kaholic"] = "", -- 
--      ["All But Last"] = "", -- WxW
--      ["All But Last: You must not solely attack the team with the least health"] = "", -- WxW
--      ["All gone...everything!"] = "", -- A_Classic_Fairytale:enemy
--      ["Allies"] = "", -- A_Space_Adventure:ice01, A_Space_Adventure:ice02
--      ["All right, I'll admit it!"] = "", -- A_Classic_Fairytale:queen
--      ["All right, we just need to get to the other side of the island!"] = "", -- A_Classic_Fairytale:journey
--      ["All right, you got me!"] = "", -- A_Classic_Fairytale:queen
--      ["All the other places are protected by our flight-inhibiting weapons."] = "", -- A_Space_Adventure:fruit01
--      ["All the saucer pilots dream to come here one day in order to compete with the best!"] = "", -- A_Space_Adventure:ice02
--      ["All they do is sit around and judge us!"] = "", -- A_Classic_Fairytale:queen
--      ["All this to please our beloved “elders” … hick …"] = "", -- A_Classic_Fairytale:queen
      ["All walls touched!"] = "Все стены тронуты!", -- WxW
--      ["All you do is take long walks when everyone else works."] = "", -- A_Classic_Fairytale:queen
--      ["All your hedgehogs must be above the marked height!"] = "", -- A_Classic_Fairytale:family
--      ["Also, you should know that the only place where you can fly is the left-most part of this area."] = "", -- A_Space_Adventure:fruit01
--      ["Always being considered weak and fragile."] = "", -- A_Classic_Fairytale:queen
--      ["Amazing! I was never beaten in a race before!"] = "", -- A_Space_Adventure:moon02
--      ["Ammo depleted!"] = "", -- Space_Invasion
--      ["Ammo: %d"] = "", -- Tumbler
--      ["Ammo is reset at the end of your turn."] = "",
--      ["Ammo Limit: Hogs can’t have more than 1 ammo per type"] = "", -- Highlander
--      ["Ammo Maniac! +5 points!"] = "", -- Space_Invasion
--      ["A mysterious Box"] = "", -- Basic_Training_-_Movement
--      ["And how am I alive?!"] = "", -- A_Classic_Fairytale:enemy
--      ["And I just forgot the checkpoint of my main mission. Great, just great!"] = "", -- A_Space_Adventure:cosmos
--      ["… and I think they are up to something. Something bad!"] = "", -- A_Classic_Fairytale:epil
--      ["Andrey"] = "", -- 
--      ["And so happened that Leaks A Lot failed to complete the challenge! He landed, pressured by shame ..."] = "", -- A_Classic_Fairytale:first_blood
--      ["And so it began..."] = "", -- A_Classic_Fairytale:first_blood
--      ["And so the cyborgs took over the island."] = "", -- A_Classic_Fairytale:queen
--      ["...and so the cyborgs took over the world..."] = "", -- A_Classic_Fairytale:shadow
--      ["And so they discovered that cyborgs weren't invulnerable..."] = "", -- A_Classic_Fairytale:journey
--      ["… and then I took a stroll …"] = "", -- A_Classic_Fairytale:epil
--      ["And what do they do in the meantime? Nothing!"] = "", -- A_Classic_Fairytale:queen
--      ["And where's all the weed?"] = "", -- A_Classic_Fairytale:dragon
--      ["And you believed me? Oh, god, that's cute!"] = "", -- A_Classic_Fairytale:journey
--      ["And you need to move to the top!"] = "", -- Basic_Training_-_Movement
--      ["An experimental editing tool for missions and more"] = "", -- HedgeEditor
--      ["Anno 1032"] = "", -- Continental_supplies
--      ["Anno 1032: [The explosion will make a strong push ~ Wide range, wont affect hogs close to the target]"] = "", -- Continental_supplies
--      ["An object has been destroyed before it took enough damage."] = "", -- SimpleMission
--      ["Antarctica"] = "", -- Continental_supplies
--      ["Antarctic summer: Every 4th turn you get 1 girder, 1 mudball, 2 sine guns and 1 portable portal device."] = "", -- Continental_supplies
--      ["Antarctic summer: - Will give you one girder/mudball and two sineguns/portals every fourth turn."] = "", -- Continental_supplies
--      ["Anti-Gravity Device Part (+1)"] = "", -- A_Space_Adventure:desert01, A_Space_Adventure:fruit02, A_Space_Adventure:ice01
--      ["Anton"] = "", -- 
--      ["An unexpected event!"] = "", -- A_Space_Adventure:cosmos
--      ["Anyway, the aliens accept me for who I am."] = "", -- A_Classic_Fairytale:queen
--      ["A random hedgehog will inherit the weapons of his deceased team-mates."] = "", -- A_Space_Adventure:death02
--      ["Arashi"] = "", -- 
--      ["Area"] = "", -- Continental_supplies
--      ["Areas surrounded by a green dashed outline are portal-proof and repel portals."] = "", -- A_Space_Adventure:final
--      ["Areas surrounded by a security border are indestructible."] = "", -- A_Space_Adventure:final
--      ["Areas with a green dashed outline are portal-proof."] = "", -- A_Space_Adventure:final
--      ["Areas with a security outline are indestructible."] = "", -- A_Space_Adventure:final
--      ["Are we there yet?"] = "", -- A_Classic_Fairytale:shadow
--      ["Are you accusing me of something?"] = "", -- A_Classic_Fairytale:backstab
--      ["Are you helping the aliens?"] = "", -- A_Classic_Fairytale:queen
--      ["Are you saying that many of us have died for your entertainment?"] = "", -- A_Classic_Fairytale:enemy
--      ["Argh, the boredom!"] = "", -- A_Classic_Fairytale:queen
--      ["Artur Detour"] = "", -- A_Classic_Fairytale:queen
--      ["As a reward for your performance, here's some new technology!"] = "", -- A_Classic_Fairytale:dragon
--      ["Ash"] = "", -- 
--      ["A Shoppa minigame"] = "", -- WxW
      ["Asia"] = "Азия", -- Continental_supplies
--      ["As long you don't touch the ground, you can|re-use the same rope as often as you like."] = "", -- Basic_Training_-_Rope
--      ["A smuggler! Prepare for battle"] = "", -- A_Space_Adventure:desert01
--      ["A Space Adventure"] = "", -- A_Space_Adventure:desert01, A_Space_Adventure:moon01
--      ["Assault Team"] = "", -- A_Classic_Fairytale:backstab
--      ["Asteroid"] = "", -- Big_Armory
--      ["As the ammo is sparse, you might want to reuse ropes while mid-air."] = "", -- A_Classic_Fairytale:dragon
--      ["As the challenge was completed, Leaks A Lot set foot on the ground..."] = "", -- A_Classic_Fairytale:first_blood
--      ["As you are more experienced, I want you to lead them to battle."] = "", -- A_Space_Adventure:fruit01
--      ["As you can see I have survived our last encounter and I had time to plot my master plan!"] = "", -- A_Space_Adventure:death01
--      ["As you can see, there is no way to get on the other side!"] = "", -- A_Classic_Fairytale:dragon
--      ["As you probably noticed, these rubber bands|are VERY elastic. Hedgehogs and many other|things will bounce off without taking any damage."] = "", -- Basic_Training_-_Movement
--      ["As you've seen, the dropped grenade roughly fell into your flying direction."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Athlete"] = "", -- Battalion
--      ["Attack: Activate"] = "", -- Racer
--      ["Attack Captain Lime before he attacks back."] = "", -- A_Space_Adventure:fruit02
--      ["Attack From Rope: %s"] = "", -- WxW
--      ["Attack From Rope: You may only attack from a rope."] = "", -- WxW
--      ["Attack rule: %s"] = "", -- WxW
--      ["Attack: Select this continent"] = "", -- Continental_supplies
--      ["Attack: [Space]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
--      ["Attack: Tap the [Bomb]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
--      ["Attack the assassins before they attack back."] = "", -- A_Space_Adventure:fruit02
--      ["Attack: Throw ball"] = "", -- Knockball
--      ["At the end of the game your health was %d."] = "", -- A_Space_Adventure:ice01
--      ["At the start of the game each enemy hog has only the weapon that he is named after."] = "", -- A_Space_Adventure:death02
      ["Australia"] = "Австралия", -- Continental_supplies
--      ["Available weapon specials:"] = "", -- Continental_supplies
      ["Average pilot"] = "Средний Пилот", -- User_Mission_-_RCPlane_Challenge
--      ["Avoid bazookas, red and blue invaders."] = "", -- Space_Invasion
--      ["Axes"] = "", -- Bazooka_Battlefield
--      ["Aye! Fellow! Let me exit this chamber of doom!"] = "", -- A_Classic_Fairytale:epil
--      ["Back Breaker"] = "", -- A_Classic_Fairytale:backstab
--      ["Back in the village, after telling the villagers about the threat..."] = "", -- A_Classic_Fairytale:united
--      ["Back in the village, the two tribes finally started to live in harmony."] = "", -- A_Classic_Fairytale:epil
--      ["Back Jump: [Backspace] ×2"] = "", -- Basic_Training_-_Movement
--      ["Back Jump: Double-tap the [Curvy Arrow]"] = "", -- Basic_Training_-_Movement
--      ["Back Jumping (1/2)"] = "", -- Basic_Training_-_Movement
--      ["Back Jumping (2/2)"] = "", -- Basic_Training_-_Movement
--      ["Backstab"] = "", -- A_Classic_Fairytale:backstab
--      ["Backwards jump: Press [Backspace] twice"] = "", -- A_Classic_Fairytale:first_blood
--      ["Backwards jump: Tap the [Curvy Arrow] twice"] = "", -- A_Classic_Fairytale:first_blood
--      ["Bacon"] = "", -- 
      ["Bad Guy"] = "Плохой", -- User_Mission_-_The_Great_Escape
--      ["Badmad"] = "", -- portal
      ["Bad Team"] = "Злодеи", -- User_Mission_-_The_Great_Escape
--      ["Bad timing"] = "", -- A_Space_Adventure:fruit01
--      ["Baggy"] = "", -- 
--      ["Balrog"] = "", -- 
      ["Bamboo Thicket"] = "Заросли Бамбука", -- User_Mission_-_Bamboo_Thicket
--      ["Barrel Launcher"] = "",
--      ["BARREL PLACEMENT MODE"] = "", -- HedgeEditor
      ["Barrel Placement Mode"] = "Режим Размещения Бочек", -- Construction_Mode
--      ["Barrier unlocked!"] = "", -- Basic_Training_-_Rope
--      ["Baseballbat"] = "", -- Continental_supplies
--      ["Baseball bat specials cannot be used close to other hogs."] = "", -- Continental_supplies
--      ["Baseball Bat with Ball"] = "", -- Knockball
--      ["Base damage has been modified to 12 per shot."] = "", -- Battalion
--      ["Based on what you've learned, destroy the target on the girder and as always, land safely!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Basically this is a combination of diving and launching."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Basic Bazooka Training"] = "", -- Basic_Training_-_Bazooka
--      ["Basic Grenade Training"] = "", -- Basic_Training_-_Grenade
--      ["Basic Movement Training"] = "", -- Basic_Training_-_Movement
--      ["Basic Rope Training"] = "", -- Basic_Training_-_Rope
--      ["Basic Training"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
--      ["Basketball"] = "", -- Basketball
      ["Bat balls at your enemies and|push them into the sea!"] = "Сбей своих соберников|бейсбольными мячами в воду!",
--      ["Battalion"] = "", -- Battalion
--      ["Battle Starts Now!"] = "", -- A_Space_Adventure:fruit01
--      ["Batty"] = "", -- 
      ["Bat your opponents through the|baskets and out of the map!"] = "Выбей своих соберников через корзину в воду!",
--      ["Bazooka Battlefield"] = "", -- Bazooka_Battlefield
--      ["Bazooka Master"] = "", -- Basic_Training_-_Bazooka
--      ["Bazookas are influenced by wind."] = "", -- Basic_Training_-_Bazooka
      ["Bazooka Training"] = "Тренировка с базукой",
--      ["Bearded Beast"] = "", -- 
--      ["Be careful, the future of Hogera is in your hands!"] = "", -- A_Space_Adventure:cosmos
--      ["Be careful, your fuel is limited from now on!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Be careful, your gadgets won't work in the bandit area. You should get an ice gun."] = "", -- A_Space_Adventure:ice01
--      ["Beep Loopers"] = "", -- A_Classic_Fairytale:queen
      ["Beginner"] = "Новичок", -- User_Mission_-_RCPlane_Challenge
--      ["Behind these trees on the east side there is Secret Base 17."] = "", -- A_Space_Adventure:cosmos
      ["Below-average pilot"] = "Пилот ниже среднего", -- User_Mission_-_RCPlane_Challenge
--      ["Besides, why would I choose certain death?"] = "", -- A_Classic_Fairytale:queen
--      ["Best laps per team: "] = "",
--      ["Best team times: "] = "", -- Racer, TechRacer
--      ["Better get yourself another health crate to heal your wounds."] = "", -- Basic_Training_-_Movement
--      ["Better luck next time!"] = "", -- ClimbHome
--      ["Better Safe Than Sorry"] = "", -- A_Space_Adventure:desert02
--      ["Beware, any damage taken will stay until you complete the moon's main mission"] = "", -- A_Space_Adventure:cosmos
--      ["Beware of mines: They explode after 3 seconds."] = "", -- A_Classic_Fairytale:journey
--      ["Beware of mines: They explode after 5 seconds."] = "", -- A_Classic_Fairytale:journey
--      ["Beware, though! If you are slow, you die!"] = "", -- A_Classic_Fairytale:dragon
--      ["Beware, though! Many smugglers come often to explore these tunnels and scavenge whatever valuable items they can find."] = "", -- A_Space_Adventure:desert01
--      ["Beware, though, you will only be able to move slowly through the water."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Big Armory"] = "", -- Big_Armory
--      ["Billy Frost"] = "", -- A_Space_Adventure:ice01
--      ["Bingo"] = "", -- 
--      ["Bio-Filter: Aggressively removes enemies."] = "", -- Construction_Mode
      ["Bio-Filter"] = "Био-Фильтр", -- Construction_Mode
--      ["Biomechanic Team"] = "", -- A_Classic_Fairytale:family
--      ["Bitter"] = "", -- 
--      ["Blanka"] = "", -- 
--      ["Blender"] = "", -- A_Classic_Fairytale:family
--      ["Bloodpie"] = "", -- A_Classic_Fairytale:backstab
--      ["Bloodrocutor"] = "", -- A_Classic_Fairytale:shadow
--      ["Bloodsucker"] = "", -- A_Classic_Fairytale:shadow
--      ["Blue"] = "", -- 
      ["Blue Team"] = "Синяя Команда", -- User_Mission_-_Dangerous_Ducklings
--      ["Bob"] = "", -- A_Space_Adventure:cosmos
      ["Bobo"] = "Бобо", -- User_Mission_-_Nobody_Laugh
--      ["Bone Jackson"] = "", -- A_Classic_Fairytale:backstab
--      ["Bonely"] = "", -- A_Classic_Fairytale:shadow
--      ["Bones"] = "", -- 
--      ["BOOM! BOOM! BOOM! %s are the masters of destruction with %d destroyed invaders."] = "", -- Space_Invasion
--      ["Boom! %s has destroyed %d invaders."] = "", -- Space_Invasion
--      ["BOOM! %s really didn't like the invaders, so they decided to destroy as much as %d of them."] = "", -- Space_Invasion
      ["Boom!"] = "Бум!",
--      ["Boris"] = "", -- A_Space_Adventure:moon01
--      ["Boss defeated! +30 points!"] = "", -- Space_Invasion
--      ["Boss Slayer! +25 points!"] = "", -- Space_Invasion
--      ["Both Barrels"] = "", -- 
--      ["Both your hedgehogs must survive."] = "", -- User_Mission_-_Teamwork_2, User_Mission_-_Teamwork
--      ["Bottom Feeder"] = "", -- Mutant
--      ["Bounciness"] = "", -- Basic_Training_-_Grenade
--      ["Bouncing Bomb"] = "", -- Basic_Training_-_Bazooka
--      ["Bouncy Boomerang"] = "", -- Continental_supplies
--      ["Bouncy Girder: [4]"] = "", -- HedgeEditor
--      ["Bouncy Land: [4]"] = "", -- HedgeEditor
--      ["Bouncy Land"] = "", -- HedgeEditor
--      ["Bounty: Get 6 weapons for each kill (even on own hogs)."] = "", -- Continental_supplies
--      ["Bozo"] = "", -- 
--      ["Brain Blower"] = "", -- A_Classic_Fairytale:journey
--      ["Brainiac"] = "", -- A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
--      ["Brainila"] = "", -- A_Classic_Fairytale:united
--      ["Brain Stu"] = "", -- A_Classic_Fairytale:united
--      ["Brain Teaser"] = "", -- A_Classic_Fairytale:backstab
--      ["Brigadier Briggs"] = "", -- 
--      ["Bruce"] = "", -- A_Space_Adventure:moon01
--      ["Brutal Lily"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil
--      ["Brutus"] = "", -- A_Classic_Fairytale:backstab
      ["Build a fortress and destroy your enemy."] = "Постройте крепость и уничтожьте своего врага.", -- Construction_Mode
--      ["Build an awesome race track by placing|waypoints which the hedgehogs have to|touch in any order to finish a round."] = "", -- Racer
      ["Build a track and race."] = "Постройте трек и гоняйте!",
--      ["Builder"] = "", -- Battalion
--      ["Build one of multiple different structures|to aid you in victory, at the cost of energy."] = "", -- Construction_Mode
--      ["Bullseye"] = "", -- A_Classic_Fairytale:dragon
--      ["Bunny"] = "", -- 
--      ["burp"] = "", -- 
--      ["Bushes"] = "", -- Bazooka_Battlefield
--      ["Bushi"] = "", -- 
--      ["Buster"] = "", -- 
--      ["But it proved to be no easy task!"] = "", -- A_Classic_Fairytale:dragon
--      ["But I want my sandals!"] = "", -- A_Classic_Fairytale:queen
--      ["But one thing's for sure:"] = "", -- A_Space_Adventure:final
--      ["But that's impossible!"] = "", -- A_Classic_Fairytale:backstab
--      ["But the ones alive are stronger in their heart!"] = "", -- A_Classic_Fairytale:enemy
--      ["But … they kidnapped you!"] = "", -- A_Classic_Fairytale:queen
--      ["But...we died!"] = "", -- A_Classic_Fairytale:backstab
--      ["But where can we go?"] = "", -- A_Classic_Fairytale:united
--      ["But why did you betray us?!"] = "", -- A_Classic_Fairytale:queen
--      ["But why would they help us?"] = "", -- A_Classic_Fairytale:backstab
--      ["But you're cannibals. It's what you do."] = "", -- A_Classic_Fairytale:enemy
--      ["But you said you'd let her go!"] = "", -- A_Classic_Fairytale:journey
--      ["But you saved me!"] = "", -- A_Classic_Fairytale:queen
--      ["By the way, not only bazookas will bounce on water, but also greandes and many other things."] = "", -- Basic_Training_-_Bazooka
--      ["By the way, not only bazookas will bounce on water, but also grenades and many other things."] = "", -- Basic_Training_-_Bazooka
--      ["By the way, you can turn around without walking|by holding down Precise when you hit a walk control."] = "", -- Basic_Training_-_Movement
--      ["C-1"] = "", -- portal
--      ["C-2"] = "", -- portal
--      ["Callahan"] = "", -- 
--      ["Call me Beep! Well, 'cause I'm such a nice...person!"] = "", -- A_Classic_Fairytale:family
--      ["Cannibals"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:first_blood
--      ["Cannibal Sentry"] = "", -- A_Classic_Fairytale:journey
--      ["Cannibals?! You're the cannibals!"] = "", -- A_Classic_Fairytale:enemy
--      ["Can you do it?"] = "", -- A_Space_Adventure:ice02
--      ["Cappy"] = "", -- Basic_Training_-_Movement
--      ["Captain Lime"] = "", -- A_Space_Adventure:fruit01, A_Space_Adventure:fruit02
--      ["Captain Lime offered his help if you assist him in battle."] = "", -- A_Space_Adventure:fruit01
--      ["Capture The Flag"] = "", -- Capture_the_Flag, CTF_Blizzard
--      ["Careful, hedgehogs can't swim!"] = "", -- Basic_Training_-_Movement
      ["Careless"] = "Беспечный",
--      ["Carol"] = "", -- A_Classic_Fairytale:family
      ["Challenge completed!"] = "Испытание пройдено!", -- SpeedShoppa
      ["CHALLENGE COMPLETE"] = "МИССИЯ ПРОЙДЕНА", -- User_Mission_-_RCPlane_Challenge
      ["Challenge failed!"] = "Испытание провалено!", -- SpeedShoppa
--      ["Challenge objectives"] = "", -- A_Space_Adventure:death02, A_Space_Adventure:desert03, A_Space_Adventure:final, A_Space_Adventure:fruit03, A_Space_Adventure:moon02
--      ["Challenge over!"] = "", -- User_Mission_-_Rope_Knock_Challenge
      ["Challenge"] = "Испытание", -- SpeedShoppa
--      ["Change bounciness: Tap [B]"] = "", -- Basic_Training_-_Grenade
--      ["Change Content: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change detonation timer: Tap the [Clock]"] = "", -- Basic_Training_-_Grenade, A_Classic_Fairytale:shadow
--      ["Change direction: [Left]/[Right]"] = "", -- Basic_Training_-_Grenade
--      ["Change Health Boost: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change Health: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change modification mode: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change Placement Mode: [Up], [Down]"] = "", -- HedgeEditor
--      ["Change Rotation: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change Sprite Frame: [Precise]+[Left], [Precise]+[Right]"] = "", -- HedgeEditor
--      ["Change Sprite: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change Timer: [Left], [Right]"] = "", -- HedgeEditor
--      ["Change weapon: [Long jump] or [Slot 1]-[Slot 3]"] = "", -- Tumbler
--      ["Charmander"] = "", -- 
--      ["Chasing the blue hog"] = "", -- A_Space_Adventure:moon02
      ["Cheater"] = "Читер", -- User_Mission_-_RCPlane_Challenge
--      ["Checkpoint reached!"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:ice01, A_Space_Adventure:moon01
--      ["Chef"] = "", -- Battalion, HedgeEditor
--      ["Chester"] = "", -- 
--      ["Chicken"] = "", -- 
--      ["Chief Sandologist"] = "", -- A_Space_Adventure:desert01
--      ["Chikorita"] = "", -- 
--      ["Choose location: Left click"] = "", -- A_Classic_Fairytale:shadow
--      ["Choose location: Tap the [Target] button, then tap on the spot you want to choose"] = "", -- A_Classic_Fairytale:shadow
--      ["Choose Selection/Placement/Deletion: [Left], [Right]"] = "", -- HedgeEditor
      ["Choose your continent wisely, as your decision will be permanent."] = "Выбирайте ваш континент ответственно, это решение нельзя будет изменить.", -- Continental_supplies
--      ["Choose your side! If you want to join the strange man, walk up to him.|Otherwise, walk away from him. If you decide to att...nevermind..."] = "", -- A_Classic_Fairytale:shadow
--      ["Chunli"] = "", -- 
      ["Clark Kent"] = "Кларк Кент", -- 
--      ["Cleaver Placement Mode"] = "", -- Construction_Mode
--      ["CLEAVER PLACEMENT MODE"] = "", -- HedgeEditor
      ["Cleaver"] = "Секач", -- Construction_Mode
--      ["Climb Home"] = "", -- ClimbHome
--      ["Closing in"] = "", -- A_Classic_Fairytale:queen
      ["Clowns"] = "Клоуны", -- User_Mission_-_Nobody_Laugh
      ["Clown"] = "Клоун", -- HedgeEditor
--      ["Cluck-cluck time: [Fire an egg ~ Sabotages and cures poison ~ Cannot be fired close to another hog]"] = "", -- Continental_supplies
      ["Clumsy"] = "Неуклюжий",
      ["Cluster Bomb Training"] = "Тренировка с Касcетной бомбой", -- Basic_Training_-_Cluster_Bomb
--      ["Collateral Damage"] = "", -- A_Classic_Fairytale:journey
--      ["Collateral Damage II"] = "", -- A_Classic_Fairytale:journey
--      ["- Collect all the blue crates"] = "", -- HedgeEditor
--      ["Collect all the crates, but remember, our time in this life is limited!"] = "", -- A_Classic_Fairytale:first_blood
      ["Collect or destroy all the health crates."] = "Собери или уничтожь все аптечки.", -- User_Mission_-_RCPlane_Challenge
--      ["Collect or destroy the final crate to finish the training."] = "", -- Basic_Training_-_Flying_Saucer
--      ["- Collect the blue crate"] = "", -- HedgeEditor
--      ["Collect the crate and attack!"] = "", -- WxW
--      ["Collect the crate on the right."] = "", -- A_Classic_Fairytale:first_blood
--      ["Collect the crates within the time limit!|If you fail, you'll have to try again."] = "", -- A_Classic_Fairytale:first_blood
--      ["Collect the first crate to begin!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Collect the freezer and get the device part from Thanta."] = "", -- A_Space_Adventure:ice01
--      ["Collect the green and purple invaders."] = "", -- Space_Invasion
--      ["Collect the remaining crates to complete the training."] = "", -- Basic_Training_-_Movement
--      ["Collect the weapon crate and drop|a grenade from rope to destroy the barrels."] = "", -- Basic_Training_-_Rope
--      ["Collect the weapon crate at the left coast!"] = "", -- A_Classic_Fairytale:journey
--      ["Color Squad"] = "", -- 
--      ["Come closer and die! … burp …"] = "", -- A_Classic_Fairytale:queen
--      ["Come closer, so that your training may continue!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Comet"] = "", -- Big_Armory
--      ["Commander"] = "", -- HedgeEditor
      ["Compete to use as few planes as possible!"] = "Постарайся использовать как можно меньше самолетов!", -- User_Mission_-_RCPlane_Challenge
--      ["Complete all main and side missions to complete the spacetrip mission."] = "", -- A_Space_Adventure:cosmos
--      ["Complete the obstacle course."] = "", -- Basic_Training_-_Movement
--      ["Complete the remaining side missions to complete this mission."] = "", -- A_Space_Adventure:cosmos
      ["Complete the track as fast as you can!"] = "Закончите трек так быстро, как сможете!",
--      ["Completion time: %.2fs"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Comrades! Sail me away!"] = "", -- A_Classic_Fairytale:queen
      ["Configuration accepted."] = "Конфигурация принята.", -- WxW
--      ["Configuration phase"] = "", -- WxW
--      ["Congrats! You won!"] = "", -- A_Space_Adventure:moon01
--      ["Congratulations, you acquired the device part!"] = "", -- A_Space_Adventure:ice01
      ["Congratulations, you are the best!"] = "Поздравляем, вы лучший!", -- A_Space_Adventure:desert03
      ["Congratulations, you are the fastest!"] = "Поздравляем, вы самый быстрый!", -- A_Space_Adventure:moon02
--      ["Congratulations, you collected the device part!"] = "", -- A_Space_Adventure:ice01
--      ["Congratulations! You have completed the obstacle course!"] = "", -- Basic_Training_-_Movement
      ["Congratulations! You have destroyed all targets within the time."] = "Поздравляем! Вы уничтожили все цели во время.", -- TargetPractice
--      ["Congratulations, you have saved Hogera!"] = "", -- A_Space_Adventure:final
      ["Congratulations! You have truly mastered this challenge! Don't forget to save the demo."] = "Поздравляем! Вы действительно освоили это испытание!", -- User_Mission_-_RCPlane_Challenge
--      ["Congratulations! You've completed the Basic Rope Training!"] = "", -- Basic_Training_-_Rope
      ["Congratulations! You've eliminated all targets|within the allowed time frame."] = "Поздравляем! Ты уничтожил все цели во время.", --Bazooka, Shotgun, SniperRifle
      ["Congratulations! You win."] = "Поздравляем! Вы выиграли.", -- Big_Armory
      ["Congratulations, you won!"] = "Поздравляем, вы выиграли!", -- A_Space_Adventure:death01, A_Space_Adventure:death02, A_Space_Adventure:desert01, A_Space_Adventure:desert02, A_Space_Adventure:fruit02, A_Space_Adventure:fruit03, A_Space_Adventure:ice02
      ["Congratulations!"] = "Поздравления!",
      ["Congratulations"] = "Поздравляем", -- Basic_Training_-_Rope
--      ["Conquering the galaxy"] = "", -- A_Space_Adventure:cosmos
--      ["Construction Mode tool"] = "", -- Construction_Mode
      ["CONSTRUCTION MODE"] = "РЕЖИМ СТРОИТЕЛЬСТВА", -- Construction_Mode
--      ["Construction Station: Allows placement of|    girders, rubber, mines, sticky mines|    and barrels."] = "", -- Construction_Mode
      ["Construction Station"] = "Станция Утилит", -- Construction_Mode
--      ["Continental supplies"] = "", -- Continental_supplies
--      ["Continent selection"] = "", -- Continental_supplies
--      ["Continents: Select a continent at the beginning."] = "", -- Continental_supplies
--      ["Control"] = "", -- Control
      ["Control pillars to score points."] = "Контролируй колонны, чтобы заработать очки.", -- Control
--      ["Controls: Hold the Attack key (space by default) to|fire the rope, then, once attached use:|Left and Right to swing the rope;|Up and Down to contract and expand."] = "", -- Basic_Training_-_Rope
      ["Copper"] = "Медный", -- User_Mission_-_Nobody_Laugh
--      ["Corn"] = "", -- A_Space_Adventure:fruit01
--      ["Corporal Calvin"] = "", -- 
--      ["Corporationals"] = "", -- A_Classic_Fairytale:queen
--      ["Corpsemonger"] = "", -- A_Classic_Fairytale:shadow
--      ["Corpse Thrower"] = "", -- A_Classic_Fairytale:epil
--      ["Cost: %d"] = "", -- Construction_Mode
      ["Cost"] = "Стоимость", -- Construction_Mode
--      ["Cotton Needer"] = "", -- Mutant
--      ["Count Hogula"] = "", -- 
--      ["Coward"] = "", -- A_Classic_Fairytale:queen
--      ["Crate Before Attack: %s"] = "", -- WxW
--      ["Crate Before Attack: You must collect a crate before you can attack."] = "", -- WxW
--      ["Crate Placer"] = "", -- Construction_Mode
--      ["Crates: Crates drop more often with a higher chance of bonus ammo"] = "", -- Battalion
--      ["Crates: Crates drop randomly and may be empty"] = "", -- Battalion
--      ["Crates: Crates drop randomly with chance of being empty"] = "", -- Battalion
      ["Crates left: %d"] = "Осталось ящиков: %d", -- User_Mission_-_RCPlane_Challenge
--      ["Crates per turn: %d"] = "", -- WxW
--      ["Crazy Gravity: Gravity randomly changes within a range from %i%% to %i%% with a period of %s"] = "", -- Gravity
--      ["Crazy Runner"] = "", -- A_Space_Adventure:moon02
--      ["Cricket Time"] = "", -- Continental_supplies
--      ["Cricket time: [Fire away a 1 sec mine! ~ Cannot be fired close to another hog]"] = "", -- Continental_supplies
--      ["CTF_Blizzard"] = "", -- CTF_Blizzard
--      ["Cursor: Build structure"] = "", -- Construction_Mode
--      ["Cursor: Mode action"] = "", -- HedgeEditor
--      ["|Cursor: Place crate"] = "", -- Construction_Mode
--      ["Cursor: Place waypoint"] = "", -- Racer
--      ["Cutlass Cain"] = "", -- 
      ["Cybernetic Empire"] = "Кибер Империя", -- User_Mission_-_Bamboo_Thicket
--      ["Cyborg. It's what the aliens call themselves."] = "", -- A_Classic_Fairytale:enemy
--      ["Dahmer"] = "", -- A_Classic_Fairytale:backstab
--      ["Daisy"] = "", -- 
      ["DAMMIT, ROOKIE! GET OFF MY HEAD!"] = "ЧЁРТ ПОБЕРИ! СЛЕЗЬ С МОЕЙ ГОЛОВЫ!",
      ["DAMMIT, ROOKIE!"] = "ЧЁРТ ПОБЕРИ, САЛАГА!",
--      ["+%d ammo"] = "", -- Battalion
--      ["+%d Ammo"] = "", -- Space_Invasion
      ["Dangerous Ducklings"] = "Опасные Утята", -- User_Mission_-_Dangerous_Ducklings
--      ["Dark Strawberry"] = "", -- A_Space_Adventure:fruit02
--      ["+%d"] = "", -- Battalion
      ["%d crate(s) remaining"] = "%d ящиков осталось", -- SpeedShoppa
--      ["%d damage was dealt in this game."] = "", -- Mutant
--      ["%d / %d"] = "", -- Battalion
--      ["%d | %d"] = "", -- Mutant
--      ["%d/%d"] = "", -- SpeedShoppa
--      ["Deadly Grape"] = "", -- A_Space_Adventure:fruit02
      ["Deadweight"] = "Балласт",
--      ["Deal 15 damage + 10% of your hog’s health to all hogs around you and get 2/3 back."] = "", -- Continental_supplies
--      ["Deals 15 damage to all enemies in the circle."] = "", -- Continental_supplies
--      ["Deer"] = "", -- 
--      ["Defeat all enemies!"] = "", -- portal
--      ["Defeat!"] = "", -- HedgeEditor
--      ["Defeat Professor Hogevil!"] = "", -- A_Space_Adventure:death01
--      ["Defeat the cannibals!"] = "", -- A_Classic_Fairytale:shadow
--      ["Defeat the cannibals!|Grenade hint: set the timer with [1-5], aim with [Up]/[Down] and hold [Space] to set power"] = "", -- A_Classic_Fairytale:shadow
--      ["Defeat the cyborgs!"] = "", -- A_Classic_Fairytale:enemy
--      ["Defeat the enemy!"] = "", -- A_Classic_Fairytale:queen
--      ["Delete Waypoint"] = "", -- HedgeEditor
--      ["Deletion Mode: [5]"] = "", -- HedgeEditor
--      ["Deletion Mode"] = "", -- HedgeEditor
--      ["Deletition Mode"] = "", -- HedgeEditor
      ["Demolition is fun!"] = "Разрушать весело!",
      ["Demo"] = "Подрывник", -- The_Specialists
--      ["Dense Cloud"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["Dense Cloud must have already told them everything..."] = "", -- A_Classic_Fairytale:shadow
--      ["Dense Cloud?! What are you doing?!"] = "", -- A_Classic_Fairytale:queen
--      ["Depleted Kamikaze! +5 points!"] = "", -- Space_Invasion
      ["Derp"] = "Глупый", -- User_Mission_-_Nobody_Laugh
--      ["Desert Storm"] = "", -- 
--      ["Destroy all targets with no more than 10 bazookas."] = "", -- Basic_Training_-_Bazooka
--      ["Destroy all targets with no more than 5 bazookas."] = "", -- Basic_Training_-_Bazooka
--      ["Destroy all the targets!"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
      ["Destroyer of planes"] = "Уничтожитель самолётов", -- User_Mission_-_RCPlane_Challenge
--      ["Destroy him, Leaks A Lot! He is responsible for the deaths of many of us!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Destroy invaders and collect bonuses to score points."] = "", -- Space_Invasion
--      ["- Destroy the enemy"] = "", -- HedgeEditor
--      ["- Destroy the red target"] = "", -- HedgeEditor
--      ["- Destroy the red targets"] = "", -- HedgeEditor
--      ["Destroy the targets!"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["+%d flamer fuel!"] = "", -- Tumbler
--      ["+%d health"] = "", -- Mutant
--      ["%d-Hit Combo! +%d points!"] = "", -- Space_Invasion
--      ["Did anyone follow you?"] = "", -- A_Classic_Fairytale:united
--      ["Did I miss something?"] = "", -- Space_Invasion
--      ["Did not finish"] = "", -- Racer, TechRacer
--      ["Did you really think I've changed?"] = "", -- A_Classic_Fairytale:queen
--      ["Did you really think that I've changed?"] = "", -- A_Classic_Fairytale:queen
--      ["Did you really think that we needed the help of one of you?"] = "", -- A_Classic_Fairytale:queen
--      ["Did you see him coming?"] = "", -- A_Classic_Fairytale:shadow
--      ["Did you warn the village?"] = "", -- A_Classic_Fairytale:shadow
--      ["Die, die, die!"] = "", -- A_Classic_Fairytale:dragon
--      ["Difficulty: "] = "", -- Continental_supplies
--      ["Difficulty: Easy"] = "", -- A_Classic_Fairytale:first_blood
--      ["Difficulty: Hard"] = "", -- A_Classic_Fairytale:first_blood
--      ["Dimitry"] = "", -- 
--      ["%d invaders have been destroyed in this game."] = "", -- Space_Invasion
      ["Disabled"] = "Отключено", -- WxW
--      ["Disguise as a Rockhopper Penguin"] = "", -- Continental_supplies
--      ["Disguise as a Rockhopper Penguin: [Swap place with a random enemy hog in the circle]"] = "", -- Continental_supplies
--      ["Displacer"] = "", -- 
--      ["Diver"] = "", -- User_Mission_-_Diver
--      ["%d ms"] = "", -- HedgeEditor
--      ["Doing stuff a monkey could do."] = "", -- A_Classic_Fairytale:queen
--      ["Domination game"] = "", -- Control
      ["Donald"] = "Дональд", -- 
--      ["Do not destroy the crates!"] = "", -- A_Space_Adventure:fruit02
--      ["Do not laugh, inexperienced one, for he speaks the truth!"] = "", -- A_Classic_Fairytale:backstab
--      ["Do not let his words fool you, young one! He will stab you in the back as soon as you turn away!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Don't be foolish, son, there will be more."] = "", -- A_Space_Adventure:fruit01
--      ["Don't blow up the crate."] = "", -- A_Classic_Fairytale:journey
--      ["Don't destroy the device crate!"] = "", -- A_Space_Adventure:desert01
--      ["Don't eliminate Captain Lime before collecting the last crate!"] = "", -- A_Space_Adventure:fruit02
--      ["Don't hit me, you fools!"] = "", -- A_Space_Adventure:moon01
--      ["Don't hit yourself!"] = "", -- Basic_Training_-_Bazooka
--      ["Don't touch the flames!"] = "", -- ClimbHome
--      ["Don't you dare harming our tribe!"] = "", -- A_Classic_Fairytale:queen
--      ["Double kill!"] = "", -- Mutant
      ["Double Kill!"] = "Двойное убийство!",
--      ["Do you have any idea how bad an exploding arrow hurts?"] = "", -- A_Classic_Fairytale:queen
--      ["Do you have any idea how valuable grass is?"] = "", -- A_Classic_Fairytale:enemy
--      ["Do you have any idea what it's like in the village for a woman?"] = "", -- A_Classic_Fairytale:queen
--      ["Do you know where they are?"] = "", -- A_Classic_Fairytale:queen
--      ["Do you think you're some kind of god?"] = "", -- A_Classic_Fairytale:enemy
--      ["Dragon's Lair"] = "", -- A_Classic_Fairytale:dragon
--      ["Dr. Banting"] = "", -- 
--      ["Dr. Barnard"] = "", -- 
--      ["Dr. Blackwell"] = "", -- 
--      ["Dr. Cornelius"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:death01
--      ["Dr. Crushing"] = "", -- 
--      ["Dr. Drew"] = "", -- 
--      ["Dr. Harvey"] = "", -- 
--      ["Dr. Hollows"] = "", -- 
--      ["Dr. Horace"] = "", -- 
--      ["Drills"] = "", -- A_Classic_Fairytale:backstab
--      ["Drill Strike"] = "", -- Construction_Mode
--      ["Dr. Jenner"] = "", -- 
--      ["Dr. Jung"] = "", -- 
--      ["Drone Hunter! +10 points!"] = "", -- Space_Invasion
--      ["Drop a ball of dirt which turns into a|cluster on impact. Doesn’t end turn."] = "", -- Continental_supplies
--      ["Drop a bomb: [Drop some heroic wind that will turn into a bomb on impact]"] = "", -- Continental_supplies
--      ["- Dropped flags may be returned or recaptured"] = "", -- Capture_the_Flag
--      ["Dropping a weapon while in water would just drown it, but launching one would work."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Drop weapon (while on rope): [Long Jump]"] = "", -- Basic_Training_-_Rope
      ["Drowner"] = "Утопающий", -- User_Mission_-_Nobody_Laugh
--      ["Dr. Parkinson"] = "", -- 
      ["Drunk greenhorn"] = "Пьяный молокосос", -- User_Mission_-_RCPlane_Challenge
--      ["Drunk with power, perhaps!"] = "", -- A_Classic_Fairytale:queen
--      ["%d sec"] = "", -- Construction_Mode
--      ["+%d seconds!"] = "", -- Tumbler
--      ["Dubloon Devil"] = "", -- 
--      ["Dude, all the plants are gone!"] = "", -- A_Classic_Fairytale:family
--      ["Dude, can you see Ramon and Spiky?"] = "", -- A_Classic_Fairytale:journey
--      ["Dude, it's unbearable!"] = "", -- A_Classic_Fairytale:queen
--      ["Dude, let me out!"] = "", -- A_Classic_Fairytale:epil
--      ["Dude, that outfit is so cool!"] = "", -- A_Classic_Fairytale:epil
--      ["Dude, that's so cool!"] = "", -- A_Classic_Fairytale:backstab
--      ["Dude, this is boring!"] = "", -- A_Classic_Fairytale:queen
--      ["Dude, we really need a new shaman..."] = "", -- A_Classic_Fairytale:shadow
--      ["Dude, what's this place?!"] = "", -- A_Classic_Fairytale:dragon
--      ["Dude, where are we?"] = "", -- A_Classic_Fairytale:backstab
--      ["Dude, wow! I just had the weirdest high!"] = "", -- A_Classic_Fairytale:backstab
--      ["Dude, wow, you're so cute!"] = "", -- A_Classic_Fairytale:queen
--      ["Dud Mine Placement Mode"] = "", -- HedgeEditor
--      ["DUD MINE PLACEMENT MODE"] = "", -- HedgeEditor
--      ["Duration"] = "", -- Continental_supplies
--      ["During the final testing of the device an accident happened."] = "", -- A_Space_Adventure:moon02
--      ["During the game you can get new RC planes by collecting the weapon crates."] = "", -- A_Space_Adventure:desert03
--      ["Dust Storm"] = "", -- Continental_supplies
--      ["Dust storm: [Deals 15 damage to all enemies in the circle]"] = "", -- Continental_supplies
--      ["Each time you destroy all the targets on your current level you'll get teleported to the next level."] = "", -- A_Space_Adventure:desert03
--      ["Each time you play this missions enemy hogs will play in a random order."] = "", -- A_Space_Adventure:death02
--      ["Each turn is only ONE SECOND!"] = "", -- Frenzy
      ["Each turn you get 1-3 random weapons"] = "Каждый ход вы получаете 1-3 случайных оружия",
      ["Each turn you get one random weapon"] = "Каждый ход вы получаете одно случайное оружие",
--      ["Each turn you'll have only one rope to use."] = "", -- A_Space_Adventure:moon02
--      ["Eagle Eye"] = "", -- A_Classic_Fairytale:backstab
--      ["Eagle Eye: [Blink to the impact ~ One shot]"] = "", -- Continental_supplies
--      ["Ear Sniffer"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:epil
--      ["EASY"] = "", -- Continental_supplies
      ["Eckles"] = "Заика", -- User_Mission_-_Nobody_Laugh
--      ["Eclipse"] = "", -- Big_Armory
--      ["Editing Commands: (Use while no weapon is selected)"] = "", -- HedgeEditor
--      ["Ehm, okay ..."] = "", -- A_Space_Adventure:moon01
--      ["Elderbot"] = "", -- A_Classic_Fairytale:family
      ["Elimate your captor."] = "Уничтожь твоего похитителя.", -- User_Mission_-_The_Great_Escape
      ["Eliminate all targets before your time runs out.|You have unlimited ammo for this mission."] = "Уничтожь все цели, пока время не вышло.|Для этой миссии доступен неограниченный боезапас.", --Bazooka, Shotgun, SniperRifle
--      ["Eliminate the enemy before the time runs out."] = "", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree
--      ["Eliminate the enemy hogs to win."] = "",
--      ["Eliminate the enemy."] = "", -- User_Mission_-_Bamboo_Thicket, User_Mission_-_Newton_and_the_Hammock, User_Mission_-_Nobody_Laugh
--      ["Eliminate Unit 3378."] = "", -- User_Mission_-_Teamwork
--      ["Eliminate WatchBot 4000."] = "", -- User_Mission_-_Teamwork_2
--      ["Eliminate your captor."] = "", -- User_Mission_-_The_Great_Escape
      ["Elite pilot"] = "Элитный пилот", -- User_Mission_-_RCPlane_Challenge
--      ["Elmo"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
      ["Enabled"] = "Включено", -- WxW
--      ["Enemy kills: Collect victim's weapons and +%d%% of its base health"] = "", -- Battalion
      ["Energetic Engineer"] = "Энергичный Инженер", -- User_Mission_-_Bamboo_Thicket
      ["Engineer"] = "Инженер", -- The_Specialists
      ["Enjoy the swim..."] = "Приятного плавания...",
--      ["Entered boredom phase! Discrepancies detected …"] = "", -- A_Classic_Fairytale:queen
      ["Epilogue"] = "Эпилог", -- A_Classic_Fairytale:epil
--      ["ERROR [getHogInfo]: Hog is nil!"] = "", -- Battalion
      ["Eugene"] = "Евгений", -- 
      ["Europe"] = "Европа", -- Continental_supplies
      ["Everyone knows this."] = "Каждый знает это.", -- A_Classic_Fairytale:enemy
--      ["Every single time!"] = "", -- A_Classic_Fairytale:dragon
      ["Everything looks OK..."] = "Всё выглядит нормально...", -- A_Classic_Fairytale:enemy
--      ["Every time you kill an enemy hog your ammo will get reset next turn."] = "", -- A_Space_Adventure:death02
--      ["Everywhere I look, I see hogs walking around …"] = "", -- A_Classic_Fairytale:epil
--      ["Exactly, man! That was my dream."] = "", -- A_Classic_Fairytale:backstab
      ["Except me, of course! I just saved a whole planet!"] = "Кроме меня, конечно! Я только что спас целую планету!", -- A_Space_Adventure:final
      ["Experienced beginner"] = "Продвинутый новичок", -- User_Mission_-_RCPlane_Challenge
--      ["Explore the tunnel with the other hedgehogs and search for the device."] = "", -- A_Space_Adventure:fruit02
--      ["Exploring the tunnel"] = "", -- A_Space_Adventure:fruit02
--      ["Eye Chewer"] = "", -- A_Classic_Fairytale:journey
--      ["Fair Wind"] = "", -- 
--      ["Fall Damage"] = "", -- Basic_Training_-_Movement
--      ["Fallen Angel"] = "", -- Tentacle_Terror
--      ["Family Reunion"] = "", -- A_Classic_Fairytale:family
--      ["Fastest escape: %d turns"] = "", -- A_Space_Adventure:desert02
      ["Fastest lap: %.3fs by %s"] = "Лучший результат: %.3fs от %s", -- TrophyRace
      ["Fastest lap: "] = "Лучший результат: ",
      ["Feeble Resistance"] = "Слабое Сопротивление",
--      ["Fell From Grace"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Fell From Heaven"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen
--      ["Fell From Heaven is the best! Fell From Heaven is the greatest!"] = "", -- A_Classic_Fairytale:family
--      ["Femur Lover"] = "", -- A_Classic_Fairytale:shadow
--      ["Fierce Competition! +8 points!"] = "", -- Space_Invasion
--      ["Fiery Water"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Fiery Water?! Are you drunk again?"] = "", -- A_Classic_Fairytale:queen
--      ["Fighting instead of cultivating a beautiful friendship."] = "", -- A_Classic_Fairytale:epil
--      ["Fight: Press [Attack]"] = "", -- A_Space_Adventure:fruit01
      ["Filthy Blue"] = "Грязный Синяк", -- User_Mission_-_Dangerous_Ducklings
      ["Final Challenge:"] = "Последнее испытание:", -- Basic_Training_-_Rope
--      ["Finally! We're out of this hellhole. Now go save the princess, %s!"] = "", -- A_Classic_Fairytale:family
--      ["Finally you are here!"] = "", -- A_Space_Adventure:desert01, A_Space_Adventure:ice01
--      ["Final result"] = "", -- Mutant
--      ["Final Targets"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["Final team scores:"] = "", -- Space_Invasion
--      ["Find all the parts of the anti-gravity device."] = "", -- A_Space_Adventure:cosmos
--      ["Find a way to detonate all the explosives and stay alive!"] = "", -- A_Space_Adventure:final
--      ["Find your tribe!|Cross the lake!"] = "", -- A_Classic_Fairytale:dragon
--      ["Finish this challenge as fast as possible to earn bonus points."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Finish waypoint placement"] = "", -- Racer
--      ["Finish your training."] = "", -- A_Classic_Fairytale:first_blood
--      ["Finite Ropes"] = "", -- Basic_Training_-_Rope
--      ["Fire a rocket with napalm."] = "", -- Continental_supplies
--      ["Fire: [Precise]"] = "", -- Space_Invasion, Tumbler
--      ["Fire some exploding medicine that will heal 15 health to all hogs in its effect radius."] = "", -- Continental_supplies
--      ["Fire your hedgehog like a sticky mine."] = "", -- Continental_supplies
--      ["First aid kits?!"] = "", -- A_Classic_Fairytale:united
--      ["First Blood"] = "", -- A_Classic_Fairytale:first_blood
--      ["- First clan to capture the flag wins"] = "", -- Capture_the_Flag
      ["- First clan to score %d captures wins"] = "Первая команда набравшая %d очков выигрывает", -- Capture_the_Flag
--      ["First killer will mutate"] = "", -- Mutant
--      ["First Steps"] = "", -- A_Classic_Fairytale:first_blood
--      ["- First team to capture the flag wins"] = "", -- Capture_the_Flag
--      ["- First team to score %d captures wins"] = "", -- Capture_the_Flag
--      ["Fishy"] = "", -- 
      ["Flag captured!"] = "Флаг захвачен!",
      ["Flag respawned!"] = "Респаун флага!",
      ["Flag returned!"] = "Флаг возвращен!",
--      ["Flamer"] = "",
--      ["Flaming Worm"] = "", -- A_Classic_Fairytale:backstab
--      ["Flare"] = "", -- Continental_supplies
      ["Flawless victory!"] = "Безупречная победа!", -- User_Mission_-_RCPlane_Challenge
--      ["Flee: Press [Jump]"] = "", -- A_Space_Adventure:fruit01
--      ["Flesh for Brainz"] = "", -- A_Classic_Fairytale:journey
--      ["Fly around and hurl explosives to your enemies."] = "", -- Tumbler
--      ["Flying Saucer Training"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Fly into space to fight off the invaders with barrels!"] = "", -- Space_Invasion
--      ["Fly to the meteorite and detonate the explosives"] = "", -- A_Space_Adventure:cosmos
--      ["Follow the path and destroy the next target."] = "", -- Basic_Training_-_Rope
--      ["Forgetfulness: You will lose all your weapons each turn."] = "", -- Continental_supplies
--      ["For the next crate, you have to do back jumps."] = "", -- Basic_Training_-_Movement
--      ["Four Eyes"] = "", -- 
--      ["Frankie"] = "", -- 
      ["Frank"] = "Фрэнк", -- User_Mission_-_Nobody_Laugh
--      ["Free Dense Cloud and continue the mission!"] = "", -- A_Classic_Fairytale:journey
--      ["FRENZY"] = "", -- Frenzy
--      ["Friendly Fire!"] = "",
--      ["Friendly kills: Clear killer's pool and -%d%% of its base health"] = "", -- Battalion
--      ["From the second turn and beyond the water rises."] = "", -- A_Space_Adventure:desert02
--      ["Frozen Bandits"] = "", -- A_Space_Adventure:ice01
--      ["Fruit"] = "", -- 
--      ["Fruit Assassins"] = "", -- A_Space_Adventure:fruit02
--      ["Fruity"] = "", -- 
--      ["Fuel: %d"] = "", -- Tumbler
--      ["Fuzzy Beard"] = "", -- 
--      ["“g=150”, where 150 is 150% of normal gravity."] = "", -- Gravity
--      ["“g=50, g2=150, period=4000” for gravity changing|from 50 to 150 and back with period of 4000 ms."] = "", -- Gravity
--      ["Galaxy Guardians"] = "", -- Big_Armory
--      ["Game over!"] = "", -- Space_Invasion
      ["Game Started!"] = "Игра Началась!",
--      ["Game? Was this a game to you?!"] = "", -- A_Classic_Fairytale:enemy
--      ["Gangsters"] = "", -- 
--      ["GasBomb"] = "", -- Continental_supplies
--      ["Gas Gargler"] = "", -- A_Classic_Fairytale:queen
--      ["Gasp! A smuggler!"] = "", -- A_Space_Adventure:desert01
--      ["Gasp!"] = "", -- A_Space_Adventure:desert01
--      ["Gathering fruits all day long."] = "", -- A_Classic_Fairytale:queen
--      ["Gear Placement Tool"] = "", -- HedgeEditor
--      ["General information"] = "", -- Continental_supplies
--      ["General information:"] = "", -- Continental_supplies
--      ["General Lemon"] = "", -- A_Space_Adventure:fruit01
--      ["Generator: Generates energy."] = "", -- Construction_Mode
      ["Generator"] = "Генератор", -- Construction_Mode
--      ["Get Dense Cloud out of the pit!"] = "", -- A_Classic_Fairytale:journey
--      ["Get him, Spike!"] = "", -- A_Space_Adventure:desert01
      ["Get on over there and take him out!"] = "Доберись туда и уничтожь его!",
--      ["Get on the head of the mole."] = "", -- A_Classic_Fairytale:first_blood
--      ["Get past the flower."] = "", -- A_Classic_Fairytale:journey
--      ["Get ready to fight!"] = "", -- A_Space_Adventure:moon01
--      ["Get that crate!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Get the crate on the other side of the island!|"] = "", -- A_Classic_Fairytale:journey
--      ["Get the crate on the other side of the island."] = "", -- A_Classic_Fairytale:journey
--      ["Get the final crate to the right to complete the training."] = "", -- Basic_Training_-_Movement
--      ["Get the highest score to win."] = "", -- Space_Invasion
--      ["Get the next crate by jumping over the abyss."] = "", -- Basic_Training_-_Movement
--      ["Getting ready"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:desert01, A_Space_Adventure:desert02, A_Space_Adventure:ice01, A_Space_Adventure:ice02, A_Space_Adventure:moon01
--      ["Getting Started"] = "", -- Basic_Training_-_Rope
--      ["Getting to the device"] = "", -- A_Space_Adventure:fruit02
--      ["Get to the crate using your flying saucer!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Get to the target using your rope!"] = "", -- Basic_Training_-_Rope
--      ["Get your teammates out of their natural prison and save the princess!"] = "", -- A_Classic_Fairytale:family
--      ["Get your teammates out of their natural prison and save the princess!|Hint: Drilling holes should solve everything.|Hint: It might be a good idea to place a girder before starting to drill. Just saying.|Hint: All your hedgehogs need to be above the marked height!|Hint: Leaks A Lot needs to get really close to the princess!"] = "", -- A_Classic_Fairytale:family
--      ["Giggles"] = "", -- 
--      ["Gimme Bones"] = "", -- A_Classic_Fairytale:backstab
--      ["Girder"] = "", -- Construction_Mode
--      ["GIRDER PLACEMENT MODE"] = "", -- HedgeEditor
      ["Girder Placement Mode"] = "Режим Размещения Балок", -- Construction_Mode
--      ["Give a hog a preset identity and weapons"] = "", -- HedgeEditor
--      ["Give an entire team themed hats and names"] = "", -- HedgeEditor
--      ["Glark"] = "", -- A_Classic_Fairytale:shadow
--      ["Glasses"] = "", -- 
--      ["Glassy"] = "", -- 
--      ["Goal Definition Mode"] = "", -- HedgeEditor
--      ["GOAL DEFINITION MODE"] = "", -- HedgeEditor
--      ["Goal: Score %d points or more to win!"] = "", -- Mutant
--      ["Go and collect the crate"] = "", -- A_Space_Adventure:cosmos
--      ["Godai"] = "", -- 
--      ["Go down and save these PAotH hogs!"] = "", -- A_Space_Adventure:moon01
--      ["Go, get him again!"] = "", -- A_Space_Adventure:moon02
--      ["Goggles"] = "", -- 
--      ["Goggs"] = "", -- 
      ["GO! GO! GO!"] = "ВПЕРЁД! ВПЕРЁД! ВПЕРЁД!",
      ["Good birdy......"] = "Хорошая птичка...",
--      ["Good bye!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Good idea, they'll never find us there!"] = "", -- A_Classic_Fairytale:united
--      ["Good job!"] = "", -- Basic_Training_-_Flying_Saucer, Basic_Training_-_Rope
--      ["Good job! Defeat the rest of the aliens!"] = "", -- A_Classic_Fairytale:queen
--      ["Good job! Now destroy the final targets to finish the training."] = "", -- Basic_Training_-_Grenade
--      ["Good luck!"] = "", -- A_Space_Adventure:desert01, A_Space_Adventure:fruit02
--      ["Good luck...or else!"] = "", -- A_Classic_Fairytale:journey
      ["Good luck out there!"] = "Удачи там!",
      ["Good so far!"] = "Пока хорошо!",
      ["Good to go!"] = "Пошёл!",
--      ["Good! You now control Cappy."] = "", -- Basic_Training_-_Movement
--      ["Go on top of the flower."] = "", -- A_Classic_Fairytale:first_blood
--      ["Go, quick!"] = "", -- A_Classic_Fairytale:backstab
--      ["Gorkij"] = "", -- A_Classic_Fairytale:journey
      ["Go surf!"] = "Теперь сёрфить!", -- WxW
--      ["Got 1 more saucer and 8 more seconds added to the clock"] = "", -- A_Space_Adventure:ice02
--      ["Got 1 more saucer"] = "", -- A_Space_Adventure:ice02
      ["GOTCHA!"] = "ПОПАЛСЯ!",
--      ["Go to Thanta and get the device part!"] = "", -- A_Space_Adventure:ice01
--      ["Go to the surface!"] = "", -- A_Space_Adventure:fruit02
--      ["Go to the target."] = "", -- Basic_Training_-_Rope
--      ["Go to the upper platform and get the weapons in the crates!"] = "", -- A_Space_Adventure:moon01
--      ["Got the saucer!"] = "", -- A_Space_Adventure:cosmos
--      ["Got to go back."] = "", -- A_Space_Adventure:cosmos
--      ["Got you? You're acting weird."] = "", -- A_Classic_Fairytale:queen
--      ["Grab mines/barrels: [High jump]"] = "", -- Tumbler
--      ["Gravity: 100%"] = "", -- Gravity
--      ["Great!"] = "", -- Basic_Training_-_Rope
--      ["Great choice, Steve! Mind if I call you that?"] = "", -- A_Classic_Fairytale:shadow
--      ["Great! Let’s kill all these enemies, using portals."] = "", -- portal
      ["Great work! Now hit it with your Baseball Bat! |Tip: You can change weapon with 'Right Click'!"] = "Хорошая работа! А теперь ударь его Бейсбольной Битой! |Подсказка: Оружие можно сменить 'Правым кликом'!", -- Basic_Training_-_Rope
--      ["Great! You will be contacted soon for assistance."] = "", -- A_Classic_Fairytale:shadow
--      ["Green"] = "", -- 
--      ["Green Bananas"] = "", -- A_Space_Adventure:fruit01
--      ["Green double rings also give you a new flying saucer."] = "", -- A_Space_Adventure:ice02
--      ["Green Hog Grape"] = "", -- A_Space_Adventure:fruit01
--      ["Green hogs won't intentionally hurt you."] = "", -- A_Space_Adventure:fruit01
      ["Greenhorn"] = "Молокосос", -- User_Mission_-_RCPlane_Challenge
--      ["Green Lipstick Bullet"] = "", -- Continental_supplies
--      ["Green lipstick bullet: [Poisonous, deals no damage]"] = "", -- Continental_supplies
--      ["Greetings, cloudy one!"] = "", -- A_Classic_Fairytale:shadow
--      ["Greetings from the Navy, %s (%s), for being a distance of %d away from the mainland!"] = "", -- ClimbHome
--      ["Greetings, %s!"] = "", -- A_Classic_Fairytale:dragon
--      ["Grenades explode after 1 to 5 seconds (you decide)."] = "", -- Basic_Training_-_Grenade
--      ["Grenades with high bounciness bounce a lot and behave chaotic."] = "", -- Basic_Training_-_Grenade
      ["Grenade Training"] = "Тренировка с Гранатой", -- Basic_Training_-_Grenade
      ["Grenadiers"] = "Гренадеры", -- Basic_Training_-_Grenade
      ["Grenadier"] = "Гренадер", -- Target_Practice_-_Grenade_easy, Target_Practice_-_Grenade_hard
--      ["Grey"] = "", -- 
--      ["Guards"] = "", -- A_Space_Adventure:cosmos
--      ["Guile"] = "", -- 
--      ["Guys, do you think there's more of them?"] = "", -- A_Classic_Fairytale:backstab
--      ["HAHA!"] = "", -- A_Classic_Fairytale:enemy
--      ["Haha!"] = "", -- A_Classic_Fairytale:united
--      ["Haha! Come!"] = "", -- A_Classic_Fairytale:queen
      ["Hahahaha!"] = "Хахахаха!",
--      ["Haha, I love the look on your face!"] = "", -- A_Classic_Fairytale:queen
      ["Haha, now THAT would be something!"] = "Хаха, да не гони, ЭТО уже слишком!",
--      ["Haha, that was just a coincidence!"] = "", -- A_Classic_Fairytale:queen
      ["Hammer"] = "Молот", -- Construction_Mode, Continental_supplies
--      ["Hannibal"] = "", -- A_Classic_Fairytale:epil
      ["Hapless Hogs"] = "Несчастные Ежи",
--      ["Happy with your race track?|Then stop building and start racing!"] = "", -- Racer
--      ["HARD"] = "", -- Continental_supplies
--      ["Hard flying"] = "", -- A_Space_Adventure:ice02
--      ["Harris"] = "", -- 
--      ["Harry Potter"] = "", -- 
      ["Harry"] = "Гарри", -- User_Mission_-_Nobody_Laugh
--      ["H"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:death01
--      ["Hatless Jerry"] = "", -- A_Classic_Fairytale:queen
--      ["Have no illusions, your tribe is dead, indifferent of your choice."] = "", -- A_Classic_Fairytale:shadow
--      ["Haven't found it yet ..."] = "", -- A_Space_Adventure:desert01
--      ["Have we ever attacked you first?"] = "", -- A_Classic_Fairytale:enemy
--      ["H confirmed that there isn't such a PAotH activity logged."] = "", -- A_Space_Adventure:desert01
--      ["Healing Station: Heals nearby hogs."] = "", -- Construction_Mode
      ["Healing Station"] = "Лечебная Станция", -- Construction_Mode
--      ["Health and Mission Panel"] = "", -- Basic_Training_-_Movement
--      ["Health"] = "", -- Basic_Training_-_Movement
--      ["HEALTH CRATE PLACEMENT MODE"] = "", -- HedgeEditor
      ["Health Crate Placement Mode"] = "Режим Размещения Аптечек", -- Construction_Mode
--      ["Health: %d"] = "", -- HedgeEditor
--      ["Health: Hogs lose up to 7% base health per turn"] = "", -- Battalion
--      ["Health Modification Mode"] = "", -- HedgeEditor
--      ["HEALTH MODIFICATION MODE"] = "", -- HedgeEditor
--      ["Heavenly Defense"] = "", -- Tentacle_Terror
--      ["Heavy Cannfantry"] = "", -- A_Classic_Fairytale:united
      ["Heavy"] = "Тяжёлый",
--      ["Heckles"] = "", -- 
--      ["Heck, you even executed one of your own!"] = "", -- A_Classic_Fairytale:queen
--      ["Hedge-cogs"] = "", -- A_Classic_Fairytale:enemy
--      ["HEDGEEDITOR"] = "", -- HedgeEditor
--      ["HedgeEditor tool"] = "", -- HedgeEditor
--      ["Hedgehog"] = "", -- 
--      ["Hedgehog Projectile"] = "", -- Continental_supplies
--      ["Hedgehog projectile: [Fire your hog like a Sticky Bomb]"] = "", -- Continental_supplies
--      ["Hedgehogs can not be deleted."] = "", -- HedgeEditor
--      ["Hedgehogs left: %d"] = "", -- User_Mission_-_That_Sinking_Feeling
--      ["Hedgehogs will be revived after their death."] = "", -- Mutant
--      ["Hedgehogs will start in the first waypoint."] = "", -- Racer
--      ["Hedgibal Lecter"] = "", -- A_Classic_Fairytale:backstab
--      ["He doesn't know it but this device is a part of the anti-gravity device."] = "", -- A_Space_Adventure:ice01
      ["He has captured the rest of the PAotH team and awaits to capture you!"] = "Он захватил остатки команды ПАЕ и собирается захватить тебя!", -- A_Space_Adventure:moon01
      ["Heh, it's not that bad."] = "Хех, не так уж всё и плохо.",
--      ["Height over time"] = "", -- ClimbHome
--      ["He is a very tough and very determined hedgehog. I would be extremely careful if I were you."] = "", -- A_Space_Adventure:moon02
--      ["Helena"] = "", -- A_Space_Adventure:moon01
      ["Hell Army"] = "Армия Ада", -- portal
--      ["Hello again, %s!"] = "", -- A_Classic_Fairytale:family
--      ["Help Disabled"] = "", -- HedgeEditor
--      ["Help Enabled"] = "", -- HedgeEditor
--      ["Helpers: Each team starts with %d helper points"] = "", -- Battalion
--      ["Helpers: Hogs will get 1 out of 2 helpers randomly each turn"] = "", -- Battalion
--      ["Help me, Leaks!"] = "", -- A_Classic_Fairytale:journey
--      ["Help me, please!!!"] = "", -- A_Classic_Fairytale:journey
--      ["Help me, please!"] = "", -- A_Classic_Fairytale:journey
--      ["He moves like an eagle in the sky."] = "", -- A_Classic_Fairytale:first_blood
--      ["He must be in the village already."] = "", -- A_Classic_Fairytale:journey
--      ["HeneK"] = "", -- 
--      ["Here, let me help you!"] = "", -- A_Classic_Fairytale:backstab
--      ["Here, let me help you save her!"] = "", -- A_Classic_Fairytale:family
--      ["Here...pick your weapon!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Here! Take it!"] = "", -- A_Space_Adventure:ice01
--      ["Here we go!"] = "", -- A_Space_Adventure:moon01
--      ["Here you will find the current mission instructions."] = "", -- Basic_Training_-_Movement
--      ["Here you will learn how to fly the flying saucer|and get so learn some cool tricks."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Heroic Wind"] = "", -- Continental_supplies
--      ["He's so brave..."] = "", -- A_Classic_Fairytale:first_blood
--      ["He was the lab assistant of Dr. Goodhogan, the inventor of the anti-gravity device."] = "", -- A_Space_Adventure:moon02
--      ["He won't be selling us out anymore!"] = "", -- A_Classic_Fairytale:backstab
--      ["Hey, don't forget us! We still need to climb up!"] = "", -- A_Classic_Fairytale:family
--      ["Hey, guys!"] = "", -- A_Classic_Fairytale:backstab
--      ["Hey guys!"] = "", -- A_Classic_Fairytale:united
--      ["Hey! I was supposed to collect it!"] = "", -- A_Space_Adventure:fruit02
--      ["Hey, %s! Finally you have come!"] = "", -- A_Space_Adventure:moon01
--      ["Hey, %s! Look, someone is stealing the saucer!"] = "", -- A_Space_Adventure:cosmos
--      ["Hey! This is cheating!"] = "", -- A_Classic_Fairytale:journey
--      ["Hidden"] = "", -- portal
--      ["High Gravity: Gravity is %i%%"] = "", -- Gravity
--      ["High Jump: [Backspace]"] = "", -- Basic_Training_-_Movement
--      ["High Jump: Tap the [Curvy Arrow] shortly"] = "", -- Basic_Training_-_Movement
--      ["--- Highland ---"] = "", -- Battalion
--      ["Highlander: Eliminate hogs to take their weapons"] = "", -- Highlander
--      ["Highland: Hogs get %d random weapons from their pool"] = "", -- Battalion
--      ["--- Highland Mode ---"] = "", -- Battalion
--      ["High Target"] = "", -- Basic_Training_-_Bazooka
--      ["Hightime"] = "", -- A_Classic_Fairytale:first_blood
--      ["Hightower"] = "", -- 
--      ["Hill Guard"] = "", -- Bazooka_Battlefield
--      ["Hi! Nice to meet you."] = "", -- A_Space_Adventure:ice01
--      ["--- Hint ---"] = "", -- Battalion
--      ["Hint: Cinematics can be skipped with the [Precise] key."] = "", -- A_Classic_Fairytale:first_blood, A_Classic_Fairytale:shadow
--      ["Hint: Drilling holes should solve everything."] = "", -- A_Classic_Fairytale:family
--      ["Hint: Hold down [M] to review the mission texts."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: If this mission panel disappears, you can|see it again by hitting the Pause or Quit key."] = "", -- Basic_Training_-_Movement
--      ["Hint: It might be a good idea to place a girder before starting to drill. Just saying."] = "", -- A_Classic_Fairytale:family
--      ["Hint: It might be easier if you vary the angle only slightly."] = "", -- Basic_Training_-_Bazooka
--      ["Hint: Just select the parachute, it opens automatically when you fall."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: Kills won't transfer a hog's pool to the killer's pool"] = "", -- Battalion
      ["Hint: Launch the bazooka horizontally at full power."] = "Подсказка: Выстрелите из базуки горизонтально на полной мощности.", -- Basic_Training_-_Bazooka
--      ["Hint: Pause the game to review the mission texts."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: Select the blow torch, aim and press [Fire]. Press [Fire] again to stop."] = "", -- A_Classic_Fairytale:journey
      ["Hint: Select the low gravity and press [Fire]."] = "Подсказка: Активируйте низкую гравитацию и нажмите [Огонь].", -- A_Classic_Fairytale:journey
--      ["Hint: Select the rope, [Up] or [Down] to aim, [Attack] to fire, directional keys to move."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: Select the Shoryuken and hit [Attack].|P.S.: You can use it mid-air."] = "", -- A_Classic_Fairytale:first_blood
--      ["Hint: %s needs to get really close to the princess!"] = "", -- A_Classic_Fairytale:family
--      ["Hint: The rope only bends around objects.|When it doesn't hit anything, it's always straight."] = "", -- Basic_Training_-_Rope
--      ["Hint: To jump higher, wait a bit before you hit “High Jump” a second time."] = "", -- Basic_Training_-_Movement
--      ["Hint: To place a girder, select it,|then use [Left] and [Right] to select angle and length,|then choose a location for the girder."] = "", -- A_Classic_Fairytale:shadow
--      ["Hint: Use the quit key to see the team’s continent."] = "", -- Continental_supplies
--      ["Hint: When you shorten the rope, you move faster!|And when you lengthen it, you move slower."] = "", -- Basic_Training_-_Rope
--      ["Hint: you might want to stay out of sight and take all the crates...|"] = "", -- A_Classic_Fairytale:journey
--      ["Hint: You might want to stay out of sight and take all the crates ..."] = "", -- A_Classic_Fairytale:journey
--      ["His arms are so strong!"] = "", -- A_Classic_Fairytale:first_blood
      ["hits"] = "попаданий", -- Basic_Training_-_Bazooka
--      ["Hit the “Switch Hedgehog” key until you have|selected Cappy, the hedgehog with the cap!"] = "", -- Basic_Training_-_Movement
--      ["Hmm … it's going slower than expected."] = "", -- A_Classic_Fairytale:queen
--      ["Hmmm...actually...I didn't either."] = "", -- A_Classic_Fairytale:enemy
      ["Hmmm, I’ll have to find some way of moving him off this anti-portal surface."] = "Хммм, я должен найти способ сдвинуть его с этого антипортального покрытия.", -- portal
      ["Hmmm...it's a draw. How unfortunate!"] = "Хммм...Это ничья. Какая неудача!", -- A_Classic_Fairytale:enemy
--      ["Hmmm...perhaps a little more time will help."] = "", -- A_Classic_Fairytale:first_blood
      ["Hmmm..."] = "Хммм...",
      ["Hm ... Now I ran out of fuel."] = "Хм... У меня закончилось топливо.", -- A_Space_Adventure:cosmos
--      ["Hog 100"] = "", -- A_Space_Adventure:fruit03
--      ["Hog 1"] = "", -- A_Space_Adventure:fruit03
--      ["Hog 3x5"] = "", -- A_Space_Adventure:fruit03
--      ["Hog 7+7"] = "", -- A_Space_Adventure:fruit03
--      ["Hog D"] = "", -- A_Space_Adventure:fruit03
--      ["Hog decar"] = "", -- A_Space_Adventure:fruit03
--      ["Hog dertien"] = "", -- A_Space_Adventure:fruit03
--      ["Hog %d"] = "", -- SimpleMission
--      ["Hog EOF"] = "", -- A_Space_Adventure:fruit03
--      ["Hogera is definitely the last planet I saved!"] = "", -- A_Space_Adventure:final
--      ["Hogera is safe!"] = "", -- A_Space_Adventure:final
--      ["Hog exi"] = "", -- A_Space_Adventure:fruit03
--      ["Hog Hephaestus"] = "", -- A_Space_Adventure:fruit03
--      ["Hog Identity Mode"] = "", -- HedgeEditor
--      ["HOG IDENTITY MODE"] = "", -- HedgeEditor
--      ["Hog III"] = "", -- A_Space_Adventure:fruit03
--      ["Hogminator"] = "", -- A_Classic_Fairytale:family
--      ["Hog nueve"] = "", -- A_Space_Adventure:fruit03
--      ["Hog octo"] = "", -- A_Space_Adventure:fruit03
--      ["Hog onze"] = "", -- A_Space_Adventure:fruit03
--      ["Hog Saturn"] = "", -- A_Space_Adventure:fruit03
--      ["Hogs in sight!"] = "", -- Continental_supplies
--      ["Hog Solo and GB"] = "", -- A_Space_Adventure:fruit02
--      ["Hog Solo"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:death01, A_Space_Adventure:death02, A_Space_Adventure:desert01, A_Space_Adventure:desert02, A_Space_Adventure:desert03, A_Space_Adventure:final, A_Space_Adventure:fruit01, A_Space_Adventure:fruit02, A_Space_Adventure:fruit03, A_Space_Adventure:ice01, A_Space_Adventure:ice02, A_Space_Adventure:moon01, A_Space_Adventure:moon02
--      ["- Hogs will be revived"] = "", -- Capture_the_Flag
--      ["- Hogs will drop the flag when killed"] = "", -- Capture_the_Flag
--      ["Hog two"] = "", -- A_Space_Adventure:fruit03
--      ["Hold [Attack] to attach the rope."] = "", -- Basic_Training_-_Rope
--      ["Hold the Attack key pressed for more power."] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["Holy shit!"] = "", -- Mutant
      ["Homing Bee"] = "Пчёлка", -- Construction_Mode
--      ["Honda"] = "", -- 
--      ["Honest Lee"] = "", -- A_Classic_Fairytale:enemy
--      ["Hooks"] = "", -- 
--      ["Hooray! I actually did it! Hogera is safe!"] = "", -- A_Space_Adventure:final
--      ["Hooray! I've found it, now I have to get back to Captain Lime!"] = "", -- A_Space_Adventure:fruit02
--      ["Hooray! You are a champion!"] = "", -- A_Space_Adventure:ice02
      ["Hopeless case"] = "Безнадежный случай", -- User_Mission_-_RCPlane_Challenge
--      ["Hop on top of the next flower and advance to the left coast."] = "", -- A_Classic_Fairytale:journey
--      ["Horns"] = "", -- 
--      ["Hostage Situation"] = "", -- A_Classic_Fairytale:family
--      ["How can I ever repay you for saving my life?"] = "", -- A_Classic_Fairytale:journey
--      ["How come in a village full of warriors, it's up to me to save it?"] = "", -- A_Classic_Fairytale:dragon
--      ["How could you betray us?"] = "", -- A_Classic_Fairytale:queen
--      ["How difficult would you like it to be?"] = "", -- A_Classic_Fairytale:first_blood
--      ["HOW DO THEY KNOW WHERE WE ARE?"] = "", -- A_Classic_Fairytale:united
--      ["However, if you fail to do so, she dies a most violent death, just like your friend! Muahahaha!"] = "", -- A_Classic_Fairytale:journey
--      ["However, if you fail to do so, she dies a most violent death! Muahahaha!"] = "", -- A_Classic_Fairytale:journey
--      ["However, my mates don't agree with me on letting you go..."] = "", -- A_Classic_Fairytale:dragon
--      ["However, the army of %s is about to attack any moment now."] = "", -- A_Space_Adventure:fruit01
--      ["How to Rope"] = "", -- Basic_Training_-_Rope
--      ["How would you like being discriminated against?"] = "", -- A_Classic_Fairytale:queen
--      ["Huh?"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:queen
      ["Hunter"] = "Охотник", --Bazooka, Shotgun, SniperRifle
--      ["I ain't gonna sit around no more!"] = "", -- A_Classic_Fairytale:queen
--      ["I already said I'm sorry!"] = "", -- A_Classic_Fairytale:epil
--      ["I always suspected him!"] = "", -- A_Classic_Fairytale:epil
--      ["I am going to leave the kids play by themselves."] = "", -- A_Classic_Fairytale:queen
--      ["I am not ready for this planet yet. I should visit it when I have found all the other device parts."] = "", -- A_Space_Adventure:cosmos
--      ["I am sorry but I was looking for a device that may be hidden somewhere around here."] = "", -- A_Space_Adventure:fruit02
--      ["I believe there's more of them."] = "", -- A_Classic_Fairytale:backstab
--      ["I cannot let you go any further! … burp …"] = "", -- A_Classic_Fairytale:queen
--      ["I can see you have been training diligently."] = "", -- A_Classic_Fairytale:first_blood
--      ["I can't believe how blind we were."] = "", -- A_Classic_Fairytale:epil
--      ["I can't believe it worked!"] = "", -- A_Classic_Fairytale:shadow
--      ["I can't believe this!"] = "", -- A_Classic_Fairytale:enemy
--      ["I can't believe what I'm hearing!"] = "", -- A_Classic_Fairytale:backstab
--      ["I can't let you go further because …"] = "", -- A_Classic_Fairytale:queen
--      ["I can't wait any more, I have to save myself!"] = "", -- A_Classic_Fairytale:shadow
--      ["Ice Jake"] = "", -- A_Space_Adventure:ice01
--      ["I could just teleport myself there..."] = "", -- A_Classic_Fairytale:family
--      ["Icy Girder: [3]"] = "", -- HedgeEditor
--      ["Icy Land: [3]"] = "", -- HedgeEditor
--      ["Icy Land"] = "", -- HedgeEditor
--      ["I'd better get going myself."] = "", -- A_Classic_Fairytale:journey
--      ["Identity Thief"] = "", -- Mutant
--      ["I didn't until about a month ago."] = "", -- A_Classic_Fairytale:enemy
--      ["I don't care. It's worth a fortune! Good bye, you idiot!"] = "", -- A_Space_Adventure:fruit02
--      ["I don't know how you did that. But good work!|The next one should be easy as cake for you!"] = "", -- Basic_Training_-_Rope
--      ["I don't know if I can forget what you've done!"] = "", -- A_Classic_Fairytale:epil
--      ["I don't know who I can trust anymore."] = "", -- A_Classic_Fairytale:epil
--      ["I don't like your tone! You're hurting me!"] = "", -- A_Classic_Fairytale:queen
--      ["I feel something...a place! They will arrive near the circles!"] = "", -- A_Classic_Fairytale:backstab
--      ["If only I had a way..."] = "", -- A_Classic_Fairytale:backstab
--      ["If only I were given a chance to explain my being here..."] = "", -- A_Classic_Fairytale:first_blood
--      ["If only one enemy is left, you'll get bonus ammo."] = "", -- A_Space_Adventure:death02
--      ["I forgot that she's the daughter of the chief, too..."] = "", -- A_Classic_Fairytale:backstab
--      ["I found it! Hooray!"] = "", -- A_Space_Adventure:desert01
--      ["If some good old explosives were enough to save Hogera …"] = "", -- A_Space_Adventure:final
--      ["If they try coming here, they can have a taste of my delicious knuckles!"] = "", -- A_Classic_Fairytale:united
--      ["If you agree to provide the information we need, you will be spared!"] = "", -- A_Classic_Fairytale:shadow
--      ["If you can get that crate fast enough, your beloved \"princess\" may go free."] = "", -- A_Classic_Fairytale:journey
--      ["If you decide to help us, though, we will no longer need to find a new governor for the island."] = "", -- A_Classic_Fairytale:shadow
--      ["If you don't want to slip away, you have to keep moving!"] = "", -- Basic_Training_-_Movement
--      ["If you get stuck, use your Desert Eagle or restart the mission!"] = "", -- A_Classic_Fairytale:journey
--      ["If you get stuck, use your Desert Eagle or restart the mission!|"] = "", -- A_Classic_Fairytale:journey
--      ["If you help us you can keep the device if you find it but we'll keep everything else."] = "", -- A_Space_Adventure:fruit02
--      ["If you hurt an enemy, you'll get one third of the damage dealt."] = "", -- A_Space_Adventure:death02
--      ["If you injure a hedgehog you'll get 35% of the damage dealt."] = "", -- A_Space_Adventure:death02
--      ["If you just don’t care …"] = "", -- Continental_supplies
--      ["If you kill a hedgehog with the respective weapon your health points will be set to 100."] = "", -- A_Space_Adventure:death02
--      ["If you kill an enemy, your health will be set to 100."] = "", -- A_Space_Adventure:death02
--      ["If you know what I mean..."] = "", -- A_Classic_Fairytale:shadow
--      ["If you miss a shot while trying to|re-attach, your rope is gone, too!"] = "", -- Basic_Training_-_Rope
--      ["If you say so..."] = "", -- A_Classic_Fairytale:shadow
--      ["If you skip a turn then the turn time left will be added to your next turn."] = "", -- A_Space_Adventure:fruit03
--      ["If you wish to replay, there are other possible endings, too!"] = "", -- A_Classic_Fairytale:epil
      ["Igmund"] = "Джокер", -- User_Mission_-_Nobody_Laugh
--      ["I grew sick of the oppression! I broke free!"] = "", -- A_Classic_Fairytale:queen
      ["I guess I can't go far without fuel!"] = "Я полагаю, что не улечу далеко без топлива!", -- A_Space_Adventure:cosmos
      ["I guess we lost him!"] = "Я полагаю, мы потеряли его!", -- A_Space_Adventure:cosmos
      ["I guess you'll have to kill them."] = "Я полагаю, ты должен убить их.", -- A_Classic_Fairytale:dragon
      ["I have come to make you an offering..."] = "Я пришёл, чтобы сделать тебе предложение...", -- A_Classic_Fairytale:shadow
      ["I have heard that the local tribes say that many years ago some PAotH scientists were dumping their waste here."] = "Я слышал, как местные племена говорили, что давным давно учёные из ПАЕ сбрасывали сюда свои отходы.", -- A_Space_Adventure:desert01
      ["I have more important things to do!"] = "У меня есть более важные дела!", -- A_Classic_Fairytale:queen
      ["I have no idea where that mole disappeared...Can you see it?"] = "Я не понимаю, куда делся этот крот...Ты его видишь?", -- A_Classic_Fairytale:shadow
--      ["I have only 3 hogs available and they are all cadets."] = "", -- A_Space_Adventure:fruit01
      ["I have to follow that alien."] = "Я должен следовать за этим инопланетянином.", -- A_Classic_Fairytale:backstab
      ["I have to get back to the village!"] = "Я должен вернуться обратно в деревню!", -- A_Classic_Fairytale:shadow
--      ["I have to reach the surface as quickly as I can."] = "", -- A_Space_Adventure:desert02
      ["I hope you are prepared for a small challenge, young one."] = "Я надеюсь ты подготовился к небольшому испытанию, юнец.", -- A_Classic_Fairytale:first_blood
--      ["I just don't want to sink to your level."] = "", -- A_Classic_Fairytale:backstab
--      ["I just forgot all checkpoints of incomplete missions."] = "", -- A_Space_Adventure:cosmos
--      ["I just found out that they have captured your princess!"] = "", -- A_Classic_Fairytale:family
--      ["I just want the strange device you found!"] = "", -- A_Space_Adventure:ice01
--      ["I just wonder where Ramon and Spiky disappeared..."] = "", -- A_Classic_Fairytale:journey
      ["I know and I'm terribly sorry!"] = "Я знаю и мне ужасно жаль!", -- A_Classic_Fairytale:epil
--      ["I know, my hero!"] = "", -- A_Classic_Fairytale:epil
--      ["I know that your resources are low due to the battle but I'll send two of my best hogs to assist you."] = "", -- A_Space_Adventure:fruit02
--      ["I … like being with you, too."] = "", -- A_Classic_Fairytale:epil
--      ["I'll get him!"] = "", -- A_Space_Adventure:cosmos
--      ["I'll hold them off while you return to the village!"] = "", -- A_Classic_Fairytale:shadow
--      ["I'll let you know whatever I know about him if you manage to catch me 3 times."] = "", -- A_Space_Adventure:moon02
--      ["I'll make good use of it."] = "", -- A_Space_Adventure:cosmos
      ["I'll protect you!"] = "Я буду защищать тебя!", -- A_Classic_Fairytale:epil
--      ["I love Dense Cloud now!"] = "", -- A_Classic_Fairytale:epil
      ["I love you."] = "Я люблю тебя.", -- A_Classic_Fairytale:epil
--      ["I'm afraid I can't let you proceed!"] = "", -- A_Classic_Fairytale:queen
      ["I'm afraid we cannot afford that."] = "Я боюсь мы не можем себе этого позволить.", -- A_Classic_Fairytale:queen
--      ["Imagine those targets are the wolves that killed your parents! Take your anger out on them!"] = "", -- A_Classic_Fairytale:first_blood
--      ["I'm...alive? How? Why?"] = "", -- A_Classic_Fairytale:backstab
      ["I'm a ninja."] = "Я ниньзя.", -- A_Classic_Fairytale:dragon
--      ["I marked the place of their arrival. You're welcome!"] = "", -- A_Classic_Fairytale:backstab
      ["I may lost this battle, but I haven't lost the war yet!"] = "Может я и проиграл эту битву, но я не проиграл войну!", -- A_Space_Adventure:moon01
--      ["I'm certain that this is a misunderstanding, fellow hedgehogs!"] = "", -- A_Classic_Fairytale:first_blood
--      ["I mean, none of you ceased to live."] = "", -- A_Classic_Fairytale:enemy
      ["I'm getting old for this!"] = "Я становлюсь старым для этого!", -- A_Classic_Fairytale:family
--      ["I'm getting thirsty..."] = "", -- A_Classic_Fairytale:family
      ["I'm glad this is over!"] = "Я рад, что это закончилось!", -- A_Classic_Fairytale:epil
      ["I'm here to help you rescue her."] = "Я здесь, чтобы помочь тебе спасти её.", -- A_Classic_Fairytale:family
--      ["I'm living a dream!"] = "", -- A_Classic_Fairytale:queen
      ["I'm not sure about that!"] = "Я не уверен насчёт этого!", -- A_Classic_Fairytale:united
--      ["IMPORTANT: To see the mission panel again, hold the mission panel key."] = "", -- Basic_Training_-_Movement
--      ["IMPORTANT: To see the mission panel again, pause the game."] = "", -- Basic_Training_-_Movement
--      ["Impressive...you are still dry as the corpse of a hawk after a week in the desert..."] = "", -- A_Classic_Fairytale:first_blood
--      ["%i ms"] = "", -- Gravity
      ["I'm so glad this is finally over!"] = "Я так рад, что это наконец-то закончилось!", -- A_Space_Adventure:final
      ["I'm so scared!"] = "Мне так страшно!", -- A_Classic_Fairytale:united
--      ["I'm still low on hogs. If you are not afraid I could use a set of extra hands."] = "", -- A_Space_Adventure:fruit02
--      ["I'm still with the aliens."] = "", -- A_Classic_Fairytale:queen
      ["I'm terribly sorry!"] = "Мне ужасно жаль!", -- A_Classic_Fairytale:queen
--      ["I'm the spy! I've been giving you out!"] = "", -- A_Classic_Fairytale:queen
--      ["In am also entrusting you with some rope."] = "", -- A_Space_Adventure:cosmos
--      ["In case you haven't noticed, I'm a woman, too!"] = "", -- A_Classic_Fairytale:queen
--      ["Increase the dust storm damage by sacrificing|your invulnerable ammo."] = "", -- Continental_supplies
      ["Incredible..."] = "Невероятно...", -- A_Classic_Fairytale:shadow
--      ["Indestructible Girder: [2]"] = "", -- HedgeEditor
--      ["Indestructible Land: [2]"] = "", -- HedgeEditor
--      ["Indestructible Land"] = "", -- HedgeEditor
      ["In each round, the worst hedgehog of the round is eliminated."] = "В каждом раунде худший ёжик будет уничтожен.", -- TrophyRace
      ["I need to find the others!"] = "Я должен найти других!", -- A_Classic_Fairytale:backstab
--      ["I need to get to the other side of this island, fast!"] = "", -- A_Classic_Fairytale:journey
--      ["I need to move the tribe!"] = "", -- A_Classic_Fairytale:united
--      ["I need to prevent their arrival!"] = "", -- A_Classic_Fairytale:backstab
--      ["I need to warn the others."] = "", -- A_Classic_Fairytale:backstab
--      ["In fact, you are the only one that's been acting strangely."] = "", -- A_Classic_Fairytale:backstab
--      ["Initial health: %d"] = "", -- Continental_supplies
--      ["Initiate escape wish!"] = "", -- A_Classic_Fairytale:queen
--      ["In order to get to the other side, you need to get rid of the crates first."] = "", -- A_Classic_Fairytale:dragon
--      ["Insanity!"] = "", -- Mutant
--      ["Inside %d"] = "", -- WxW
--      ["Inside"] = "", -- WxW
--      ["Instructions"] = "", -- Basic_Training_-_Flying_Saucer
      ["Instructor"] = "Инструктор", -- 01#Boot_Camp, User_Mission_-_Dangerous_Ducklings
      ["Insufficient Power"] = "Недостаточно Энергии", -- Construction_Mode
--      ["Interesting idea, haha!"] = "", -- A_Classic_Fairytale:enemy
--      ["Interesting! Last time you said you killed a cannibal!"] = "", -- A_Classic_Fairytale:backstab
--      ["In the Ice Planet Flying Saucer Stadium ..."] = "", -- A_Space_Adventure:ice02
--      ["In the meantime, take these and return to your \"friend\"!"] = "", -- A_Classic_Fairytale:shadow
--      ["In the stadium, where the best pilots compete ..."] = "", -- A_Space_Adventure:ice02
--      ["In this accident, Professor Hogevil lost all his spines on his head!"] = "", -- A_Space_Adventure:moon02
--      ["In this mission you get %d%% fuel."] = "", -- User_Mission_-_Diver
--      ["In this mission you have infinite time."] = "", -- portal
      ["Invalid Placement"] = "Неверное Размещение", -- Construction_Mode
--      ["Invasion"] = "", -- A_Classic_Fairytale:united
      ["In your best (and only) flight you took out %d crates with one RC plane!"] = "В вашем лучшем (и единственном) полёте вы достали %d ящиков с одним самолётом.", -- User_Mission_-_RCPlane_Challenge
      ["In your best flight you took out %d crates with one RC plane."] = "В вашем лучшем полёте вы достали %d ящиков с одним самолётом.", -- User_Mission_-_RCPlane_Challenge
--      ["I regret to end your little odyssey."] = "", -- A_Classic_Fairytale:queen
--      ["I saw it with my own eyes!"] = "", -- A_Classic_Fairytale:shadow
--      ["I see..."] = "", -- A_Classic_Fairytale:shadow
--      ["I see you already took care of your enemies."] = "", -- A_Classic_Fairytale:dragon
--      ["I see you have already taken the leap of faith."] = "", -- A_Classic_Fairytale:first_blood
--      ["I see you would like his punishment to be more...personal..."] = "", -- A_Classic_Fairytale:first_blood
--      ["I sense another wave of cannibals heading my way!"] = "", -- A_Classic_Fairytale:backstab
--      ["I sense another wave of cannibals heading our way!"] = "", -- A_Classic_Fairytale:backstab
--      ["%i s"] = "", -- Gravity
--      ["I should get myself a portal device, maybe this crate has one."] = "", -- portal
--      ["I should go now, goodbye!"] = "", -- A_Space_Adventure:moon02
--      ["I shouldn't have drunk that last pint."] = "", -- A_Classic_Fairytale:dragon
--      ["Is this place in my head?"] = "", -- A_Classic_Fairytale:dragon
--      ["I still can't believe he sold us out like that."] = "", -- A_Classic_Fairytale:epil
--      ["I still can't believe you forgave her!"] = "", -- A_Classic_Fairytale:epil
--      ["I still have to get rid of the crates."] = "", -- A_Classic_Fairytale:dragon
--      ["Itami"] = "", -- 
--      ["It doesn't matter. I won't let that alien hurt my daughter!"] = "", -- A_Classic_Fairytale:dragon
--      ["I think I love you!"] = "", -- A_Classic_Fairytale:epil
--      ["I think we are safe here."] = "", -- A_Classic_Fairytale:backstab
--      ["I thought their shaman died when he tried our medicine!"] = "", -- A_Classic_Fairytale:shadow
--      ["It is called 'Hogs of Steel'."] = "", -- A_Classic_Fairytale:enemy
--      ["It is time to practice your fighting skills."] = "", -- A_Classic_Fairytale:first_blood
--      ["It must be a childhood trauma..."] = "", -- A_Classic_Fairytale:family
--      ["It must be the aliens!"] = "", -- A_Classic_Fairytale:backstab
--      ["It must be the aliens' deed."] = "", -- A_Classic_Fairytale:backstab
--      ["It must be the cyborgs again!"] = "", -- A_Classic_Fairytale:enemy
--      ["It needs some practice, but you have infinite lives."] = "", -- Basic_Training_-_Rope
--      ["I told you, I just found them."] = "", -- A_Classic_Fairytale:backstab
--      ["It only works in teleportation nodes of your own clan."] = "", -- Construction_Mode
     ["It's a good thing SUDDEN DEATH is 99 turns away..."] = "Хорошо, что ВНЕЗАПНАЯ СМЕРТЬ аж через 99 ходов...",
--      ["It's all about the right carrots, you know."] = "", -- A_Classic_Fairytale:epil
--      ["It's always up to women to clear up the mess men created!"] = "", -- A_Classic_Fairytale:dragon
--      ["It's amazing how quickly our lives can change."] = "", -- A_Classic_Fairytale:epil
--      ["It's an ancient ritual of theirs."] = "", -- A_Classic_Fairytale:queen
--      ["IT'S A SERIOUS MEDICAL CONDITION!"] = "", -- A_Classic_Fairytale:queen
--      ["It's a shame, I forgot how to do that!"] = "", -- A_Classic_Fairytale:family
--      ["It's a shame, really!"] = "", -- A_Classic_Fairytale:queen
--      ["It seems that Professor Hogevil has prepared for your arrival!"] = "", -- A_Space_Adventure:moon01
--      ["It's empty!"] = "", -- Battalion
--      ["It's impossible to communicate with the spirits without a shaman."] = "", -- A_Classic_Fairytale:shadow
--      ["It's not that easy, so listen carefully:"] = "", -- Basic_Training_-_Flying_Saucer
--      ["It's over..."] = "", -- A_Classic_Fairytale:shadow
--      ["It's precious to me!"] = "", -- A_Classic_Fairytale:queen
--      ["It's time you learned that your actions have consequences!"] = "", -- A_Classic_Fairytale:journey
--      ["It's worth more than wood!"] = "", -- A_Classic_Fairytale:enemy
--      ["It's your fault you're there!"] = "", -- A_Classic_Fairytale:epil
--      ["It wants our brains!"] = "", -- A_Classic_Fairytale:shadow
--      ["It was all a trick?!"] = "", -- A_Classic_Fairytale:queen
--      ["It was all just bad luck!"] = "", -- ClimbHome
--      ["It was completely useless!"] = "", -- A_Space_Adventure:final
--      ["It was fun to watch."] = "", -- A_Classic_Fairytale:queen
--      ["It was fun to watch, though."] = "", -- A_Classic_Fairytale:queen
--      ["It was not a dream, unwise one!"] = "", -- A_Classic_Fairytale:backstab
--      ["It wasn't her fault!"] = "", -- A_Classic_Fairytale:epil
--      ["It would be wiser to steal the space ship while the PAotH guards are taking a brake!"] = "", -- A_Space_Adventure:cosmos
--      ["Ivan"] = "", -- 
--      ["I've made it! Yeah!"] = "", -- A_Space_Adventure:moon01
--      ["I've seen this before. They just appear out of thin air."] = "", -- A_Classic_Fairytale:united
--      ["I've thought that the best way to get the device is to let you collect most of the parts for me!"] = "", -- A_Space_Adventure:death01
--      ["I want to play a game..."] = "", -- A_Classic_Fairytale:journey
--      ["I want to see how it handles this!"] = "", -- A_Classic_Fairytale:backstab
--      ["I was heading home, you see!"] = "", -- A_Classic_Fairytale:queen
--      ["I was so scared."] = "", -- A_Classic_Fairytale:epil
--      ["I was told that as the leader of the king's guard, no one knows this world better than you!"] = "", -- A_Space_Adventure:fruit01
--      ["I will never hand you the parts!"] = "", -- A_Space_Adventure:death01
--      ["I wish to help you, %s!"] = "", -- A_Classic_Fairytale:dragon
--      ["I wonder where Dense Cloud is..."] = "", -- A_Classic_Fairytale:journey, A_Classic_Fairytale:shadow
--      ["I wonder why I'm so angry all the time..."] = "", -- A_Classic_Fairytale:family
--      ["I won't let you kill her!"] = "", -- A_Classic_Fairytale:journey
--      ["I won't let you kill the tribe!"] = "", -- A_Classic_Fairytale:queen
--      ["I would gladly help you if we won this battle but under these circumstances I'll only help you if you fight for our side."] = "", -- A_Space_Adventure:fruit01
--      ["Jack"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Jason"] = "", -- 
--      ["Jeremiah"] = "", -- A_Classic_Fairytale:dragon
--      ["Jetpack"] = "", -- Big_Armory
--      ["Jigglypuff"] = "", -- 
--      ["Jim Morgan"] = "", -- 
--      ["Jimmy"] = "", -- 
--      ["Jingo"] = "", -- 
--      ["Joe"] = "", -- A_Space_Adventure:moon01
--      ["John"] = "", -- A_Classic_Fairytale:journey
--      ["John Snow"] = "", -- A_Space_Adventure:ice01
--      ["Jolly Roger"] = "", -- 
--      ["Jones"] = "", -- 
--      ["Judas"] = "", -- A_Classic_Fairytale:backstab
--      ["Juicy"] = "", -- 
--      ["Jumping"] = "", -- Basic_Training_-_Movement
      ["Jumping is disabled"] = "Прыжки отключены",
--      ["Just kidding, none of you have died!"] = "", -- A_Classic_Fairytale:enemy
--      ["Just look at Leaks, may he rest in peace!"] = "", -- A_Classic_Fairytale:queen
--      ["Just on a walk."] = "", -- A_Classic_Fairytale:united
--      ["Just wait till I get my hands on that trauma! ARGH!"] = "", -- A_Classic_Fairytale:family
--      ["Kaboom!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Kaboom! Hahahaha! Take this, stupid meteorite!"] = "", -- A_Space_Adventure:final
--      ["Kamikaze"] = "", -- Construction_Mode
--      ["Kamikaze Expert! +15 points!"] = "", -- Space_Invasion
      ["Keep it up!"] = "Так держать!",
--      ["Ken"] = "", -- 
--      ["Kenshi"] = "", -- 
--      ["Kerguelen"] = "", -- Continental_supplies
--      ["key."] = "", -- Continental_supplies
--      ["Kill all enemy hedgehogs in a single turn."] = "", -- Big_Armory
--      ["Kill him or skip your turn."] = "", -- A_Classic_Fairytale:backstab
--      ["Killing spree!"] = "",
--      ["Killing the specialists"] = "", -- A_Space_Adventure:death02
--      ["KILL IT!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Kills: %d"] = "", -- Space_Invasion
--      ["Kill the aliens!"] = "", -- A_Classic_Fairytale:dragon
--      ["Kill the cannibal!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Kill The Leader"] = "", -- WxW
--      ["Kill The Leader: You must also hit the team with the most health."] = "", -- WxW
--      ["Kill the traitor, %s, or spare his life!"] = "", -- A_Classic_Fairytale:backstab
--      ["--- King ---"] = "", -- Battalion
--      ["King"] = "", -- Battalion
--      ["--- King Mode ---"] = "", -- Battalion
--      ["Knight"] = "", -- Battalion
--      ["Knives"] = "", -- 
--      ["Knockball"] = "", -- Knockball
--      ["Knockball weapon"] = "", -- Knockball
--      ["Knock off the enemies from the left-most place of the map!"] = "", -- A_Space_Adventure:fruit01
--      ["koda"] = "", -- 
--      ["Kostya"] = "", -- 
--      ["Lady Mango"] = "", -- A_Space_Adventure:fruit01, A_Space_Adventure:fruit02
--      ["LandFlag Modification Mode"] = "", -- HedgeEditor
--      ["Land mines explode instantly."] = "", -- User_Mission_-_Teamwork_2
--      ["Lassard"] = "", -- 
--      ["Last Resort: Having less than 25% base health gives kamikaze"] = "", -- Battalion
      ["Last Target!"] = "Последняя цель!",
--      ["Launch a bouncy ball which explodes into a crate."] = "", -- Continental_supplies
--      ["Launch some bazookas to destroy the targets!"] = "", -- Basic_Training_-_Bazooka
--      ["Leader"] = "", -- A_Classic_Fairytale:enemy
--      ["Leaderbot"] = "", -- A_Classic_Fairytale:queen
--      ["Lead your allies to battle and eliminate all the enemies!"] = "", -- A_Space_Adventure:fruit01
--      ["Leaks A Lot"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:journey, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow, A_Classic_Fairytale:united
--      ["Leaks A Lot, depressed for killing his loved one, failed to save the village..."] = "", -- A_Classic_Fairytale:journey
--      ["Leaks A Lot gave his life for his tribe! He should have survived!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Leaks A Lot must survive!"] = "", -- A_Classic_Fairytale:journey
--      ["Leap of Faith"] = "", -- Basic_Training_-_Movement
--      ["Led Heart"] = "", -- A_Classic_Fairytale:queen
--      ["Lee"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Left and right"] = "", -- WxW
--      ["Left, right and roof"] = "", -- WxW
--      ["[Left], [Right]: Change between identities."] = "", -- HedgeEditor
--      ["[Left], [Right]: Change health value."] = "", -- HedgeEditor
--      ["Left/right: Choose crate contents"] = "", -- Construction_Mode
--      ["Left/right: Choose structure type"] = "", -- Construction_Mode
--      ["Left/right: Choose structure type|Cursor: Build structure"] = "", -- Construction_Mode
--      ["Legs"] = "", -- 
--      ["Less tools, more fun"] = "", -- Battalion
      ["Lestat"] = "Лестат", -- portal
--      ["Let a continent provide your weapons!"] = "", -- Continental_supplies
--      ["Let me test your skills a little, will you?"] = "", -- A_Classic_Fairytale:journey
--      ["Let's get started!"] = "", -- Basic_Training_-_Bazooka
--      ["Let's go!"] = "", -- A_Space_Adventure:moon02
--      ["Let's go home!"] = "", -- A_Classic_Fairytale:journey
--      ["Let's go, %s!"] = "", -- WxW
--      ["Let's head back to the village!"] = "", -- A_Classic_Fairytale:shadow
--      ["Let's see what your comrade does now!"] = "", -- A_Classic_Fairytale:journey
--      ["Let's show those cannibals what we're made of!"] = "", -- A_Classic_Fairytale:backstab
--      ["Let them have a taste of my fury!"] = "", -- A_Classic_Fairytale:backstab
--      ["Let us help, too!"] = "", -- A_Classic_Fairytale:backstab
--      ["Level 1 clear!"] = "", -- A_Space_Adventure:desert03
--      ["Level 2 clear!"] = "", -- A_Space_Adventure:desert03
--      ["Level Data Saved!"] = "", -- HedgeEditor
--      ["Lightbender"] = "", -- 
--      ["Light Cannfantry"] = "", -- A_Classic_Fairytale:united
--      ["Limited Ammo"] = "", -- Basic_Training_-_Bazooka
--      ["Listen carefully! The bandit leader, Thanta, has recently found a very strange device."] = "", -- A_Space_Adventure:ice01
--      ["Listen up, maggot!"] = "", -- User_Mission_-_Dangerous_Ducklings
      ["Listen up, maggot!!"] = "Слушай сюда, щегол!!",
--      ["Little did they know that this hunt will mark them forever..."] = "", -- A_Classic_Fairytale:shadow
--      ["Little Obstacle Course"] = "", -- Basic_Training_-_Rope
--      ["Lively Lifeguard"] = "",
--      ["Lonely Cries"] = "", -- Continental_supplies
--      ["Lonely Cries: [Rise the water if no hog is in the circle and deal 6 damage to all enemy hogs.]"] = "", -- Continental_supplies
--      ["Long Jump: [Enter]"] = "", -- Basic_Training_-_Movement
--      ["Long Jump: Tap the [Curvy Arrow] button for long"] = "", -- Basic_Training_-_Movement, A_Classic_Fairytale:first_blood
--      ["Long Live The Queen"] = "", -- A_Classic_Fairytale:queen
--      ["Look around: [Mouse movement]"] = "", -- Basic_Training_-_Movement
--      ["Look around: [Tap or swipe on the screen]"] = "", -- Basic_Training_-_Movement
--      ["Look, boss! There is the target!"] = "", -- A_Space_Adventure:moon01
--      ["Look, I had no choice!"] = "", -- A_Classic_Fairytale:backstab
--      ["Look out! There's more of them!"] = "", -- A_Classic_Fairytale:backstab
--      ["Look out! We're surrounded by cannibals!"] = "", -- A_Classic_Fairytale:enemy
--      ["Looks like the whole world is falling apart!"] = "", -- A_Classic_Fairytale:enemy
--      ["Look to the left and do a backwards jump towards the mushroom."] = "", -- A_Classic_Fairytale:first_blood
      ["Loon"] = "Псих", -- The_Specialists
--      ["Loopy"] = "", -- 
--      ["Losing Condition: Destroy"] = "", -- HedgeEditor
--      ["Low Gravity: Gravity is %i%%"] = "", -- Gravity
--      ["Loyal Highlander: Eliminate enemy hogs to take their weapons"] = "", -- Highlander
--      ["Lt. Luke"] = "", -- 
      ["Lucifer"] = "Люцифер", -- portal
--      ["Luck: %d%% (modifier for crates)"] = "", -- Battalion
--      ["Luckily, I've managed to snatch some of them."] = "", -- A_Classic_Fairytale:united
--      ["Ludicrous kill!"] = "", -- Mutant
--      ["Lugia"] = "", -- 
--      ["Luigi"] = "", -- 
--      ["Made it!"] = "", -- ClimbHome
--      ["Mahoney"] = "", -- 
--      ["Make fun of me when I fart …"] = "", -- A_Classic_Fairytale:queen
--      ["Manual: https://hedgewars.org/hedgeeditor"] = "", -- HedgeEditor
--      ["Many long forgotten things can be found in the same tunnels that we are about to explore!"] = "", -- A_Space_Adventure:fruit02
--      ["Many meters below the surface ..."] = "", -- A_Space_Adventure:desert02
--      ["Mario"] = "", -- 
--      ["Mark gears for win/lose conditions"] = "", -- HedgeEditor
--      ["Mark/unmark gear: [Left Click]"] = "", -- HedgeEditor
--      ["- Massive weapon bonus on first turn"] = "", -- Continental_supplies
--      ["Max Citrus"] = "", -- A_Space_Adventure:fruit01
--      ["Maybe you should try an easier map next time."] = "", -- Racer
--      ["Maybe you should try an easier TechRacer map."] = "", -- TechRacer
--      ["Maybe you should try easier waypoints next time."] = "", -- Racer
--      ["May the spirits aid you in all your quests!"] = "", -- A_Classic_Fairytale:backstab
--      ["Meals"] = "", -- 
--      ["Medic"] = "", -- Battalion
--      ["Medicine"] = "", -- Continental_supplies
--      ["Medicine: [Fire some exploding medicine that will heal all hogs effected by the explosion]"] = "", -- Continental_supplies
--      ["MEDIUM"] = "", -- Continental_supplies
--      ["Mega kill!"] = "", -- Mutant
--      ["Meiwes"] = "", -- A_Classic_Fairytale:backstab
--      ["mikade"] = "", -- 
--      ["Mindy"] = "", -- A_Classic_Fairytale:united
--      ["Mine Deployer"] = "",
--      ["MINE PLACEMENT MODE"] = "", -- HedgeEditor
      ["Mine Placement Mode"] = "Режим Размещения Мин", -- Construction_Mode
--      ["Mines explode after %d s."] = "", -- Mutant
--      ["Mines time: 0s-5s"] = "", -- SimpleMission
--      ["Mines time: 0 seconds"] = "", -- portal, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork, User_Mission_-_The_Great_Escape, A_Space_Adventure:desert01, A_Space_Adventure:final, A_Space_Adventure:fruit02, A_Space_Adventure:ice01
--      ["Mines time: 1.5 seconds"] = "", -- A_Space_Adventure:death01
--      ["Mines time: %.1fs"] = "", -- SimpleMission
--      ["Mines time: 1 second"] = "", -- User_Mission_-_Diver, User_Mission_-_Newton_and_the_Hammock, A_Space_Adventure:desert02
--      ["Mines time: %.2fs"] = "", -- SimpleMission
--      ["Mines time: 3 seconds"] = "", -- A_Classic_Fairytale:journey
--      ["Mines time: 5 seconds"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:journey
--      ["Mines time: %ds"] = "", -- SimpleMission
--      ["Mine Strike"] = "", -- Construction_Mode
--      ["Minion"] = "", -- A_Space_Adventure:moon01
--      ["Minions"] = "", -- A_Space_Adventure:moon01
--      ["Mission failed!"] = "", -- Big_Armory
--      ["Mission failure in %d s"] = "", -- Big_Armory
--      ["Mission"] = "", -- HedgeEditor
      ["Mission lost!"] = "Миссия провалена!", -- Basic_Training_-_Grenade
--      ["Mission Panel"] = "", -- Basic_Training_-_Movement
--      ["Mission panel: [M]"] = "", -- Basic_Training_-_Movement
--      ["Mission succeeded!"] = "", -- portal, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork_2, User_Mission_-_Teamwork, SimpleMission, HedgeEditor
      ["Mission won!"] = "Миссия успешна!", -- Basic_Training_-_Grenade
--      ["Mister Pear"] = "", -- A_Space_Adventure:fruit01, A_Space_Adventure:fruit02
--      ["Mixed %d"] = "", -- WxW
--      ["Mixed"] = "", -- WxW
--      ["Modes: Activate “highland”, “king” or “points” mode by putting mode=<name>|into the script parameter"] = "", -- Battalion
--      ["Modifiers: Unlimited ammo, per-hog ammo"] = "", -- Battalion
--      ["Modifiers: Unlimited ammo, shared clan ammo"] = "", -- Battalion
--      ["Modifiers: Unlimited attacks, per-hog ammo"] = "", -- Battalion
--      ["Modifiers: Unlimited attacks, shared clan ammo"] = "", -- Battalion
--      ["Modify Sprite under Cursor: [Left Click]"] = "", -- HedgeEditor
--      ["Molly"] = "", -- 
--      ["Molotov"] = "", -- Continental_supplies
--      ["Monster kill!"] = "", -- Mutant
--      ["Monsters"] = "", -- 
--      ["Mooney"] = "", -- 
--      ["Morris"] = "", -- 
--      ["Most mines are not active."] = "", -- A_Space_Adventure:desert02
--      ["Most of the destructible terrain in marked with blue color"] = "", -- A_Space_Adventure:desert01
--      ["Most of the destructible terrain is marked with dashed lines."] = "", -- A_Space_Adventure:desert01
--      ["Most of the time you'll be able to use the freezer only."] = "", -- A_Space_Adventure:ice01
--      ["Movement: [Up], [Down], [Left], [Right]"] = "",
--      ["Mr Mango"] = "", -- A_Space_Adventure:fruit01
--      ["Mudkip"] = "", -- 
--      ["Multi-shot! +15 points!"] = "", -- Space_Invasion
--      ["Multi-Use: You can take and use the same ammo type multiple times in a turn"] = "", -- Highlander
--      ["Muriel"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Muscle Dissolver"] = "", -- A_Classic_Fairytale:shadow
--      ["Mushroom Kingdom"] = "", -- 
      ["Mutant"] = "Мутант", -- Mutant
--      ["My First Bazooka"] = "", -- Basic_Training_-_Bazooka
--      ["My flying saucer stopped working!"] = "", -- A_Space_Adventure:ice01
      ["Nade Boy"] = "Снайперок", -- Basic_Training_-_Grenade
--      ["Nah, probably everyone was just stupid."] = "", -- A_Space_Adventure:final
--      ["Name"] = "", -- A_Classic_Fairytale:queen
--      ["Nancy Screw"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:queen
--      ["Napalm"] = "", -- Construction_Mode
--      ["Napalm Rocket"] = "", -- Continental_supplies
--      ["Napalm rocket: [Fire a bomb with napalm!]"] = "", -- Continental_supplies
--      ["Naranja Jed"] = "", -- A_Space_Adventure:fruit01
      ["Naughty Ninja"] = "Озорной ниндзя", -- User_Mission_-_Dangerous_Ducklings
--      ["Near a PAotH base on the moon ..."] = "", -- A_Space_Adventure:moon01
--      ["Near Secret Base 17 of PAotH in the rural Hogland ..."] = "", -- A_Space_Adventure:cosmos
--      ["nemo"] = "", -- 
--      ["Neutralize your enemies and be careful!"] = "", -- A_Space_Adventure:moon01
--      ["New barrels per turn: %d"] = "", -- Tumbler
--      ["New clan record: %.1fs"] = "", -- Racer, TechRacer
      ["NEW fastest lap: "] = "НОВЫЙ лучший круг: ",
--      ["New mines per turn: %d"] = "", -- Tumbler
--      ["New race record: %.1fs"] = "", -- Racer, TechRacer
--      ["Newton and the Hammock"] = "", -- User_Mission_-_Newton_and_the_Hammock
--      ["Next target is ready!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Next time you play \"Searching in the dust\" you'll have an RC plane available."] = "", -- A_Space_Adventure:desert03
--      ["Nice!"] = "", -- A_Space_Adventure:cosmos
--      ["Nicely done, meatbags!"] = "", -- A_Classic_Fairytale:enemy
--      ["Nice! Now hurry and get down! You have to rescue my friends!"] = "", -- A_Space_Adventure:moon01
--      ["Nice, then I should get the part as soon as possible!"] = "", -- A_Space_Adventure:ice01
--      ["Nice work!"] = "", -- A_Classic_Fairytale:enemy
--      ["Nice work, meatbags!"] = "", -- A_Classic_Fairytale:queen
--      ["Nice work, %s!"] = "", -- A_Classic_Fairytale:dragon
--      ["Nilarian"] = "", -- A_Classic_Fairytale:queen
      ["Ninja"] = "Ниндзя", -- The_Specialists
--      ["Ninpo"] = "", -- 
      ["Nobody Laugh"] = "Никто не смеётся", -- User_Mission_-_Nobody_Laugh
--      ["Nobody managed to finish the race. What a shame!"] = "", -- Racer, TechRacer
--      ["Nobody takes walks every day!"] = "", -- A_Classic_Fairytale:epil
--      ["No continent selected"] = "", -- Continental_supplies
--      ["No, I am afraid I had to travel light."] = "", -- A_Space_Adventure:moon01
--      ["No, I came back to help you out..."] = "", -- A_Classic_Fairytale:shadow
--      ["No...I wonder where they disappeared?!"] = "", -- A_Classic_Fairytale:journey
--      ["Nom-Nom"] = "", -- A_Classic_Fairytale:journey
--      ["NomNom"] = "", -- A_Classic_Fairytale:united
--      ["No Multi-Use: Once you used an ammo, you can’t take it again in this turn"] = "", -- Highlander
--      ["Noo, Thanta has to stay alive!"] = "", -- A_Space_Adventure:ice01
--      ["Nope. It was one fast mole, that's for sure."] = "", -- A_Classic_Fairytale:shadow
--      ["No! Please, help me!"] = "", -- A_Classic_Fairytale:journey
--      ["No problem, Captain!"] = "", -- A_Space_Adventure:fruit01
--      ["No problem, I would do anything for H!"] = "", -- A_Space_Adventure:desert01
--      ["No radar pings left!"] = "", -- Space_Invasion
--      ["NORMAL"] = "", -- Continental_supplies
--      ["Normal Girder: [1]"] = "", -- HedgeEditor
--      ["Normal Land: [1]"] = "", -- HedgeEditor
--      ["Normal Land"] = "", -- HedgeEditor
--      ["Normally, the mission panel disappears after a few seconds."] = "", -- Basic_Training_-_Movement
--      ["Normal Rubber: [1]"] = "", -- HedgeEditor
--      ["North America"] = "", -- Continental_supplies
--      ["Not being able to fight or hunt."] = "", -- A_Classic_Fairytale:queen
--      ["Note: Some weapons have a second option (See continent information). Find and use them with the \""] = "", -- Continental_supplies
--      ["Note: Some weapons have a second option (See continent information). Find and use them with the \"%s\" key."] = "", -- Continental_supplies
--      ["Note: This basic training assumes default controls."] = "", -- Basic_Training_-_Movement
--      ["Note: Walking is disabled in this mission."] = "", -- Basic_Training_-_Grenade
--      ["Note: We only give you grenades if you stay in your flying saucer."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Nothing of interest has happened."] = "", -- Space_Invasion
--      ["Not now, Fiery Water!"] = "", -- A_Classic_Fairytale:backstab
      ["Not So Friendly Match"] = "Совсем Не Товарищеский Матч", -- Basketball, Knockball
--      ["Not you again! My head still hurts from last time!"] = "", -- A_Classic_Fairytale:shadow
--      ["No waypoint to be removed!"] = "", -- Racer
--      ["Now collect the 2 crates to the far left and right."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Now collect the next crate!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Now dive just one more time and collect the next crate."] = "", -- Basic_Training_-_Flying_Saucer
--      ["No, we made sure of that!"] = "", -- A_Classic_Fairytale:united
      ["Now find the next target! |Tip: Normally you lose health by falling down, so be careful!"] = "Теперь найди следующую цель!|Подсказка: Ты потеряешь здоровье, если упадешь, будь осторожен!", -- Basic_Training_-_Rope
--      ["Now for the supreme discipline of saucer flying, the underwater attack."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Now go and don't waste more of my time, you coward!"] = "", -- A_Space_Adventure:fruit01
--      ["Now go and play the menu mission to complete the campaign."] = "", -- A_Space_Adventure:death01
--      ["Now go to the next crate."] = "", -- Basic_Training_-_Movement
--      ["No! What have I done?! What have YOU done?!"] = "", -- A_Classic_Fairytale:journey
--      ["No. Where did he come from?"] = "", -- A_Classic_Fairytale:shadow
--      ["Now how do I get on the other side?!"] = "", -- A_Classic_Fairytale:dragon
--      ["Now I have to climb these trees"] = "", -- A_Space_Adventure:cosmos
--      ["No Wind Influcence"] = "", -- Basic_Training_-_Grenade
--      ["No Wind Influence"] = "", -- Basic_Training_-_Grenade
--      ["Now let's try to drop weapons while flying!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Now listen carefully! Below us there are tunnels that have been created naturally over the years"] = "", -- A_Space_Adventure:desert01
--      ["Now try to get out of this bounce house|and take the next crate."] = "", -- Basic_Training_-_Movement
--      ["Now use it and go to the moon PAotH station to get more fuel!"] = "", -- A_Space_Adventure:cosmos
--      ["Now you have the chance to try and claim the place that you deserve among the best."] = "", -- A_Space_Adventure:ice02
--      ["No. You and the rest of the tribe are safer there!"] = "", -- A_Classic_Fairytale:backstab
--      ["Objective completed! Now land safely."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Objectives"] = "", -- A_Space_Adventure:ice01
--      ["Object Placer"] = "", -- Construction_Mode
--      ["Obliterate them!|Hint: You might want to take cover..."] = "", -- A_Classic_Fairytale:shadow
--      ["Obstacle"] = "", -- Basic_Training_-_Rope
--      ["Obstacle course"] = "", -- A_Classic_Fairytale:dragon
--      ["Of course, but you're … special."] = "", -- A_Classic_Fairytale:epil
--      ["Of course I am!"] = "", -- A_Classic_Fairytale:queen
--      ["Of course I have to save her. What did I expect?!"] = "", -- A_Classic_Fairytale:family
--      ["Of course! It's all obvious now!"] = "", -- A_Classic_Fairytale:epil
--      ["Of course, I will observe the battle and intervene if necessary."] = "", -- A_Space_Adventure:fruit01
--      ["OH, COME ON!"] = "", -- A_Classic_Fairytale:journey
--      ["Oh man! Learn how to fly!"] = "", -- A_Space_Adventure:ice02
--      ["Oh, my!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Oh, my! I forgot something!"] = "", -- A_Classic_Fairytale:queen
--      ["Oh, my! This is even more entertaining than I've expected!"] = "", -- A_Classic_Fairytale:backstab
--      ["Oh no, not %s!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["Oh no, the companions have betrayed %s and stole the anti-gravity device part!"] = "", -- A_Space_Adventure:fruit02
--      ["Oh no! You have died. Try again!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Oh! Please spare me. You can take all my treasures!"] = "", -- A_Space_Adventure:ice01
--      ["Oh, silly me! I forgot that I'm the shaman."] = "", -- A_Classic_Fairytale:backstab
--      ["Oh, that. We were just having fun!"] = "", -- A_Classic_Fairytale:queen
--      ["Oh yeah! You sure know how to rope!"] = "", -- Basic_Training_-_Rope
--      ["Oh yes! I got the device part! Now it belongs to me alone."] = "", -- A_Space_Adventure:fruit02
--      ["Okay, I'll be extra careful!"] = "", -- A_Space_Adventure:desert01
--      ["Okay, now destroy the target|using the baseball bat."] = "", -- Basic_Training_-_Rope
--      ["Okay then!"] = "", -- A_Space_Adventure:fruit02
--      ["Okay, then you have to go and take some of the weapons we have hidden in case of an emergency!"] = "", -- A_Space_Adventure:moon01
--      ["Old One Eye"] = "", -- 
--      ["Oleg"] = "", -- 
--      ["Olive"] = "", -- A_Classic_Fairytale:united
--      ["Omnivore"] = "", -- A_Classic_Fairytale:first_blood
--      ["Once upon a time, on an island with great natural resources, lived two tribes in heated conflict..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Once you set off the proximity trigger, Mr. Mine is not your friend"] = "", -- ClimbHome
--      ["One does not simply rope to the moon!"] = "", -- A_Space_Adventure:cosmos
--      ["One flower: Incomplete side missions"] = "", -- A_Space_Adventure:cosmos
--      ["One shall not judge one by one's appearance!"] = "", -- A_Classic_Fairytale:epil
--      ["One tribe was peaceful, spending their time hunting and training, enjoying the small pleasures of life..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Oneye"] = "", -- portal
--      ["Only one hog per team allowed! Excess hogs will be removed"] = "", -- Mutant
--      ["Only one hog per team allowed! Excess hogs will be removed."] = "", -- Mutant
--      ["Only %s can be trusted with the crate."] = "", -- A_Space_Adventure:fruit02
--      ["Only the best pilots can master the following stunts."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Only two clans allowed! Excess hedgehogs will be removed."] = "", -- CTF_Blizzard
--      ["On the Ice Planet, where ice rules ..."] = "", -- A_Space_Adventure:ice01
--      ["On the other side of the moon ..."] = "", -- A_Space_Adventure:moon02
--      ["On the Planet of Sand, you have to double check your moves ..."] = "", -- A_Space_Adventure:desert01
--      ["On this map you get %d%% fuel."] = "", -- TechRacer
--      ["On this map you get infinite fuel."] = "", -- TechRacer
--      ["Oops...I dropped them."] = "", -- A_Classic_Fairytale:united
--      ["Oops, I've been spotted and I have no weapons! I am doomed!"] = "", -- A_Space_Adventure:moon01
--      ["Oops! You have selected the wrong hedgehog! Just try again."] = "", -- Basic_Training_-_Movement
--      ["Open ammo menu: [Right click]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
--      ["Open ammo menu: Tap the [Suitcase]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
--      ["Open that crate and we will continue!"] = "", -- A_Classic_Fairytale:first_blood
      ["Opposing Team: "] = "Команда Соперника: ",
--      ["Orange"] = "", -- 
--      ["Orlando Boom!"] = "", -- A_Classic_Fairytale:queen
--      ["Or let the next player place waypoints|if less than 2 waypoints have been placed."] = "", -- Racer
--      ["Or maybe this was all part of an evil plan, so evil that even Prof. Hogevil can't think of it!"] = "", -- A_Space_Adventure:final
--      ["Oscillating Gravity: Gravity periodically changes within a range from %i%% to %i%% with a period of %s"] = "", -- Gravity
      ["Other kills don't give you points."] = "Другие убийства не дадут вам очков.", -- Mutant
--      ["Ouch! That must have hurt. %s (%s) hit the ground with %d damage points."] = "", -- ClimbHome
--      ["Ouch! That must have hurt. You mutilated your poor hedgehog hog with %d damage."] = "", -- ClimbHome
--      ["Ouch! You just took fall damage."] = "", -- Basic_Training_-_Movement
--      ["Our tribe, our beautiful island!"] = "", -- A_Classic_Fairytale:enemy
--      ["Out of ammo!"] = "", -- A_Space_Adventure:desert03, Tumbler
--      ["Out of ammo! Try again!"] = "", -- Basic_Training_-_Bazooka
--      ["Over the Water"] = "", -- Basic_Training_-_Rope
--      ["PAotH"] = "", -- A_Space_Adventure:cosmos, A_Space_Adventure:death01, A_Space_Adventure:desert01, A_Space_Adventure:moon01
--      ["PAotH has sent explosives but unfortunately the trigger mechanism seems to be faulty!"] = "", -- A_Space_Adventure:cosmos
      ["Parachute"] = "Парашют", -- Continental_supplies
--      ["Patches"] = "", -- 
--      ["Paul McHoggy"] = "", -- A_Space_Adventure:ice01, A_Space_Adventure:ice02
--      ["Pause: [P]"] = "", -- Basic_Training_-_Movement
--      ["Pause: Tap the [Pause] button"] = "", -- Basic_Training_-_Movement
--      ["Penalty: If you violate above rule, you have to skip in the next turn."] = "", -- WxW
--      ["Penguin Roar"] = "", -- Continental_supplies
--      ["Penguin roar: [Deal 15 damage + 10% of your hog’s health to all hogs around you and get 2/3 back]"] = "", -- Continental_supplies
--      ["Penguin roar: [Deal 15 damage + 10% of your hogs health to all hogs around you and get 2/3 back]"] = "", -- Continental_supplies
--      ["Perfect! Now try to get the next crate without hurting yourself!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Per-hog Ammo: Weapons are not shared between hogs"] = "", -- User_Mission_-_Nobody_Laugh
--      ["Personal best: %.3f seconds"] = "", -- A_Space_Adventure:ice02
--      ["Per team weapons"] = "", -- Continental_supplies
--      ["Pfew! That was close!"] = "", -- A_Classic_Fairytale:shadow
--      ["Phosphat"] = "", -- portal
--      ["Physicist"] = "", -- HedgeEditor
      ["Piano Strike"] = "Фортепьяновый удар", -- Construction_Mode
--      ["Pikachu"] = "", -- 
--      ["Pings left: %d"] = "", -- Space_Invasion
--      ["Pink"] = "", -- 
--      ["Pirates"] = "", -- 
--      ["Place 2-%d waypoints using the waypoint placement tool."] = "", -- Racer
--      ["Place 2 waypoints using the waypoint placement tool."] = "", -- Racer
--      ["Place air mines"] = "", -- HedgeEditor
--      ["Place barrels"] = "", -- HedgeEditor
--      ["Place cleavers"] = "", -- HedgeEditor
--      ["Place/Delete Waypoint: [Left Click]"] = "", -- HedgeEditor
--      ["Place dud mines"] = "", -- HedgeEditor
--      ["Place Gears (and more): Gear Placement Tool"] = "", -- HedgeEditor
--      ["Place Girder: Girder"] = "", -- HedgeEditor
--      ["Place Girder: [Left Click]"] = "", -- HedgeEditor
--      ["Place girders"] = "", -- HedgeEditor
--      ["Place health crates"] = "", -- HedgeEditor
--      ["Place hedgehogs: Place your hedgehogs at the start of the game."] = "", -- WxW
--      ["Placement Mode"] = "", -- HedgeEditor
--      ["Place mines"] = "", -- HedgeEditor
--      ["Place, modify and delete gears (e.g. objects)|and waypoints, edit hedgehog settings, values,|victory conditions, and more."] = "", -- HedgeEditor
--      ["Place Object: [Left Click]"] = "", -- HedgeEditor
--      ["Place or delete waypoints"] = "", -- HedgeEditor
--      ["Place rubber"] = "", -- HedgeEditor
--      ["Place Rubber: Rubber"] = "", -- HedgeEditor
--      ["Place Sprite: [Left Click]"] = "", -- HedgeEditor
--      ["Place sprites to build land"] = "", -- HedgeEditor
--      ["Place sticky mines"] = "", -- HedgeEditor
--      ["Place targets"] = "", -- HedgeEditor
--      ["Place utility crates"] = "", -- HedgeEditor
--      ["Place Waypoint"] = "", -- HedgeEditor
--      ["Place waypoint"] = "", -- Racer
--      ["Place weapon crates"] = "", -- HedgeEditor
--      ["- Place your clan flag at the end of your first turn"] = "", -- Capture_the_Flag
--      ["- Place your team flag at the end of your first turn"] = "", -- Capture_the_Flag
      ["Planes used: %d"] = "Использовано самолётов: %d", -- User_Mission_-_RCPlane_Challenge
--      ["Planets with all missions completed will be marked with two flowers."] = "", -- A_Space_Adventure:cosmos
--      ["Planets with completed main missions will be marked with a flower."] = "", -- A_Space_Adventure:cosmos
--      ["Play with me!"] = "", -- A_Classic_Fairytale:shadow
--      ["Please click on a crate."] = "", -- HedgeEditor
--      ["Please click on a gear."] = "", -- HedgeEditor
--      ["Please click on a hedgehog, barrel, health crate or dud mine."] = "", -- HedgeEditor
--      ["Please click on a hedgehog."] = "", -- HedgeEditor
--      ["Please place the waypoint further away from the waterline"] = "", -- Racer, TechRacer
--      ["Please place the waypoint in the air and within the map boundaries"] = "", -- TechRacer
--      ["Please place the waypoint in the air, within the map boundaries"] = "", -- Racer
--      ["Please place your hedgehog first!"] = "", -- WxW
--      ["Please, stop releasing your \"smoke signals\"!"] = "", -- A_Classic_Fairytale:shadow
--      ["Please wait …"] = "", -- WxW
--      ["Point Blank Combo! +5 points!"] = "", -- Space_Invasion
--      ["--- Points ---"] = "", -- Battalion
--      ["--- Points Mode ---"] = "", -- Battalion
--      ["Poisonous Apple"] = "", -- A_Space_Adventure:fruit02
--      ["Poisonous, deals no damage."] = "", -- Continental_supplies
      ["Poison"] = "Яд",
--      ["Pokémon"] = "", -- 
--      ["Poor %s (%s) died %d times."] = "", -- Mutant
--      ["Population"] = "", -- Continental_supplies
--      ["Porkey"] = "", -- 
--      ["Portal hint: one goes to the destination, and one is the entrance.|"] = "", -- A_Classic_Fairytale:dragon
--      ["Portal hint: One goes to the destination, the other one is the entrance.|"] = "", -- A_Classic_Fairytale:dragon
--      ["Portal Mind Challenge"] = "", -- portal
--      ["Precise Aim: [Left Shift]"] = "", -- Basic_Training_-_Movement
--      ["Precise Aim: [Left Shift] + [Up]/[Down]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["Precise flying"] = "", -- A_Space_Adventure:desert03
--      ["Precise: Remove previous waypoint"] = "", -- Racer
--      ["Precise shooting"] = "", -- A_Space_Adventure:fruit03
      ["Predator"] = "Хищник", -- portal
--      ["Prepare for battle!"] = "", -- A_Space_Adventure:moon01
--      ["Prepare to fight"] = "", -- A_Space_Adventure:moon01
--      ["Prepare to flee!"] = "", -- A_Space_Adventure:cosmos
--      ["Prepare yourself, %s!"] = "", -- The_Specialists
--      ["Press [Attack] (space bar by default) to start,|repeadedly tap the up, left and right movement keys to accelerate."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Press [Attack] (space bar by default) to start,|repeatedly tap the up, left and right movement keys to accelerate."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Press [Attack] to begin."] = "", -- A_Classic_Fairytale:first_blood
--      ["Press [Attack] to confirm."] = "", -- Continental_supplies
--      ["Press [Attack] to select this continent!"] = "", -- Continental_supplies
--      ["Press [Left] and [Right] to change the difficulty."] = "", -- A_Classic_Fairytale:first_blood
--      ["Press [Left] or [Right] to move around, [Long Jump] to jump forwards."] = "", -- A_Classic_Fairytale:first_blood
--      ["Press [Long jump] to accept this configuration and begin placing hedgehogs."] = "", -- WxW
--      ["Press [Long jump] to accept this configuration and start the game."] = "", -- WxW
--      ["Press [M] to see the mission texts"] = "", -- Basic_Training_-_Movement
--      ["Press [Precise] to skip intro"] = "",
--      ["Press [Up] and [Down] to move between menu items.|Press [Attack], [Left], or [Right] to toggle."] = "", -- WxW
      ["Prestigious Pilot"] = "Престижный Пилот", -- User_Mission_-_RCPlane_Challenge
--      ["Princess"] = "", -- A_Classic_Fairytale:family, A_Classic_Fairytale:journey
--      ["Princess Peach"] = "", -- 
--      ["Problems, dude? Chillax!"] = "", -- A_Classic_Fairytale:epil
      ["Professional pilot"] = "Профессиональный пилот", -- User_Mission_-_RCPlane_Challenge
      ["Professional stunt pilot"] = "Профессиональный пилот-трюкач", -- User_Mission_-_RCPlane_Challenge
--      ["Professor"] = "", -- A_Space_Adventure:death01, A_Space_Adventure:moon01
--      ["Professor Hogevil, then known as James Hogus, worked for PAotH back in my time."] = "", -- A_Space_Adventure:moon02
--      ["Professor's Team"] = "", -- A_Space_Adventure:death01
--      ["Prof. Hogevil"] = "", -- A_Space_Adventure:death01, A_Space_Adventure:moon01
--      ["Protect the King: When the king dies, so does the team"] = "", -- Battalion
--      ["Protect yourselves!|Grenade hint: set the timer with [1-5], aim with [Up]/[Down] and hold [Space] to set power"] = "", -- A_Classic_Fairytale:shadow
--      ["Purple"] = "", -- 
--      ["Pyromancer"] = "", -- Battalion
      ["Pyro"] = "Пироман", -- The_Specialists
--      ["Quit: [Esc]"] = "", -- Basic_Training_-_Movement
--      ["Race complexity limit reached"] = "", -- Racer, TechRacer
--      ["Race failed!"] = "", -- A_Space_Adventure:moon02
--      ["Racer"] = "", -- Racer
--      ["Racer tool"] = "", -- Racer
      ["Race"] = "Гонка", -- TrophyRace
--      ["Rachel"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["Radar: Off"] = "", -- WxW
--      ["Radar: On"] = "", -- WxW
--      ["Radar Ping: [High jump]"] = "", -- Space_Invasion
--      ["Radar: Show after crate drop"] = "", -- WxW
--      ["Raging Buffalo"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Ramesses"] = "", -- 
--      ["Ramon"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow
--      ["Random continent"] = "", -- Continental_supplies
      ["Rank: %s"] = "Ранк: %s", -- User_Mission_-_RCPlane_Challenge
--      ["Razac"] = "", -- portal
--      ["RC Plane Challenge"] = "", -- User_Mission_-_RCPlane_Challenge
--      ["RC Plane"] = "", -- Construction_Mode
--      ["Reach and destroy the final target to win."] = "", -- Basic_Training_-_Rope
--      ["Read the challenge objectives from within the mission for more details."] = "", -- A_Space_Adventure:death02, A_Space_Adventure:desert03, A_Space_Adventure:fruit03
--      ["Ready for Battle?"] = "", -- A_Space_Adventure:fruit01
--      ["Really?! You thought you could harm me with your little toys?"] = "", -- A_Classic_Fairytale:shadow
--      ["Red"] = "", -- 
--      ["Reflector Shield: Reflects enemy projectiles."] = "", -- Construction_Mode
      ["Reflector Shield"] = "Щит-Отражатель", -- Construction_Mode
--      ["Regurgitator"] = "", -- A_Classic_Fairytale:backstab
--      ["Reinforcements! +2 of each weapon!"] = "", -- A_Space_Adventure:death02
--      ["Reinforcements"] = "", -- A_Classic_Fairytale:backstab
--      ["Release rope: [Attack]"] = "", -- Basic_Training_-_Rope
--      ["Remember: Hold down [Left Shift] to prevent slipping"] = "", -- Basic_Training_-_Movement
--      ["Remember! Many will seek the anti-gravity device! Now go, hurry up!"] = "", -- A_Space_Adventure:cosmos
      ["Remember: The rope only bend around objects, |if it doesn't hit anything it's always stright!"] = "Помни: Верёвка изгибается только вокруг объекты, |если же она ничего не касается, то всегда остается прямой!", -- Basic_Training_-_Rope
--      ["Remember this, pathetic animal: when the day comes, you will regret your blind loyalty!"] = "", -- A_Classic_Fairytale:shadow
--      ["Remember this, pathetic animal: When the day comes, you will regret your blind loyalty!"] = "", -- A_Classic_Fairytale:shadow
--      ["Replenishment: Weapons are restocked on turn start of a new hog"] = "", -- Highlander
--      ["Repositioning Mode"] = "", -- HedgeEditor
--      ["REPOSITIONING MODE"] = "", -- HedgeEditor
--      ["Rescue the imprisoned PAotH team and get the fuel!"] = "", -- A_Space_Adventure:moon01
--      ["Respawner: Resurrects dead hogs."] = "", -- Construction_Mode
      ["Respawner"] = "Воскреситель", -- Construction_Mode
--      ["Resurrector"] = "", -- Construction_Mode
--      ["Retract/Extend rope: [Up]/[Down]"] = "", -- Basic_Training_-_Rope
--      ["- Return the enemy flag to your base to score"] = "", -- Capture_the_Flag
--      ["Return to Leaks A Lot!"] = "", -- A_Classic_Fairytale:shadow
--      ["Return to the mission menu by pressing the \"Go back\" button."] = "", -- A_Space_Adventure:cosmos
--      ["Return to the Surface"] = "", -- A_Space_Adventure:fruit02
--      ["Return to the training menu by pressing the “Go back” button."] = "", -- Basic_Training_-_Movement
      ["Rider"] = "Адский Всадник", -- portal
--      ["Rifleman"] = "", -- Battalion
--      ["Righteous Beard"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:first_blood, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
--      ["Ripe"] = "", -- 
--      ["Rise the water if nobody else is in the circle and deal 6 damage to all enemy hogs."] = "", -- Continental_supplies
--      ["Robert Yellow Apple"] = "", -- A_Space_Adventure:fruit01
--      ["Rocket"] = "", -- Big_Armory
--      ["Ronald"] = "", -- portal
--      ["Roof"] = "", -- WxW
--      ["Rope-knocking Challenge"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Rope Master"] = "", -- Basic_Training_-_Rope
      ["Ropes and Crates"] = "Верёвки и Ящики", -- Challenge_-_Speed_Shoppa_-_Ropes
--      ["Ropes can be fired again in the air!"] = "", -- A_Classic_Fairytale:first_blood
      ["Rope Team"] = "Верёвочники", -- Basic_Training_-_Rope
      ["Rope Training"] = "Тренировка с Верёвкой", -- Basic_Training_-_Rope
--      ["Rope Weapons"] = "", -- Basic_Training_-_Rope
--      ["Roshi"] = "", -- 
--      ["Rot Molester"] = "", -- A_Classic_Fairytale:shadow
--      ["Rotten"] = "", -- 
--      ["Round draw"] = "", -- Racer, TechRacer
--      ["Round %d (Sudden Death in round %d)"] = "", -- Battalion
--      ["Round limit: %d"] = "", -- Racer
--      ["Round Limit: %d"] = "", -- Space_Invasion
--      ["Round limit:"] = "", -- TechRacer
--      ["Rounds complete: %d/%d"] = "", -- Racer, Space_Invasion, TechRacer
      ["Round's slowest lap: %.3fs by %s"] = "Самый медленный круг: %s за %.3fs", -- TrophyRace
--      ["RS1"] = "", -- A_Space_Adventure:fruit03
--      ["RS2"] = "", -- A_Space_Adventure:fruit03
--      ["Rubber"] = "", -- Construction_Mode, HedgeEditor
--      ["RUBBER PLACEMENT MODE"] = "", -- HedgeEditor
      ["Rubber Placement Mode"] = "Режим Размещения Батутов", -- Construction_Mode
--      ["Rules:"] = "", -- Capture_the_Flag
--      ["RULES:"] = "", -- Frenzy
--      ["Rules: "] = "", -- Mutant
--      ["Run away, you coward!"] = "", -- A_Space_Adventure:desert01
--      ["Running displacement algorithm …"] = "", -- A_Classic_Fairytale:queen
--      ["Running for survival"] = "", -- A_Space_Adventure:desert02
--      ["Rusted Diego"] = "", -- 
--      ["Rusty Joe"] = "", -- A_Classic_Fairytale:queen
--      ["Ryu"] = "", -- 
--      ["%s (+1)"] = "", -- A_Space_Adventure:fruit03
--      ["%s: %.1fs"] = "", -- Racer, TechRacer
--      ["Sabotage all hogs in the circle and fire a cluster above you.|Sabotaged hogs lose health and have to deal with a very high gravity during their turn."] = "", -- Continental_supplies
--      ["Sabotage/Flare: [Sabotage all hogs in the circle and deal ~1 dmg OR Fire a cluster up into the air]"] = "", -- Continental_supplies
      ["Saint"] = "Святой", -- The_Specialists
--      ["Salivaslurper"] = "", -- A_Classic_Fairytale:united
--      ["Salty Dog"] = "", -- 
--      ["Salvation"] = "", -- A_Classic_Fairytale:family
--      ["Salvation was one step closer now..."] = "", -- A_Classic_Fairytale:dragon
--      ["Sam"] = "", -- A_Space_Adventure:cosmos
--      ["Sandals?! I thought you left your ring!"] = "", -- A_Classic_Fairytale:queen
--      ["%s and GB"] = "", -- A_Space_Adventure:fruit02
--      ["%s and %s enter the battlefield"] = "", -- A_Space_Adventure:fruit01
--      ["Sandstorm"] = "", -- A_Space_Adventure:desert01
--      ["Sandy"] = "", -- A_Space_Adventure:desert01
--      ["%s arrived at the Desert Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["%s arrived at the Fruit Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["%s arrived at the Ice Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["%s arrived at the meteorite!"] = "", -- A_Space_Adventure:cosmos
--      ["%s arrived at the moon!"] = "", -- A_Space_Adventure:cosmos
--      ["%s arrived at the Planet of Death!"] = "", -- A_Space_Adventure:cosmos
--      ["Save as many hogs as possible!"] = "", -- User_Mission_-_That_Sinking_Feeling
--      ["Save Fell From Heaven!"] = "", -- A_Classic_Fairytale:journey
--      ["Save Leaks A Lot!|Hint: The switch hedgehog utility might be of help to you."] = "", -- A_Classic_Fairytale:shadow
--      ["Save Level: [Precise]+[4]"] = "", -- HedgeEditor
--      ["Save the princess! All your hogs must survive!|Hint: Kill the cyborgs first! Use the ammo very carefully!|Hint: You might want to spare a girder for cover!"] = "", -- A_Classic_Fairytale:family
--      ["Save the princess by collecting the crate in under 12 turns!"] = "", -- A_Classic_Fairytale:journey
--      ["Saving Hogera"] = "", -- A_Space_Adventure:cosmos
--      ["%s barely made it past the hogosphere."] = "", -- ClimbHome
--      ["%s bravely climbed up to a dizzy height of %d to reach home."] = "", -- ClimbHome
--      ["Scallywag"] = "", -- 
--      ["Scalp Muncher"] = "", -- A_Classic_Fairytale:backstab
--      ["Scenario"] = "", -- Big_Armory, portal, User_Mission_-_Bamboo_Thicket, User_Mission_-_Dangerous_Ducklings, User_Mission_-_Diver, User_Mission_-_Newton_and_the_Hammock, User_Mission_-_Nobody_Laugh, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork_2, User_Mission_-_Teamwork, User_Mission_-_The_Great_Escape
--      ["Scientist"] = "", -- Battalion
--      ["%s climbed home in %d seconds!"] = "", -- ClimbHome
--      ["%s (contd.)"] = "", -- A_Classic_Fairytale:epil
--      ["Score: %d"] = "", -- Space_Invasion
--      ["Score goal: %d"] = "", -- Control
--      ["Score graph"] = "", -- Mutant, Space_Invasion
--      ["Score points by killing other hedgehogs."] = "", -- Mutant
--      ["Score points by killing other hedgehogs (see below)."] = "", -- Mutant
--      ["Scores: "] = "", -- Capture_the_Flag
--      ["Scores"] = "", -- Mutant
--      ["Scores:"] = "", -- Mutant
--      ["Scoring: "] = "", -- Mutant
--      ["%s couldn't escape, try again!"] = "", -- A_Space_Adventure:fruit01
--      ["Script parameter examples:"] = "", -- Gravity
--      ["%s (+%d)"] = "", -- Battalion
--      ["%s: %d"] = "", -- Capture_the_Flag, Control
--      ["%s (%d)"] = "", -- Continental_supplies
--      ["%s: %d (deaths: %d)"] = "", -- Mutant
--      ["%s (%d), %d sec"] = "", -- Continental_supplies
--      ["%s: Did not finish"] = "", -- Racer, TechRacer
--      ["%s did not finish the race."] = "", -- Racer, TechRacer
--      ["%s didn't expect that."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s died … and lives again!"] = "", -- Construction_Mode
--      ["%s doesn’t really know how to handle a rope properly."] = "", -- ClimbHome
--      ["%s, %d sec"] = "", -- Continental_supplies
--      ["Search for the device with the help of the other hedgehogs."] = "", -- A_Space_Adventure:fruit02
--      ["Searching in the dust"] = "", -- A_Space_Adventure:desert01
--      ["Searching the stars!"] = "", -- A_Space_Adventure:cosmos
      ["Seduction"] = "Соблазнение", -- Continental_supplies
--      ["Seems like every time you take a \"walk\", the enemy finds us!"] = "", -- A_Classic_Fairytale:backstab
--      ["See that crate farther on the right?"] = "", -- A_Classic_Fairytale:first_blood
      ["See ya!"] = "Увидимся!",
--      ["Segmentation Paul"] = "", -- A_Classic_Fairytale:dragon
--      ["Select a placement mode and read the infos|in the mission panel to learn how to use it."] = "", -- HedgeEditor
--      ["Select continent!"] = "", -- Continental_supplies
--      ["Select continent"] = "", -- Continental_supplies
--      ["Selection Mode"] = "", -- HedgeEditor
--      ["Select, modify, or delete girders, rubbers and sprites"] = "", -- HedgeEditor
--      ["Select/Place/Delete Gear: [Left Click]"] = "", -- HedgeEditor
--      ["Select, reposition and delete gears"] = "", -- HedgeEditor
--      ["Select Rope"] = "", -- Basic_Training_-_Rope
--      ["Select “Switch Hedgehog” from the ammo menu and|hit the “Attack” key."] = "", -- Basic_Training_-_Movement
--      ["Select “Switch Hedgehog” from the ammo menu and|hit the “Attack” key to proceed."] = "", -- Basic_Training_-_Movement
--      ["Select the current continent."] = "", -- Continental_supplies
--      ["Select the rope to begin!"] = "", -- Basic_Training_-_Rope
--      ["Select this item for a random continent."] = "", -- Continental_supplies
--      ["Select Weapon"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["Select weapon: [Left click]"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade
--      ["Select win/lose condition: [Left], [Right]"] = "", -- HedgeEditor
--      ["Select your continent/weaponset: with the \"Up\" or \"Down\" keys. You can also select one with the weapons menu."] = "", -- Continental_supplies
--      ["Select your continent/weaponset: With the \"Up\" or \"Down\" keys. You can also select one with the weapons menu."] = "", -- Continental_supplies
--      ["Select your continent with [Up]/[Down] or by selecting a representative weapon."] = "", -- Continental_supplies
--      ["%s enters the battlefield"] = "", -- A_Space_Adventure:fruit01
--      ["Sergey"] = "", -- 
--      ["%s escaped successfully!"] = "", -- A_Space_Adventure:fruit01
--      ["Set bounciness: [Left Shift] + [1]-[5]"] = "", -- Basic_Training_-_Grenade
--      ["Set detonation timer: [1]-[5]"] = "", -- Basic_Training_-_Grenade
--      ["Set Health: [Left Click]"] = "", -- HedgeEditor
--      ["Set Identity: [Left Click]"] = "", -- HedgeEditor
--      ["Set period to negative value for random gravity."] = "", -- Gravity
--      ["Set the health of hogs, health crates, barrels and duds"] = "", -- HedgeEditor
--      ["Set to %d"] = "", -- HedgeEditor
--      ["%s exploded."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s fell from a high cliff."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s fell too fast."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s fell victim to a weapon filter"] = "", -- Construction_Mode
--      ["%s felt unstable."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s felt victim to rope-knocking."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s flew like a rock."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s gets an extra life"] = "", -- Construction_Mode
--      ["%s goes the way of the lemming."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Sgt. Smith"] = "", -- 
--      ["%s had it coming."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s had no chance."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["... share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["%s has been killed before taking enough damage first."] = "", -- SimpleMission
--      ["%s has been knocked out."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s has been rescued from death"] = "", -- Construction_Mode
--      ["%s has dropped the flag!"] = "", -- CTF_Blizzard
--      ["%s has fallen victim to gravity."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s has mutated! +2 points"] = "", -- Mutant
--      ["%s has passed the best height of %s!"] = "", -- ClimbHome
--      ["%s has scored!"] = "", -- Capture_the_Flag
--      ["%s has to refuel the saucer."] = "", -- A_Space_Adventure:moon01
--      ["%s hates Newton."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["She endangered the whole tribe!"] = "", -- A_Classic_Fairytale:epil
--      ["sheepluva"] = "", -- 
--      ["Sheepy"] = "", -- 
--      ["She's behind that tall thingy."] = "", -- A_Classic_Fairytale:family
--      ["Shield boosted! +%d power"] = "", -- Space_Invasion
--      ["Shield depleted"] = "", -- Space_Invasion
--      ["Shield is fully recharged!"] = "",
--      ["Shield Master! +10 points!"] = "", -- Space_Invasion
--      ["Shield Miser! +%d points!"] = "", -- Space_Invasion
--      ["Shield OFF: %d power remaining"] = "", -- Space_Invasion
--      ["Shield ON: %d power remaining"] = "", -- Space_Invasion
--      ["Shield Seeker! +10 points!"] = "", -- Space_Invasion
--      ["Shinobi"] = "", -- 
--      ["%s hit the ground."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Shoppa Love"] = "", -- Challenge_-_Speed_Shoppa_-_Hedgelove
      ["Shotgun"] = "Дробовик", -- Continental_supplies
--      ["Sigh."] = "", -- A_Classic_Fairytale:epil
      ["Silly"] = "Глупый",
--      ["Silver"] = "", -- 
--      ["Sine Gun"] = "", -- Construction_Mode
      ["Sinky"] = "Утопленник",
--      ["Sirius Lee"] = "", -- A_Classic_Fairytale:enemy
--      ["%s is dead, who was critical to this mission!"] = "", -- SimpleMission
--      ["%s is eliminated!"] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s is now as poor as a church mouse"] = "", -- Construction_Mode
--      ["%s is now a zombie hedgehog"] = "", -- Construction_Mode
--      ["%s is suddenly low on ammo"] = "", -- Construction_Mode
--      ["Skulls"] = "", -- Bazooka_Battlefield
--      ["Slimer"] = "", -- 
--      ["Slippery"] = "", -- A_Classic_Fairytale:journey
--      ["%s lost all the weapons"] = "", -- Construction_Mode
--      ["%s lost, try again!"] = "", -- A_Space_Adventure:death01, A_Space_Adventure:death02, A_Space_Adventure:desert01, A_Space_Adventure:desert02, A_Space_Adventure:desert03, A_Space_Adventure:final, A_Space_Adventure:fruit01, A_Space_Adventure:fruit02, A_Space_Adventure:fruit03, A_Space_Adventure:ice01, A_Space_Adventure:moon01
--      ["Slot %d: %s"] = "", -- Frenzy
--      ["Slot keys save time! (F1-F10 by default)"] = "", -- Frenzy
--      ["Slowpoke"] = "", -- 
--      ["%s made it past the hogosphere."] = "", -- ClimbHome
--      ["%s managed to pass half of the distance towards home."] = "", -- ClimbHome
--      ["%s may choose the rules."] = "", -- WxW
--      ["Smith 0.97"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.98"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99a"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99b"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 0.99f"] = "", -- A_Classic_Fairytale:enemy
--      ["Smith 1.0"] = "", -- A_Classic_Fairytale:enemy
--      ["Smugglers"] = "", -- A_Space_Adventure:desert01
--      ["%s must collect the final crates."] = "", -- A_Space_Adventure:fruit02
--      ["%s must skip this turn for rule violation."] = "", -- WxW
--      ["Sneaks"] = "", -- Bazooka_Battlefield
--      ["%s never got the ninja diploma."] = "", -- ClimbHome
--      ["%s never wanted to reach for the sky in the first place."] = "", -- ClimbHome
--      ["Sniper! +8 points!"] = "", -- Space_Invasion
      ["Sniper Rifle"] = "Снайперская винтовка", -- Continental_supplies
      ["Sniper Training"] = "Тренировка снайпера",
      ["Sniper"] = "Снайпер", -- The_Specialists
--      ["So, as promised I have brought you where I think that the device you are looking for is hidden."] = "", -- A_Space_Adventure:fruit02
--      ["So far, you had infinite ropes, but in the|real world, ropes are usually limited."] = "", -- Basic_Training_-_Rope
--      ["So humiliating..."] = "", -- A_Classic_Fairytale:first_blood
--      ["So, I believe that it's a good place to start."] = "", -- A_Space_Adventure:desert01
--      ["So, I kindly ask for your help."] = "", -- A_Space_Adventure:fruit01
--      ["So I shook my fist in the air!"] = "", -- A_Classic_Fairytale:epil
      ["Soldier"] = "Солдат", -- The_Specialists
--      ["So, let me tell you what I know about Professor Hogevil."] = "", -- A_Space_Adventure:moon02
--      ["Some parts of the land are indestructible."] = "", -- A_Space_Adventure:fruit03
--      ["Some sick game of yours?!"] = "", -- A_Classic_Fairytale:queen
--      ["Some weapons can be dropped from the rope."] = "", -- Basic_Training_-_Rope
--      ["Somewhere else on the planet of fruits, Captain Lime helps %s"] = "", -- A_Space_Adventure:fruit02
--      ["Somewhere else on the planet of fruits, %s gets closer to the device"] = "", -- A_Space_Adventure:fruit02
--      ["Somewhere on the Planet of Fruits a terrible war is about to begin ..."] = "", -- A_Space_Adventure:fruit01
--      ["Somewhere on the uninhabitable Death Planet ..."] = "", -- A_Space_Adventure:death01
--      ["So, now I got the last part and I have your friends captured."] = "", -- A_Space_Adventure:death01
--      ["So, %s, here we are ..."] = "", -- A_Space_Adventure:cosmos
--      ["So the princess was never heard of again ..."] = "", -- A_Classic_Fairytale:family
--      ["So, uhmm, how did you manage to teleport them so far?"] = "", -- A_Classic_Fairytale:epil
--      ["Sour"] = "", -- 
--      ["South America"] = "", -- Continental_supplies
--      ["So? What will it be?"] = "", -- A_Classic_Fairytale:shadow
--      ["So you are able to launch projectiles into your aiming direction, always at full power."] = "", -- Basic_Training_-_Flying_Saucer
--      ["So you are interested in Professor Hogevil, huh?"] = "", -- A_Space_Adventure:moon02
--      ["So you basically did the dirty work for us."] = "", -- A_Classic_Fairytale:dragon
--      ["Space Invasion"] = "", -- Space_Invasion
--      ["SPACE INVASION"] = "", -- Space_Invasion
--      ["Spacetrip"] = "", -- A_Space_Adventure:cosmos
--      ["Spawn the crate and attack!"] = "", -- WxW
--      ["Specials: Kings and air generals drop helpers, not weapons"] = "", -- Battalion
--      ["Special weapons:"] = "", -- Continental_supplies
--      ["Special Weapons:"] = "", -- Continental_supplies
--      ["Speckles"] = "", -- 
--      ["Specs"] = "", -- 
--      ["Specs Appeal"] = "", -- 
--      ["Spectator"] = "", -- 
--      ["Speed Roping"] = "", -- Basic_Training_-_Rope
--      ["Speed Shoppa"] = "", -- SpeedShoppa
--      ["Spike"] = "", -- A_Space_Adventure:desert01
--      ["Spikes"] = "", -- 
--      ["Spiky Cheese"] = "", -- A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:shadow
--      ["%s, place the first hedgehog!"] = "", -- WxW
--      ["Spleenlover"] = "", -- A_Classic_Fairytale:united
      ["Sponge"] = "Губка",
      ["Spooky Tree"] = "Зловещее дерево",
--      ["Sprite Erasure Mode"] = "", -- HedgeEditor
--      ["Sprite Modification Mode"] = "", -- HedgeEditor
--      ["SPRITE MODIFICATION MODE"] = "", -- HedgeEditor
--      ["Sprite Placement Mode"] = "", -- Construction_Mode
--      ["SPRITE PLACEMENT MODE"] = "", -- HedgeEditor
--      ["Sprite Testing Mode"] = "", -- Construction_Mode
--      ["Squirtle"] = "", -- 
--      ["Squishy"] = "", -- 
--      ["%s reached home in %.3f seconds. Congratulations!"] = "", -- ClimbHome
--      ["%s: %s"] = "", -- Continental_supplies
--      ["%s (%s) destroyed %d invaders in one round."] = "", -- Space_Invasion
--      ["%s (%s) does not have to feel ashamed for their best height of %d."] = "", -- ClimbHome
--      ["%s, select your continent!"] = "", -- Continental_supplies
--      ["%s (%s) gave short shrift to the invaders: Longest combo of %d!"] = "", -- Space_Invasion
--      ["%s (%s) has been invited to join the Planetary Association of the Hedgehogs, it destroyed a staggering %d invaders in just one round!"] = "", -- Space_Invasion
--      ["%s (%s) has captured the flag %d times."] = "", -- Capture_the_Flag
--      ["%s (%s) hate life and suicided %d times."] = "", -- Mutant
--      ["%s should try the rope training mission first."] = "", -- ClimbHome
--      ["%s (%s) is addicted to killing: %d invaders destroyed in one round."] = "", -- Space_Invasion
--      ["%s (%s) is a hardened hunter: No misses and %d hits in its best round!"] = "", -- Space_Invasion
--      ["%s (%s) is a tumbleweed: %d points in one round."] = "", -- Space_Invasion
--      ["%s (%s) is good at this: %d points in only one round!"] = "", -- Space_Invasion
--      ["%s (%s) is Rambo in a hedgehog costume! He destroyed %d invaders in one round."] = "", -- Space_Invasion
--      ["%s skipped ninja classes."] = "", -- ClimbHome
--      ["%s spawned at a really bad position."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s splatted."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s (%s) reached a decent peak height of %d."] = "", -- ClimbHome
--      ["%s (%s) reached a peak height of %d."] = "", -- ClimbHome
--      ["%s (%s) reached for the sky and beyond with a height of %d!"] = "", -- ClimbHome
--      ["%s (%s) reached home in %.3f seconds."] = "", -- ClimbHome
--      ["%s (%s) shot %d invaders and never missed in the best round!"] = "", -- Space_Invasion
--      ["%s (%s) struck like a meteor: %d points in only one round!"] = "", -- Space_Invasion
--      ["%s still had a long way to go."] = "", -- ClimbHome
--      ["%s stumbled."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s (%s) tumbles like no other: %d points in one round."] = "", -- Space_Invasion
--      ["%s stumpled."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s (%s) was certainly not afraid of heights: Peak height of %d!"] = "", -- ClimbHome
--      ["%s (%s) was lightning-fast! Longest combo of %d, absolutely insane!"] = "", -- Space_Invasion
--      ["%s (%s) was on fire: Longest combo of %d."] = "", -- Space_Invasion
--      ["%s (%s) was panicly afraid of the water and decided to get in a safe distance of %d from it."] = "", -- ClimbHome
--      ["%s (%s) was the best baby tumbler: %d points in one round."] = "", -- Space_Invasion
--      ["%s (%s) was the greediest hedgehog and collected %d crates."] = "", -- Mutant
--      ["%s (%s) was undoubtedly the very best professional tumbler in this game: %d points in one round!"] = "", -- Space_Invasion
--      ["Star"] = "", -- Big_Armory
--      ["Status update"] = "", -- Racer, TechRacer
--      ["Status Update"] = "", -- Space_Invasion
--      ["Stay away from our weapons!"] = "", -- A_Classic_Fairytale:queen
--      ["Stay there, comrades!"] = "", -- A_Classic_Fairytale:queen
--      ["Stay there to flee!"] = "", -- A_Space_Adventure:fruit01
--      ["Steel Eye"] = "", -- A_Classic_Fairytale:queen
--      ["Step 1: Activate your flying saucer but do NOT move yet!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Step 1: Start roping"] = "", -- Basic_Training_-_Rope
--      ["Step 2: Select grenade"] = "", -- Basic_Training_-_Rope
--      ["Step 2: Select your grenade."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Step 3: Drop the grenade"] = "", -- Basic_Training_-_Rope
--      ["Step 3: Start flying and get yourself right above the target."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Step 4: Drop your grenade by pressing the [Long jump] key."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Step 5: Get away quickly and land safely anywhere."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Step By Step"] = "", -- A_Classic_Fairytale:first_blood
--      ["Steve"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["STICKY MINE PLACEMENT MODE"] = "", -- HedgeEditor
      ["Sticky Mine Placement Mode"] = "Режим Размещения Мин-Липучек", -- Construction_Mode
      ["Sticky Mine"] = "Мина-Липучка", -- Continental_supplies
--      ["Stop, comrades!"] = "", -- A_Classic_Fairytale:queen
--      ["Stop right there, puny worms!"] = "", -- A_Classic_Fairytale:queen
--      ["Street Fighters"] = "", -- 
--      ["Strength: %d (multiplier for ammo)"] = "", -- Battalion
--      ["Strong knockback, but no poison."] = "", -- Continental_supplies
--      ["Stronglings"] = "", -- A_Classic_Fairytale:shadow
      ["Structure Placement Mode"] = "Режим Размещения Сооружений", -- Construction_Mode
--      ["Structure Placer"] = "", -- Construction_Mode
--      ["Stupid, stupid Hogerians!"] = "", -- A_Space_Adventure:final
--      ["Subtract %d"] = "", -- HedgeEditor
--      ["--- Sudden Death ---"] = "", -- Battalion
--      ["Summer Squash"] = "", -- A_Space_Adventure:fruit01
--      ["Sundaland"] = "", -- Continental_supplies
--      ["Sunflame"] = "", -- Big_Armory
--      ["Super weapons: A few crates contain very powerful weapons."] = "", -- WxW
--      ["Super weapons: %s"] = "", -- WxW
--      ["Supplies: Each continent gives you unique weapons, specials and health."] = "", -- Continental_supplies
--      ["Support Station: Allows placement of crates."] = "", -- Construction_Mode
      ["Support Station"] = "Станция Поддержки", -- Construction_Mode
--      ["Sure!"] = "", -- A_Classic_Fairytale:epil
--      ["Surf Before Crate: %s"] = "", -- WxW
--      ["Surf Before Crate: You must bounce off the water once before you can get crates."] = "", -- WxW
--      ["Surfer! +15 points!"] = "", -- Space_Invasion
--      ["Surfer!"] = "", -- WxW
--      ["Surprise supplies: Get 1-3 random weapons each turn."] = "", -- Continental_supplies
--      ["Survive!"] = "", -- A_Classic_Fairytale:shadow
--      ["%s violated the “All But Last” rule and will be penalized."] = "", -- WxW
--      ["%s violated the “Kill The Leader” rule and will be penalized."] = "", -- WxW
--      ["Swap place with a random enemy in the circle."] = "", -- Continental_supplies
--      ["%s was a good target."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s was close to home."] = "", -- ClimbHome
--      ["%s was damn close to home."] = "", -- ClimbHome
--      ["%s was doomed from the beginning."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s was extracted from the scheme"] = "", -- Continental_supplies
--      ["%s was good, but not good enough."] = "", -- ClimbHome
--      ["%s was knocked away."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s was really unlucky."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s was shoved away."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["%s was smashed."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["Sweet"] = "", -- 
--      ["%s went over a quarter of the way towards home."] = "", -- ClimbHome
--      ["%s! Why?!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["Swing, Leaks A Lot, on the wings of the wind!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Swing: [Left]/[Right]"] = "", -- Basic_Training_-_Rope
--      ["%s wins, congratulations!"] = "", -- A_Space_Adventure:moon01
--      ["%s wins!"] = "", -- Racer, Space_Invasion, TechRacer, ClimbHome
--      ["%s wins with a best time of %.1fs."] = "", -- Racer, TechRacer
--      ["switch"] = "", -- Continental_supplies
--      ["Switch: Drop ball of dirt from parachute (once)"] = "", -- Continental_supplies
      ["Switched to "] = "Выбран ",
--      ["Switch Hedgehog (1/3)"] = "", -- Basic_Training_-_Movement
--      ["Switch Hedgehog (2/3)"] = "", -- Basic_Training_-_Movement
--      ["Switch Hedgehog (3/3)"] = "", -- Basic_Training_-_Movement
--      ["Switch Hedgehog (Failed!)"] = "", -- Basic_Training_-_Movement
--      ["Switch hedgehog: [Tabulator]"] = "", -- Basic_Training_-_Movement
--      ["Switch Hog"] = "", -- Construction_Mode
--      ["Switch: Select weapon special"] = "", -- Continental_supplies
--      ["Switch: Toggle crate radar"] = "", -- WxW
--      ["%s won!"] = "", -- A_Space_Adventure:fruit01
--      ["Swords"] = "", -- Bazooka_Battlefield
--      ["Syntax Errol"] = "", -- A_Classic_Fairytale:dragon
--      ["%s, you may choose the rules."] = "", -- WxW
--      ["szczur"] = "", -- 
--      ["Tackleberry"] = "", -- 
--      ["Tails"] = "", -- 
--      ["Talk about mixed signals..."] = "", -- A_Classic_Fairytale:dragon
--      ["Tall Potato"] = "", -- A_Space_Adventure:fruit01
--      ["Tap [Pause] to see the mission texts"] = "", -- Basic_Training_-_Movement
--      ["Tap the “rotating arrow” button on the left|until you have selected Cappy, the hedgehog with the cap!"] = "", -- Basic_Training_-_Movement
--      ["Target"] = "", -- HedgeEditor
--      ["Target Placement Mode"] = "", -- Construction_Mode
--      ["TARGET PLACEMENT MODE"] = "", -- HedgeEditor
      ["Target Practice: Bazooka (easy)"] = "Учебная Стрельба: Базука (легко)", -- Target_Practice_-_Bazooka_easy
      ["Target Practice: Bazooka (hard)"] = "Учебная Стрельба: Базука (сложно)", -- Target_Practice_-_Bazooka_hard
      ["Target Practice: Grenade (easy)"] = "Учебная Стрельба: Граната (легко)", -- Target_Practice_-_Grenade_easy
      ["Target Practice: Grenade (hard)"] = "Учебная Стрельба: Граната (сложно)", -- Target_Practice_-_Grenade_hard
      ["Target Practice: Homing Bee"] = "Учебная Стрельба: Пчёлка", -- Target_Practice_-_Homing_Bee
      ["Target Practice: Shotgun"] = "Учебная Стрельба: Дробовик", -- Target_Practice_-_Shotgun
--      ["Target Puncher"] = "", -- Basic_Training_-_Rope
      ["Targets left: %d"] = "Осталось целей: %d", -- TargetPractice
--      ["Tatsujin"] = "", -- 
--      ["Tatters"] = "", -- 
--      ["Team %d"] = "", -- SimpleMission
      ["Team %d: "] = "Команда %d: ",
--      ["Team highscore: %d"] = "", -- Utils
--      ["Team Identity Mode"] = "", -- HedgeEditor
--      ["TEAM IDENTITY MODE"] = "", -- HedgeEditor
--      ["Team lowscore: %d"] = "", -- Utils
--      ["Teams are tied! Continue playing rounds until we have a winner!"] = "", -- Space_Invasion
--      ["Team's best time: %.3fs"] = "", -- Utils
--      ["Team Scores:"] = "", -- Control
--      ["Team scores:"] = "", -- Space_Invasion
--      ["Team's longest time: %.3fs"] = "", -- Utils
--      ["Team's top accuracy: %d%"] = "", -- Utils
--      ["Teamwork 2"] = "", -- User_Mission_-_Teamwork_2
--      ["Teamwork"] = "", -- User_Mission_-_Teamwork
--      ["TechRacer"] = "", -- TechRacer
      ["Teleportation Mode"] = "Режим Телепортации", -- Construction_Mode
--      ["Teleportation Node: Allows teleportation|    between other nodes."] = "", -- Construction_Mode
      ["Teleportation Node"] = "Узел Телепортации", -- Construction_Mode
--      ["Teleport"] = "", -- Construction_Mode, Frenzy
--      ["Teleport hint: just use the mouse to select the destination!"] = "", -- A_Classic_Fairytale:dragon
--      ["Teleport hint: Just use the mouse to select the destination!"] = "", -- A_Classic_Fairytale:dragon
--      ["Teleport to the impact location."] = "", -- Continental_supplies
--      ["Teleport to the top of the map, expect fall damage!"] = "", -- Continental_supplies
--      ["Teleport unsuccessful. Please teleport within a clan teleporter's sphere of influence."] = "", -- Construction_Mode
      ["Teleport Unsuccessful. Please teleport within a clan teleporter's sphere of influence."] = "Неудачная Телепортация. Вы можете телепортироваться только в области влияния ваших телепортов.", -- Construction_Mode
--      ["Tentacle Terror"] = "", -- Tentacle_Terror
--      ["Textile industry: Will give you a parachute every second turn."] = "", -- Continental_supplies
--      ["Thanks!"] = "", -- A_Classic_Fairytale:family
--      ["Thanks, dude! It really means a lot to me."] = "", -- A_Classic_Fairytale:epil
--      ["Thanks, man! It really means a lot to me."] = "", -- A_Classic_Fairytale:epil
--      ["Thank you, Dr. Cornelius."] = "", -- A_Space_Adventure:cosmos
--      ["Thank you for meeting me on such a short notice!"] = "", -- A_Space_Adventure:desert01
--      ["Thank you, my hero!"] = "", -- A_Classic_Fairytale:family
--      ["Thank you, oh, thank you, Leaks A Lot!"] = "", -- A_Classic_Fairytale:journey
--      ["Thank you, oh, thank you, my heroes!"] = "", -- A_Classic_Fairytale:journey
--      ["Thanta"] = "", -- A_Space_Adventure:ice01
--      ["That is, indeed, very weird..."] = "", -- A_Classic_Fairytale:united
--      ["That makes it almost invaluable!"] = "", -- A_Classic_Fairytale:enemy
--      ["That ought to show them!"] = "", -- A_Classic_Fairytale:backstab
--      ["That's all, folks!"] = "", -- A_Classic_Fairytale:epil
--      ["That's for my father!"] = "", -- A_Classic_Fairytale:backstab
--      ["That shaman sure knows what he's doing!"] = "", -- A_Classic_Fairytale:shadow
      ["That Sinking Feeling"] = "Дед Мазай и Ёжики",
--      ["That's just the way it works, you know."] = "", -- A_Classic_Fairytale:queen
--      ["That's not our problem!"] = "", -- A_Classic_Fairytale:enemy
--      ["That's typical of you!"] = "", -- A_Classic_Fairytale:family
--      ["That's why he always wears a hat since then."] = "", -- A_Space_Adventure:moon02
--      ["That traitor won't be killing us anymore!"] = "", -- A_Classic_Fairytale:queen
--      ["That was just mean!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["That was pointless. The flag will respawn next round."] = "", -- CTF_Blizzard
--      ["The adventure begins!"] = "", -- A_Space_Adventure:cosmos
--      ["The air bombs are weaker than usual."] = "", -- Battalion
--      ["The aliens respect me, even worship me!"] = "", -- A_Classic_Fairytale:queen
--      ["The ally units share their ammo."] = "", -- A_Space_Adventure:fruit01
--      ["The ammo of %s has been vaporized"] = "", -- Construction_Mode
--      ["The answer is ... entertainment. You'll see what I mean."] = "", -- A_Classic_Fairytale:backstab
--      ["The answer is...entertaintment. You'll see what I mean."] = "", -- A_Classic_Fairytale:backstab
--      ["The anti-portal surface is all over the floor, and I have nothing to kill him. Dropping something could hurt him enough to kill him."] = "", -- portal
--      ["The big bang"] = "", -- A_Space_Adventure:final
--      ["The Boss"] = "", -- 
--      ["The boss has fallen! Retreat!"] = "", -- A_Space_Adventure:moon01
--      ["The Bull's Eye"] = "", -- A_Classic_Fairytale:first_blood
--      ["The caves are well hidden, they won't find us there!"] = "", -- A_Classic_Fairytale:united
--      ["The clan of the Red Strawberry wants to take over the dominion and overthrow King Pineapple."] = "", -- A_Space_Adventure:fruit01
--      ["The continent of cowards"] = "", -- Continental_supplies
--      ["The continent of dust"] = "", -- Continental_supplies
--      ["The continent of firearms"] = "", -- Continental_supplies
--      ["The continent of greed"] = "", -- Continental_supplies
--      ["The continent of guerilla tactics"] = "", -- Continental_supplies
--      ["The continent of ice and science"] = "", -- Continental_supplies
--      ["The continent of medicine"] = "", -- Continental_supplies
--      ["The continent of ninjas"] = "", -- Continental_supplies
--      ["The continent of sports"] = "", -- Continental_supplies
--      ["The Crate Frenzy"] = "", -- A_Classic_Fairytale:first_blood
      ["The Customer is King"] = "Покупатель это Король", -- Challenge_-_Speed_Shoppa_-_ShoppaKing
--      ["The device part has been stolen!"] = "", -- A_Space_Adventure:fruit02
--      ["The device part is hidden in one of the crates! Go and get it!"] = "", -- A_Space_Adventure:desert01
--      ["The Devs"] = "", -- 
--      ["The Dilemma"] = "", -- A_Classic_Fairytale:shadow
--      ["The editor weapons and tools have been added!"] = "", -- HedgeEditor
--      ["The editor weapons and tools have been removed!"] = "", -- HedgeEditor
--      ["The enemies aren't many anyway, it is going to be easy!"] = "", -- A_Space_Adventure:fruit01
--      ["The enemy can't move but it might be a good idea to stay out of sight!"] = "", -- A_Classic_Fairytale:dragon
--      ["The enemy has taken a crate which we really needed!"] = "", -- SimpleMission
      ["The enemy hogs play in a random order."] = "Враждебные ёжики играют в случайном порядке.", -- A_Space_Adventure:death02
      ["The enemy is hiding out on yonder ducky!"] = "Враг прячется на соседней утке!",
      ["The Enemy Of My Enemy"] = "Враг Моего Врага", -- A_Classic_Fairytale:enemy
      ["The explosion is weaker than usual."] = "Взрыв слабее, чем обычно.", -- Battalion
      ["The fastest hedgehog was %s from %s with a time of %.3fs."] = "Самый быстрый ёжик был %s от команды %s со временем %.3fs.", -- TrophyRace
      ["The fight begins!"] = "Битва начинается!", -- A_Space_Adventure:moon01
--      ["The final part"] = "", -- A_Space_Adventure:death01
--      ["The final targets are quite tricky. You need to aim well."] = "", -- Basic_Training_-_Bazooka
--      ["The First Blood"] = "", -- A_Classic_Fairytale:first_blood
--      ["The First Encounter"] = "", -- A_Classic_Fairytale:shadow
--      ["The first hedgehog to kill someone becomes the Mutant."] = "", -- Mutant
--      ["The first hedgehog which scores %d or more wins the game."] = "", -- Mutant
--      ["The first stop"] = "", -- A_Space_Adventure:moon01
--      ["The first turn will last 25 sec and every other turn 15 sec."] = "", -- A_Space_Adventure:fruit03
      ["The flag will respawn next round."] = "Флаг опять появится в следующем раунде.",
      ["The flood has stopped! Challenge over."] = "Наводнение остановилось! Испытание закончено.", -- User_Mission_-_That_Sinking_Feeling
--      ["The food bites back"] = "", -- A_Classic_Fairytale:backstab
--      ["The forgotten continent"] = "", -- Continental_supplies
--      ["The giant umbrella from the last crate should help break the fall."] = "", -- A_Classic_Fairytale:first_blood
      ["The Great Escape"] = "Великий Побег", -- User_Mission_-_The_Great_Escape
--      ["- The green target must survive"] = "", -- HedgeEditor
--      ["- The green targets must survive"] = "", -- HedgeEditor
--      ["The guardian"] = "", -- A_Classic_Fairytale:shadow
--      ["The hardships of the war turned %s (%s) into a killing machine: %d invaders destroyed in one round!"] = "", -- Space_Invasion
--      ["The health of your current hedgehog|is shown at the top right corner."] = "", -- Basic_Training_-_Movement
--      ["The hedgehog with least points (or most deaths) becomes the Bottom Feeder."] = "", -- Mutant
--      ["The Hospital"] = "", -- 
--      ["The Individualist"] = "", -- A_Classic_Fairytale:shadow
--      ["Their buildings were very primitive back then, even for an uncivilised island."] = "", -- A_Classic_Fairytale:united
--      ["The Iron Curtain"] = "", -- 
--      ["The Journey Back"] = "", -- A_Classic_Fairytale:journey
--      ["The king of %s has died!"] = "", -- Battalion
--      ["The last encounter"] = "", -- A_Space_Adventure:death01
      ["The last surviving clan wins."] = "Последняя выжившая команда побеждает.", -- TrophyRace
--      ["The leader escaped. Defeat the rest of the aliens!"] = "", -- A_Classic_Fairytale:queen
--      ["The leader seems scared, he will probably flee."] = "", -- A_Classic_Fairytale:queen
--      ["The Leap of Faith"] = "", -- A_Classic_Fairytale:first_blood
--      ["The meteorite has come too close and the anti-gravity device isn't powerful enough to stop it now."] = "", -- A_Space_Adventure:cosmos
--      ["The Moonwalk"] = "", -- A_Classic_Fairytale:journey
--      ["The Mutant has super weapons and a lot of health."] = "", -- Mutant
      ["The Mutant has super-weapons and a lot of health."] = "У Мутанта есть супер-оружие и много здоровья.", -- Mutant
--      ["The Mutant loses health quickly, but gains health by killing."] = "", -- Mutant
      ["The Mutant loses health quickly if he doesn't keep scoring kills."] = "Мутант быстро теряет здоровье, если не зарабатывает очки за убийства.", -- Mutant
--      ["The Navy greets %s for managing to get in a distance of %d away from the mainland!"] = "", -- ClimbHome
--      ["The next 4 times you play the \"The last encounter\" mission you'll get 20 more hit points and a laser sight."] = "", -- A_Space_Adventure:death02
--      ["The next crate is an utility crate."] = "", -- Basic_Training_-_Movement
      ["The next one is pretty hard! |Tip: You have to do multiple swings!"] = "Следующая цель довольно сложна! |Подсказка: Нужно сделать несколько раскачиваний!", -- Basic_Training_-_Rope
--      ["The next target can only be reached by something called “bouncing bomb”."] = "", -- Basic_Training_-_Bazooka
--      ["The next target is high in the sky."] = "", -- Basic_Training_-_Bazooka
--      ["Then how do they keep appearing?"] = "", -- A_Classic_Fairytale:shadow
--      ["The Ninja-Samurai Alliance"] = "", -- 
--      ["Then prepare for battle!"] = "", -- A_Space_Adventure:death01
--      ["Then what am I?"] = "", -- A_Classic_Fairytale:epil
--      ["The only woman, huh?"] = "", -- A_Classic_Fairytale:epil
--      ["The oppression of the elders, of course!"] = "", -- A_Classic_Fairytale:queen
--      ["The opression of the elders, of course!"] = "", -- A_Classic_Fairytale:queen
--      ["The other hog has died, he should have survived!"] = "", -- A_Space_Adventure:moon02
--      ["The other one were all cannibals, spending their time eating the organs of fellow hedgehogs..."] = "", -- A_Classic_Fairytale:first_blood
--      ["The Police"] = "", -- 
--      ["The power of love! No, wait, the power of the aliens!"] = "", -- A_Classic_Fairytale:queen
--      ["The RC plane only carries 2 weak bombs."] = "", -- Battalion
      ["There are a variety of structures available to aid you."] = "Множество сооружений доступны вам в помощь.", -- Construction_Mode
--      ["There are no snarky comments this time."] = "", -- Space_Invasion
--      ["There is one below us!"] = "", -- A_Space_Adventure:ice01
--      ["There must be a spy among us!"] = "", -- A_Classic_Fairytale:backstab
--      ["There's more of them? When did they become so hungry?"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["There's nothing more satisfying for me than seeing you share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["There's nothing more satisfying to us than seeing you share your beauty..."] = "", -- A_Classic_Fairytale:journey
--      ["There's nothing more satisfying to us than seeing you share your beauty with the world every morning, my princess!"] = "", -- A_Classic_Fairytale:journey
--      ["The respawner respawns %s"] = "", -- Construction_Mode
--      ["The Rising"] = "", -- A_Classic_Fairytale:first_blood
--      ["The rope won't get reset."] = "", -- A_Space_Adventure:death02
--      ["The Savior"] = "", -- A_Classic_Fairytale:journey
--      ["The score and deaths are shown next to the team bar."] = "", -- Mutant
--      ["These girders are slippery, like ice."] = "", -- Basic_Training_-_Movement
--      ["These primitive people are so funny!"] = "", -- A_Classic_Fairytale:backstab
--      ["These weapon specials cannot be used close to other hogs."] = "", -- Continental_supplies
--      ["The Shadow Falls"] = "", -- A_Classic_Fairytale:shadow
--      ["The Showdown"] = "", -- A_Classic_Fairytale:shadow
--      ["The Slaughter"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:first_blood
--      ["The Society of Perfectionists greets %s (%s): No misses and %d hits in its best round."] = "", -- Space_Invasion
--      ["The Specialists: Each hedgehog starts with its own weapon set"] = "", -- The_Specialists
--      ["The spinning arrows above your hedgehog show|which hedgehog is selected right now."] = "", -- Basic_Training_-_Movement
--      ["The spirits of the ancerstors are surely pleased, Leaks A Lot."] = "", -- A_Classic_Fairytale:first_blood
--      ["The spirits of the ancestors are surely pleased, Leaks A Lot."] = "", -- A_Classic_Fairytale:first_blood
--      ["The targets will guide you through the training."] = "", -- Basic_Training_-_Rope
--      ["The team continued their quest of finding the rest of the tribe."] = "", -- A_Classic_Fairytale:queen
--      ["The teams are tied for the fastest time."] = "", -- Racer, TechRacer
--      ["The teams were tied, so an additional round has been played to determine the winner."] = "", -- Space_Invasion
--      ["The teams were tied, so %d additional rounds have been played to determine the winner."] = "", -- Space_Invasion
--      ["The time that you have left when you reach the blue hedgehog will be added to the next turn."] = "", -- A_Space_Adventure:moon02
--      ["The Torment"] = "", -- A_Classic_Fairytale:first_blood
--      ["The truth about Professor Hogevil"] = "", -- A_Space_Adventure:moon02
--      ["The tunnel entrance is over there."] = "", -- A_Space_Adventure:desert01
--      ["The tunnel is about to get flooded!"] = "", -- A_Space_Adventure:desert02
--      ["The Tunnel Maker"] = "", -- A_Classic_Fairytale:journey
--      ["The Ultimate Weapon"] = "", -- A_Classic_Fairytale:first_blood
--      ["The Union"] = "", -- A_Classic_Fairytale:enemy
--      ["The Union: You can select a hedgehog at the start of your turns."] = "", -- Continental_supplies
--      ["The village, unprepared, was destroyed by the cyborgs..."] = "", -- A_Classic_Fairytale:journey
--      ["The walk of Fame"] = "", -- A_Classic_Fairytale:shadow
--      ["The wasted youth"] = "", -- A_Classic_Fairytale:first_blood
--      ["The way you handled your little internal conflicts …"] = "", -- A_Classic_Fairytale:queen
--      ["The weapon in that last crate was bestowed upon us by the ancients!"] = "", -- A_Classic_Fairytale:first_blood
--      ["The what?!"] = "", -- A_Classic_Fairytale:dragon
--      ["The wind whispers that you are ready to become familiar with tools, now..."] = "", -- A_Classic_Fairytale:first_blood
--      ["The wrong hedgehog has taken the crate."] = "", -- SimpleMission
--      ["They are all waiting back in the village, haha."] = "", -- A_Classic_Fairytale:enemy
--      ["They are up there! Take this rope and hurry!"] = "", -- A_Space_Adventure:moon01
--      ["They Call Me Bullseye! +16 points!"] = "", -- Space_Invasion
--      ["They have weapons we've never seen before!"] = "", -- A_Classic_Fairytale:united
--      ["They keep appearing like this. It's weird!"] = "", -- A_Classic_Fairytale:united
--      ["They killed %s! You bastards!"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:united
--      ["They must be trying to weaken us!"] = "", -- A_Classic_Fairytale:enemy
--      ["They never learn"] = "", -- A_Classic_Fairytale:journey
--      ["They stumbled upon a pile of weapons, they seemed to be getting closer."] = "", -- A_Classic_Fairytale:queen
--      ["They told us to wear these clothes. They said that this is the newest trend."] = "", -- A_Classic_Fairytale:enemy
--      ["They've been manipulating us all this time!"] = "", -- A_Classic_Fairytale:enemy
--      ["They won't hesitate to attack you in order to rob you!"] = "", -- A_Space_Adventure:desert01
--      ["The Zoo"] = "", -- 
--      ["Thighlicker"] = "", -- A_Classic_Fairytale:united
--      ["Things are going to get messy around here."] = "", -- A_Space_Adventure:fruit01
--      ["This allows to select any hedgehog in your team!"] = "", -- Basic_Training_-_Movement
--      ["This allows you to create a crate anywhere|within your clan's area of influence,|at the cost of energy."] = "", -- Construction_Mode
--      ["This allows you to create and place mines,|sticky mines and barrels anywhere within your|clan's area of influence at the cost of energy."] = "", -- Construction_Mode
--      ["This allows you to create and place mines,|sticky mines and barrels anywhere within your|clan's area of influence at the cost of energy.|Up/down: Choose object type|Left/right: Choose timer (for mines)|Cursor: Place object"] = "", -- Construction_Mode
--      ["This almost concludes our tutorial."] = "", -- Basic_Training_-_Flying_Saucer
--      ["This also increases the effectiveness of Medicine."] = "", -- Continental_supplies
--      ["This game wasn’t really exciting."] = "", -- Space_Invasion
--      ["This is a new personal best, congratulations!"] = "", -- A_Space_Adventure:death02, A_Space_Adventure:desert02, A_Space_Adventure:fruit03
--      ["This is a new personal best time, congratulations!"] = "", -- A_Space_Adventure:ice02, A_Space_Adventure:moon02
--      ["This is Cappy."] = "", -- Basic_Training_-_Movement
--      ["This is it! It's time to make Fell From Heaven fall for me..."] = "", -- A_Classic_Fairytale:first_blood
--      ["This island is the only place left on Earth with grass on it!"] = "", -- A_Classic_Fairytale:enemy
--      ["This is seems like a wealthy hedgehog, nice ..."] = "", -- A_Space_Adventure:desert01
--      ["This is the mission panel."] = "", -- Basic_Training_-_Movement
--      ["This is the Olympic stadium of saucer flying."] = "", -- A_Space_Adventure:ice02
--      ["This is the Olympic Stadium of Saucer Flying."] = "", -- A_Space_Adventure:ice02
--      ["This is typical!"] = "", -- A_Classic_Fairytale:dragon
--      ["This must be some kind of sorcery!"] = "", -- A_Classic_Fairytale:shadow
--      ["This must be the caves!"] = "", -- A_Classic_Fairytale:backstab
      ["This one's tricky."] = "Это непростая цель.",
--      ["This planet seems dangerous!"] = "", -- A_Space_Adventure:cosmos
      ["This rain is really something..."] = "Этот дождь нескончаем...",
--      ["This round’s award for ultimate disappointment goes to: Everyone!"] = "", -- ClimbHome
--      ["This seems like a wealthy hedgehog, nice ..."] = "", -- A_Space_Adventure:desert01
--      ["This %s is so naive! I'm going to shoot this fool so I can keep that device for myself!"] = "", -- A_Space_Adventure:fruit02
      ["This was an awesome performance! But this challenge can be finished with even just one RC plane. Can you figure out how?"] = "Потрясающее исполнение! Но это испытание можно пройти всего с одним самолётом. Знаете как?", -- User_Mission_-_RCPlane_Challenge
--      ["This will be fun!"] = "", -- A_Classic_Fairytale:enemy
--      ["This will be useful when I need a new platform or if I want to rise."] = "", -- portal
--      ["This will certainly come in handy."] = "", -- User_Mission_-_Teamwork_2
--      ["This will certianly come in handy."] = "", -- User_Mission_-_Teamwork_2
--      ["Thompson"] = "", -- 
--      ["Those aliens are destroying the island!"] = "", -- A_Classic_Fairytale:family
--      ["Those were scheduled for disposal anyway."] = "", -- A_Classic_Fairytale:dragon
--      ["Throw a 1 second mine!"] = "", -- Continental_supplies
--      ["Throw a baseball at your foes|and send them flying!"] = "", -- Knockball
--      ["Throw a grenade to destroy the target!"] = "", -- Basic_Training_-_Grenade
--      ["Throw some grenades to destroy the targets!"] = "", -- Basic_Training_-_Grenade
--      ["Thug #%d"] = "", -- A_Space_Adventure:death01
--      ["Tie-breaking round %d"] = "", -- Space_Invasion
--      ["Timbers"] = "", -- 
--      ["Time: %.1fs"] = "", -- Racer, TechRacer
--      ["Time: %.3fs by %s"] = "", -- TrophyRace
--      ["Time: %.3fs"] = "", -- TrophyRace
--      ["Time Box"] = "", -- Construction_Mode
--      ["Timed Kamikaze! +10 points!"] = "", -- Space_Invasion
--      ["Time extended! +%dsec"] = "", -- Space_Invasion
--      ["Time extension: %ds"] = "", -- Tumbler
--      ["Time for a more interesting stunt, but first just collect the next crate!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Timer"] = "", -- Basic_Training_-_Grenade
--      ["Time’s up!"] = "", -- TargetPractice
      ["Time's up!"] = "Время вышло!", -- Basic_Training_-_Sniper_Rifle
--      ["Time to run!"] = "", -- A_Space_Adventure:fruit01
--      ["Tip: Changing your aim while flying is very difficult, so adjust it before you take off."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Tip: Don't remain for too long in the water, or you won't make it."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Tip: If you get stuck in this training, use \"Skip turn\" to restart the current objective."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Tip: See the \"esc\" key (this menu) if you want to see the currently playing teams continent, or that continents specials."] = "", -- Continental_supplies
--      ["Tip: See the \"Esc\" key (this menu) if you want to see the currently playing teams continent, or that continents specials."] = "", -- Continental_supplies
      ["Tip: The rope physics are different than in the real world, |use it to your advantage!"] = "Подсказка: Поведение верёвки отличается от того, что в реальном мире, |используй это как преимущество!", -- Basic_Training_-_Rope
--      ["Tip: You can change your flying saucer|in mid-flight by hitting the [Attack] key twice."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Tiyuri"] = "", -- 
--      ["Toad"] = "", -- 
--      ["To begin, walk to the crate to the right."] = "", -- Basic_Training_-_Movement
--      ["To begin with the training, hit the attack key!"] = "", -- Basic_Training_-_Movement
--      ["To begin with the training, select the bazooka from the ammo menu!"] = "", -- Basic_Training_-_Bazooka
--      ["To begin with the training, select the grenade from the ammo menu!"] = "", -- Basic_Training_-_Grenade
--      ["To begin with the training, tap the attack button!"] = "", -- Basic_Training_-_Movement
--      ["To finish hedgehog selection, just do anything|with him, like walking."] = "", -- Basic_Training_-_Movement
--      ["To get over the next obstacles, keep some distance from the wall before you back jump."] = "", -- Basic_Training_-_Movement
--      ["To get over the water, you have to do multiple|rope shots and swings."] = "", -- Basic_Training_-_Rope
--      ["Toggle Editing Weapons and Tools: [Precise]+[2]"] = "", -- HedgeEditor
--      ["Toggle Help: [Precise]+[1]"] = "", -- HedgeEditor
--      ["Toggle Placement/Deletion: [Left], [Right]"] = "", -- HedgeEditor
--      ["Toggle Shield: [Long jump]"] = "", -- Space_Invasion
--      ["To help you, of course!"] = "", -- A_Classic_Fairytale:journey
--      ["To launch a projectile in mid-flight, hold [Precise] and press [Long jump]."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Tony"] = "", -- 
--      ["Too bad! Then you should really leave!"] = "", -- A_Space_Adventure:fruit01
--      ["Too slow! Try again ..."] = "", -- A_Space_Adventure:moon02
      ["Top-class elite pilot"] = "Элитный пилот топ класса", -- User_Mission_-_RCPlane_Challenge
--      ["To reach higher ground, walk to a ledge, look to the left, then do a back jump."] = "", -- Basic_Training_-_Movement
--      ["Torn Muscle"] = "", -- A_Classic_Fairytale:journey
--      ["To the caves..."] = "", -- A_Classic_Fairytale:united
--      ["Touch all waypoints as fast as you can!"] = "", -- Racer
--      ["- Touch the sparkles near your base to teleport"] = "", -- CTF_Blizzard
--      ["To win the game, %s has to get the bottom crates and come back to the surface."] = "", -- A_Space_Adventure:fruit02
--      ["To win the game you had to collect the 2 crates with no specific order."] = "", -- A_Space_Adventure:desert01
--      ["To win the game you have to eliminate Professor Hogevil."] = "", -- A_Space_Adventure:death01
--      ["To win the game you have to find the right crate."] = "", -- A_Space_Adventure:desert01
--      ["To win the game you have to go next to Thanta."] = "", -- A_Space_Adventure:ice01
--      ["To win the game you have to go to the surface."] = "", -- A_Space_Adventure:desert02
--      ["To win the game you have to pass into the rings in time."] = "", -- A_Space_Adventure:ice02
--      ["To win the game you have to stand next to Thanta."] = "", -- A_Space_Adventure:ice01
      ["Toxic Team"] = "Токсичные", -- User_Mission_-_Diver, User_Mission_-_Spooky_Tree, User_Mission_-_Teamwork
--      ["Track completed!"] = "", -- Racer, TechRacer
--      ["Training"] = "", -- Basic_Training_-_Flying_Saucer, Basic_Training_-_Rope
--      ["Training complete!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Traitors"] = "", -- A_Classic_Fairytale:epil
--      ["Traitors don't get to shout around here!"] = "", -- A_Classic_Fairytale:epil
--      ["Trapper"] = "", -- HedgeEditor
--      ["Travel carefully as your fuel is limited"] = "", -- A_Space_Adventure:cosmos
--      ["Travel to all the neighbor planets and collect all the pieces"] = "", -- A_Space_Adventure:cosmos
--      ["Treasure: Massive weapon bonus in first turn."] = "", -- Continental_supplies
--      ["Tribe"] = "", -- A_Classic_Fairytale:backstab
      ["TrophyRace"] = "Трофейная Гонка",
--      ["Trunks"] = "", -- 
--      ["Try again!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Try it now and dive here to collect the crate on the right girder."] = "", -- Basic_Training_-_Flying_Saucer
--      ["Try not to get spotted by the guards!"] = "", -- A_Space_Adventure:cosmos
--      ["Try out different bounciness levels to reach difficult targets."] = "", -- Basic_Training_-_Grenade
--      ["Try to be smart and eliminate them quickly. This way you might scare off the rest!"] = "", -- A_Space_Adventure:fruit01
--      ["Try to keep as many allies alive as possible."] = "", -- A_Space_Adventure:fruit01
--      ["Try to land softly, as you can still take fall damage!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["Try to protect the chief! You won't lose if he dies, but it is advised that he survives."] = "", -- A_Classic_Fairytale:united
--      ["Try to reach and destroy the next target quickly."] = "", -- Basic_Training_-_Rope
--      ["Tumbler"] = "", -- Tumbler
--      ["Turn around: [Left Shift] + [Left]/[Right]"] = "", -- Basic_Training_-_Movement
--      ["Turning Around"] = "", -- Basic_Training_-_Movement
--      ["Turns: Hogs get %d random weapon(s) from their pool"] = "", -- Battalion
--      ["Turns: King's health is set to %d%% of the team health"] = "", -- Battalion
--      ["Turns left: %d"] = "", -- A_Classic_Fairytale:journey
--      ["Turns: Refill %d weapon and %d helper points|and randomize weapons and helpers based on team points"] = "", -- Battalion
--      ["Turns until arrival: %d"] = "", -- A_Classic_Fairytale:backstab
--      ["Turn Time: %dsec"] = "", -- Space_Invasion
--      ["Twenty-Twenty"] = "", -- 
--      ["Two flowers: All missions complete"] = "", -- A_Space_Adventure:cosmos
--      ["Two little hogs cooperating, getting past obstacles..."] = "", -- A_Classic_Fairytale:journey
--      ["Ugly Mug"] = "", -- 
--      ["Uhm...I met one of them and took his weapons."] = "", -- A_Classic_Fairytale:shadow
--      ["Uhmm, it's … uhm … my ring!"] = "", -- A_Classic_Fairytale:queen
--      ["Uhmm...ok no."] = "", -- A_Classic_Fairytale:enemy
--      ["Ukemi"] = "", -- 
--      ["Ultra kill!"] = "", -- Mutant
--      ["unC0Rr"] = "", -- 
--      ["Under Construction"] = "", -- A_Classic_Fairytale:shadow
--      ["Under normal circumstances we could easily defeat them but we have kindly sent most of our men to the Kingdom of Sand to help with the annual dusting of the king's palace."] = "", -- A_Space_Adventure:fruit01
--      ["Under the meteorite’s shadow ..."] = "", -- A_Space_Adventure:cosmos
--      ["Under the meteorites shadow ..."] = "", -- A_Space_Adventure:cosmos
--      ["Unexpected Igor"] = "", -- A_Classic_Fairytale:dragon
--      ["Unique new weapons"] = "", -- Continental_supplies
--      ["Unit 0x0007"] = "", -- A_Classic_Fairytale:family
--      ["Unit 189"] = "", -- 
--      ["Unit 234"] = "", -- 
--      ["Unit 333"] = "", -- 
--      ["Unit 334a$7%;.*"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:family, A_Classic_Fairytale:queen, A_Classic_Fairytale:united
      ["Unit 3378"] = "Юнит 3378",
--      ["Unit 485"] = "", -- 
--      ["Unit 527"] = "", -- 
--      ["Unit 638"] = "", -- 
--      ["Unit 709"] = "", -- 
      ["Unit 835"] = "Юнит 835", -- User_Mission_-_Bamboo_Thicket
--      ["Unit 881"] = "", -- User_Mission_-_Newton_and_the_Hammock
--      ["Unit 883"] = "", -- 
--      ["United We Stand"] = "", -- A_Classic_Fairytale:united
      ["Unit"] = "Юнит", -- User_Mission_-_Newton_and_the_Hammock
--      ["Unlike bazookas, grenades are not influenced by wind."] = "", -- Basic_Training_-_Grenade
--      ["Unlimited Attacks: Attacks don't end your turn"] = "", -- User_Mission_-_Diver, User_Mission_-_Nobody_Laugh, User_Mission_-_Spooky_Tree
      ["Unlucky Sods"] = "Неудачники", -- User_Mission_-_Rope_Knock_Challenge
--      ["Unstoppable!"] = "",
      ["Unsuspecting Louts"] = "Доверчивые хамы", -- User_Mission_-_Rope_Knock_Challenge
--      ["Up/Down: Adjust dust storm damage"] = "", -- Continental_supplies
--      ["Up/Down: Browse through continents"] = "", -- Continental_supplies
--      ["Up/Down: Change placement mode"] = "", -- HedgeEditor
--      ["Up/down: Choose crate type"] = "", -- Construction_Mode
--      ["Up/down: Choose object type|1-5/Switch/Left/Right: Choose mine timer|Cursor: Place object"] = "", -- Construction_Mode
      ["Upper-class elite pilot"] = "Элитный пилот высшего класса", -- User_Mission_-_RCPlane_Challenge
--      ["Upside-Down World"] = "", -- Continental_supplies
--      ["Use it wisely!"] = "", -- A_Classic_Fairytale:dragon
--      ["Use it with precaution!"] = "", -- A_Classic_Fairytale:first_blood
      ["User Challenge"] = "Одиночная Миссия",
--      ["!"] = "", -- User_Mission_-_Dangerous_Ducklings
--      ["User Mission"] = "", -- HedgeEditor
--      ["Use the attack key twice to change the flying saucer while being in air."] = "", -- A_Space_Adventure:ice02
--      ["Use the attack key twice to change the flying saucer while floating in mid-air."] = "", -- A_Space_Adventure:ice02
--      ["Use the bazooka and the flying saucer to get the freezer."] = "", -- A_Space_Adventure:ice01
--      ["Use the flying saucer from the crate to fly to the moon."] = "", -- A_Space_Adventure:cosmos
--      ["Use the flying saucer to fly the other planets."] = "", -- A_Space_Adventure:cosmos
--      ["Use the flying saucer to fly to the other planets."] = "", -- A_Space_Adventure:cosmos
--      ["Use the parachute to get the next crate."] = "", -- A_Classic_Fairytale:first_blood
--      ["Use the portal gun to get to the next crate, then use the new gun to get to the final destination!|"] = "", -- A_Classic_Fairytale:dragon
--      ["Use the RC plane and destroy the all the targets."] = "", -- A_Space_Adventure:desert03
--      ["Use the rope in order to catch the blue hedgehog"] = "", -- A_Space_Adventure:moon02
--      ["Use the rope to complete the obstacle course!"] = "", -- Basic_Training_-_Rope
--      ["Use the rope to get on the head of the mole, young one!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Use the rope to get to the crate"] = "", -- A_Space_Adventure:cosmos
--      ["Use the rope to get to the target!"] = "", -- Basic_Training_-_Rope
      ["Use the rope to knock your enemies to their doom."] = "Используйте веревку, чтобы сбить врагов к их гибели.", -- User_Mission_-_Rope_Knock_Challenge
--      ["Use the rope to quickly get to the surface!"] = "", -- A_Space_Adventure:desert02
--      ["Use the saucer and fly away"] = "", -- A_Space_Adventure:cosmos
--      ["Use the saucer and fly to the moon"] = "", -- A_Space_Adventure:cosmos
--      ["Use the shield to protect yourself from bazookas."] = "", -- Space_Invasion
--      ["Use the structure placer to place structures."] = "", -- Construction_Mode
--      ["Use your ammo wisely."] = "", -- A_Space_Adventure:desert01
--      ["Use your available weapons in order to eliminate the enemies."] = "", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
--      ["Use your ready time to think."] = "", -- Frenzy
      ["Use your rope to collect all crates as fast as possible."] = "Используйте веревку, чтобы собрать все ящики как можно быстрее.", -- SpeedShoppa
      ["Use your rope to get from start to finish as fast as you can!"] = "Используй веревку, чтобы добраться от старта до финиша как можно быстрее!",
--      ["Use your rope to get to the next target, then destroy it!"] = "", -- Basic_Training_-_Rope
--      ["UTILITY CRATE PLACEMENT MODE"] = "", -- HedgeEditor
      ["Utility Crate Placement Mode"] = "Режим Размещения Ящиков с Утилитами", -- Construction_Mode
--      ["Utility crates extend your time."] = "", -- Tumbler
--      ["Variants: Hogs will be randomized from 12 different variants"] = "", -- Battalion
--      ["Variants: Kings and air generals are disabled"] = "", -- Battalion
--      ["Variants: The last hog of each team will be a king"] = "", -- Battalion
--      ["Vedgies"] = "", -- A_Classic_Fairytale:journey
--      ["Vega"] = "", -- 
--      ["Vegan Jack"] = "", -- A_Classic_Fairytale:enemy
--      ["Very valuable, haha!"] = "", -- A_Classic_Fairytale:queen
--      ["Victory Condition: Collect"] = "", -- HedgeEditor
--      ["Victory Condition: Destroy"] = "", -- HedgeEditor
--      ["Victory for %s!"] = "", -- Capture_the_Flag
      ["Victory!"] = "Победа!", -- Basic_Training_-_Rope
--      ["Violence is not the answer to your problems!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Visit the planets of Ice, Desert and Fruit before you proceed to the Death Planet"] = "", -- A_Space_Adventure:cosmos
--      ["Vladimir"] = "", -- 
--      ["Void"] = "", -- Big_Armory
--      ["Voldemort"] = "", -- portal
--      ["Voltorb"] = "", -- 
--      ["Wait a moment …"] = "", -- A_Space_Adventure:final
--      ["Walking on Ice"] = "", -- Basic_Training_-_Movement
--      ["Walk: [Left] and [Right]"] = "", -- Basic_Training_-_Movement
--      ["Walk: [Left]/[Right]"] = "", -- Basic_Training_-_Bazooka
--      ["Wall Before Crate: You must touch the marked wall before you can get crates."] = "", -- WxW
--      ["Walls Before Crate: You must touch the %d marked walls before you can get crates."] = "", -- WxW
--      ["Wall set: No walls"] = "", -- WxW
--      ["Wall set: %s (%d walls)"] = "", -- WxW
--      ["Wall set: %s"] = "", -- WxW
--      ["Walls left: %d"] = "", -- WxW
--      ["Wall to wall"] = "", -- WxW
--      ["Waluigi"] = "", -- 
--      ["Wario"] = "", -- 
--      ["Warming Up"] = "", -- Basic_Training_-_Grenade
--      ["Warning: Fire cake detected"] = "", -- ClimbHome
--      ["Warning: Never ever leave the flying saucer while in water!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["WARNING: Sabotage detected!"] = "", -- Continental_supplies
--      ["Warrior"] = "", -- Battalion
--      [" was extracted from the scheme|- This continent will be able to use the specials from the other continents!"] = "", -- Continental_supplies
--      ["WatchBot 4000"] = "", -- User_Mission_-_Teamwork_2
--      ["Watch your steps, young one!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Watermelon Heart"] = "", -- A_Space_Adventure:fruit02
--      ["Water: Rises by 37 per turn"] = "", -- Battalion
--      ["Waypoint Editing Mode"] = "", -- HedgeEditor
--      ["WAYPOINT EDITING MODE"] = "", -- HedgeEditor
--      ["Waypoint placed. Available points remaining: %d"] = "", -- Racer
--      ["Waypoint placement phase"] = "", -- Racer
--      ["Waypoint removed. Available points: %d"] = "", -- Racer
--      ["Waypoints remaining: %d"] = "", -- Racer, TechRacer
--      ["Weaklings"] = "", -- A_Classic_Fairytale:shadow
--      ["We all know what happens when you get frightened..."] = "", -- A_Classic_Fairytale:first_blood
--      ["WEAPON CRATE PLACEMENT MODE"] = "", -- HedgeEditor
      ["Weapon Crate Placement Mode"] = "Режим Размещения Ящиков с Оружием", -- Construction_Mode
--      ["Weapon Filter: Dematerializes all ammo|    carried by enemies entering it."] = "", -- Construction_Mode
      ["Weapon Filter"] = "Фильтр Оружия", -- Construction_Mode
--      ["weaponschemes"] = "", -- Continental_supplies
--      ["Weapons: Each team starts with %d weapon points"] = "", -- Battalion
--      ["Weapons: Hogs will get 1 out of 3 weapons randomly each turn"] = "", -- Battalion
--      ["Weapons: Nearly every hog variant gets 1 kamikaze"] = "", -- Battalion
--      ["Weapon specials: Some weapons have special modes (see weapon description)."] = "", -- Continental_supplies
--      ["Weapons reset: The weapons are reset after each turn."] = "", -- WxW
--      ["We are indeed."] = "", -- A_Classic_Fairytale:backstab
--      ["We can't defeat them!"] = "", -- A_Classic_Fairytale:shadow
--      ["We can't hold them up much longer!"] = "", -- A_Classic_Fairytale:united
--      ["We can't let them take over our little island!"] = "", -- A_Classic_Fairytale:enemy
--      ["We come in peace! Just let our friends go!"] = "", -- A_Classic_Fairytale:queen
--      ["We could just have blown up the meteorite from the the beginning!"] = "", -- A_Space_Adventure:final
--      ["We don't have time for that now!"] = "", -- A_Classic_Fairytale:queen
--      ["We have lost an object which was critical to this mission."] = "", -- SimpleMission
--      ["We have no time to waste..."] = "", -- A_Classic_Fairytale:journey
--      ["We have nowhere else to live!"] = "", -- A_Classic_Fairytale:enemy
--      ["We have spotted the enemy! We'll attack when the enemies start gathering!"] = "", -- A_Space_Adventure:fruit02
--      ["We have to find our folk!"] = "", -- A_Classic_Fairytale:queen
--      ["We have to hurry! Are you armed?"] = "", -- A_Space_Adventure:moon01
--      ["We have to protect the village!"] = "", -- A_Classic_Fairytale:united
--      ["We have to unite and defeat those cylergs!"] = "", -- A_Classic_Fairytale:enemy
--      ["Welcome home! Please take a seat"] = "", -- ClimbHome
--      ["Welcome, Leaks A Lot!"] = "", -- A_Classic_Fairytale:journey
--      ["Welcome, %s, surprised to see me?"] = "", -- A_Space_Adventure:death01
--      ["Welcome to the Death Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["Welcome to the Desert Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["Welcome to the Fruit Planet!"] = "", -- A_Space_Adventure:cosmos
--      ["Welcome to the meteorite!"] = "", -- A_Space_Adventure:cosmos
--      ["Welcome to the moon!"] = "", -- A_Space_Adventure:cosmos
--      ["Welcome to the Planet of Ice!"] = "", -- A_Space_Adventure:cosmos
--      ["Well done! Let's destroy the next target!"] = "", -- Basic_Training_-_Rope
--      ["Well done! The next target awaits."] = "", -- Basic_Training_-_Rope
      ["Well done."] = "Отлично.",
--      ["We'll give you a problem then!"] = "", -- A_Classic_Fairytale:enemy
--      ["We'll play a game first."] = "", -- A_Space_Adventure:moon02
--      ["We'll spare your life for now!"] = "", -- A_Classic_Fairytale:backstab
--      ["Well, that escalated quickly!"] = "", -- ClimbHome
--      ["Well that was an unnecessary act of violence."] = "", -- A_Classic_Fairytale:epil
--      ["Well, that was an unnecessary act of violence."] = "", -- A_Classic_Fairytale:epil
--      ["Well, that was a waste of time."] = "", -- A_Classic_Fairytale:dragon
--      ["We'll use our communicators to contact you."] = "", -- A_Space_Adventure:cosmos
--      ["Well, well! Isn't that the cutest thing you've ever seen?"] = "", -- A_Classic_Fairytale:journey
--      ["Well, yes. This was a cyborg television show."] = "", -- A_Classic_Fairytale:enemy
--      ["Well, you're about to wake up!"] = "", -- A_Classic_Fairytale:queen
--      ["We made sure noone followed us!"] = "", -- A_Classic_Fairytale:backstab
--      ["We need it to get split into at least two parts."] = "", -- A_Space_Adventure:cosmos
--      ["We need to go back!"] = "", -- A_Classic_Fairytale:queen
--      ["We need to hurry!"] = "", -- A_Classic_Fairytale:queen
--      ["We need to move!"] = "", -- A_Classic_Fairytale:united
--      ["We need to prevent their arrival!"] = "", -- A_Classic_Fairytale:backstab
--      ["We need to warn the village."] = "", -- A_Classic_Fairytale:shadow
--      ["We need you to go there and detonate them yourself! Good luck!"] = "", -- A_Space_Adventure:cosmos
--      ["We oppressed her, the only woman in the tribe!"] = "", -- A_Classic_Fairytale:epil
--      ["We're terribly sorry!"] = "", -- A_Classic_Fairytale:epil
--      ["We risk our lives going through challenges."] = "", -- A_Classic_Fairytale:queen
--      ["We should better report this and continue our watch!"] = "", -- A_Space_Adventure:cosmos
--      ["We should head back to the village now."] = "", -- A_Classic_Fairytale:shadow
--      ["We, the youth, have to constantly prove our value."] = "", -- A_Classic_Fairytale:queen
--      ["We trusted you, you fool!"] = "", -- A_Classic_Fairytale:queen
--      ["We were trying to save her and we got lost."] = "", -- A_Classic_Fairytale:family
--      ["We were your home! Your family!"] = "", -- A_Classic_Fairytale:queen
--      ["We won't accept you destroying our village!"] = "", -- A_Classic_Fairytale:queen
--      ["We won't let you hurt any more of us!"] = "", -- A_Classic_Fairytale:queen
--      ["We won't let you hurt her!"] = "", -- A_Classic_Fairytale:journey
--      ["We work and work until we sweat blood."] = "", -- A_Classic_Fairytale:queen
--      ["What?! A cannibal? Here? There is no time to waste! Come, you are prepared."] = "", -- A_Classic_Fairytale:first_blood
--      ["What?!"] = "", -- A_Classic_Fairytale:queen
--      ["What a douche!"] = "", -- A_Classic_Fairytale:enemy
--      ["What am I gonna...eat, yo?"] = "", -- A_Classic_Fairytale:family
--      ["What are you doing at a distance so great, young one?"] = "", -- A_Classic_Fairytale:first_blood
--      ["What are you doing? Let her go!"] = "", -- A_Classic_Fairytale:journey
--      ["What a ride!"] = "", -- A_Classic_Fairytale:shadow
--      ["What a strange cave!"] = "", -- A_Classic_Fairytale:dragon
--      ["What a strange feeling!"] = "", -- A_Classic_Fairytale:backstab
--      ["What could you possibly forget in that cage?"] = "", -- A_Classic_Fairytale:queen
--      ["What does it look like?"] = "", -- A_Classic_Fairytale:queen
--      ["What do my faulty eyes observe? A spy!"] = "", -- A_Classic_Fairytale:first_blood
--      ["What do you say? Are you in?"] = "", -- A_Space_Adventure:fruit02
--      ["What do you say? Will you fight for us?"] = "", -- A_Space_Adventure:fruit01
--      ["What do you want to do?"] = "", -- A_Space_Adventure:fruit01
--      ["Whatever floats your boat..."] = "", -- A_Classic_Fairytale:shadow
--      ["What?! For all this struggle I just win some ... time? Oh dear!"] = "", -- portal
--      ["What has %s ever done to you?"] = "", -- A_Classic_Fairytale:backstab
--      ["What? Here? How did they find us?!"] = "", -- A_Classic_Fairytale:backstab
--      ["What? Is it over already?"] = "", -- ClimbHome
--      ["What is it that you forgot?"] = "", -- A_Classic_Fairytale:queen
--      ["What is this place?"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy
--      ["What oppression? You were the most unoppressed member of the tribe!"] = "", -- A_Classic_Fairytale:queen
--      ["What shall we do with the traitor?"] = "", -- A_Classic_Fairytale:backstab
--      ["What's in the box, you ask? Let's find out!"] = "", -- Basic_Training_-_Movement
--      ["What the?"] = "", -- A_Classic_Fairytale:queen
--      ["WHAT?! You're the ones attacking us!"] = "", -- A_Classic_Fairytale:enemy
--      ["When?"] = "", -- A_Classic_Fairytale:enemy
--      ["When I find it..."] = "", -- A_Classic_Fairytale:dragon
--      ["When you're in mid-air, you can continue to aim|and fire another rope if you're not attached."] = "", -- Basic_Training_-_Rope
--      ["Where are all these crates coming from?!"] = "", -- A_Classic_Fairytale:shadow
--      ["Where are they?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Where did that alien run?"] = "", -- A_Classic_Fairytale:dragon
--      ["Where did you get the exploding apples?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the exploding apples and the magic bow that shoots many arrows?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the magic bow that shoots many arrows?"] = "", -- A_Classic_Fairytale:shadow
--      ["Where did you get the weapons in the forest, Dense Cloud?"] = "", -- A_Classic_Fairytale:backstab
--      ["Where do you get that?!"] = "", -- A_Classic_Fairytale:enemy
--      ["Where have you been?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Where have you been?"] = "", -- A_Classic_Fairytale:united
--      ["While in modification mode, you can change|the LandFlag by clicking on an object."] = "", -- HedgeEditor
--      ["White Tee"] = "", -- A_Space_Adventure:ice01
--      ["Who's there?! I'll get you!"] = "", -- A_Space_Adventure:desert01
--      ["Why?"] = "", -- A_Classic_Fairytale:queen
--      ["Why are you doing this?"] = "", -- A_Classic_Fairytale:journey
--      ["Why are you helping us, uhm...?"] = "", -- A_Classic_Fairytale:family
--      ["Why can't he just let her go?!"] = "", -- A_Classic_Fairytale:family
--      ["… why did I risk my life to collect all the parts of the anti-gravity device?"] = "", -- A_Space_Adventure:final
--      ["Why did you do this?"] = "", -- A_Classic_Fairytale:queen
--      ["Why did you kill your father?"] = "", -- A_Classic_Fairytale:queen
--      ["Why do men keep hurting me?"] = "", -- A_Classic_Fairytale:first_blood
--      ["Why do you always have to call me names?"] = "", -- A_Classic_Fairytale:queen
--      ["Why do you keep betraying us?"] = "", -- A_Classic_Fairytale:queen
--      ["Why do you not like me?"] = "", -- A_Classic_Fairytale:shadow
--      ["Why do you want to take over our island?"] = "", -- A_Classic_Fairytale:enemy
--      ["Why me?!"] = "", -- A_Classic_Fairytale:backstab
--      ["Why %s? Why?"] = "", -- A_Classic_Fairytale:backstab
--      ["Why, why, why, why!"] = "", -- A_Classic_Fairytale:queen
--      ["Why would they do this?"] = "", -- A_Classic_Fairytale:backstab
--      ["- Will get 1-3 random weapons"] = "", -- Continental_supplies
--      ["- Will Get 1-3 random weapons"] = "", -- Continental_supplies
--      ["- Will give you a parachute every second turn."] = "", -- Continental_supplies
      ["Will this ever end?"] = "Когда уже конец?",
--      ["Will you give me the other parts?"] = "", -- A_Space_Adventure:death01
--      ["Win"] = "", -- A_Space_Adventure:ice01
--      ["Wind"] = "", -- Basic_Training_-_Bazooka
--      ["Winner: %s"] = "", -- Mutant
--      ["Winning time: %s"] = "", -- Racer, TechRacer
--      ["Wise Oak"] = "", -- A_Classic_Fairytale:backstab, A_Classic_Fairytale:dragon, A_Classic_Fairytale:enemy, A_Classic_Fairytale:epil, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
--      ["With Dense Cloud on the land of shadows, I'm the village's only hope..."] = "", -- A_Classic_Fairytale:journey
--      ["With low bounciness, it barely bounces at all, but it is much more predictable."] = "", -- Basic_Training_-_Grenade
--      ["With the rest of the tribe gone, it was up to %s to save the village."] = "", -- A_Classic_Fairytale:dragon
--      ["Worry not, for it is a peaceful animal! There is no reason to be afraid..."] = "", -- A_Classic_Fairytale:first_blood
--      ["Wow, what a dream!"] = "", -- A_Classic_Fairytale:backstab
--      ["Xeli"] = "", -- 
--      ["Xerxes"] = "", -- 
--      ["Y3K1337"] = "", -- A_Classic_Fairytale:journey, A_Classic_Fairytale:shadow
--      ["Yay, we won!"] = "", -- A_Classic_Fairytale:enemy
--      ["Y Chwiliad"] = "", -- A_Classic_Fairytale:dragon
--      ["Yeah...I think it's a 'he', lol."] = "", -- A_Classic_Fairytale:shadow
--      ["Yeah, sure! I died. Hilarious!"] = "", -- A_Classic_Fairytale:backstab
--      ["Yeah, sure! I died. Hillarious!"] = "", -- A_Classic_Fairytale:backstab
--      ["Yeah, take that!"] = "", -- A_Classic_Fairytale:dragon
--      ["Yeah? Watcha gonna do? Cry?"] = "", -- A_Classic_Fairytale:journey
--      ["Yeah, well, for some dude to be happy, some other dude has to suffer."] = "", -- A_Classic_Fairytale:queen
--      ["Yellow"] = "", -- 
--      ["Yellow Pepper"] = "", -- A_Space_Adventure:fruit01
--      ["Yellow Watermelons"] = "", -- A_Space_Adventure:fruit01
--      ["Yes!"] = "", -- A_Classic_Fairytale:enemy
--      ["Yes, but you're … different!"] = "", -- A_Classic_Fairytale:queen
--      ["Yes, yeees! You are now ready to enter the real world!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Yeti"] = "", -- 
--      ["Yikes!"] = "", -- A_Space_Adventure:desert01
--      ["Yo, dude! Get away from our weapons!"] = "", -- A_Classic_Fairytale:queen
--      ["Yo, dude, we're here, too!"] = "", -- A_Classic_Fairytale:family
--      ["Yo, escort my buttocks!"] = "", -- A_Classic_Fairytale:queen
--      ["Yoshi"] = "", -- 
--      ["Yo, the aliens gave me plants. Medicinal plants. Lots of it."] = "", -- A_Classic_Fairytale:queen
--      ["You are far from home, and the water is rising, climb up as high as you can!|Your score will be based on your height."] = "", -- ClimbHome
--      ["You are given the chance to turn your life around..."] = "", -- A_Classic_Fairytale:shadow
--      ["You are in control of all the active ally units."] = "", -- A_Space_Adventure:fruit01
--      ["You are indeed the best PAotH pilot."] = "", -- A_Space_Adventure:desert03
--      ["You are out of danger, time to go to the moon!"] = "", -- A_Space_Adventure:cosmos
--      ["You are playing with our lives here!"] = "", -- A_Classic_Fairytale:enemy
--      ["You are sabotaged, RUN!"] = "", -- Continental_supplies
--      ["You are the one who fled! So, you are alive."] = "", -- A_Space_Adventure:fruit02
--      ["You bear impressive skills, %s!"] = "", -- A_Classic_Fairytale:dragon
--      ["You can also hold down the key for “Precise Aim” to prevent slipping."] = "", -- Basic_Training_-_Movement
--      ["You can always trust me!"] = "", -- A_Classic_Fairytale:epil
--      ["You can always trust me! I love you!"] = "", -- A_Classic_Fairytale:epil
--      ["You can avoid some battles."] = "", -- A_Space_Adventure:desert01
--      ["You can change the detonation timer of grenades."] = "", -- Basic_Training_-_Grenade
--      ["You can choose another planet by replaying this mission."] = "", -- A_Space_Adventure:cosmos
--      ["You can dive with your flying saucer!"] = "", -- Basic_Training_-_Flying_Saucer
--      ["You can even change your aiming direction in mid-flight if you first hold [Precice] and then press [Up] or [Down]."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You can even change your aiming direction in mid-flight if you first hold [Precise] and then press [Up] or [Down]."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You can further customize the race by changing the scheme script paramater."] = "", -- TechRacer
--      ["You can further customize the race by changing the scheme script parameter."] = "", -- TechRacer
--      ["You can only use the sniper rifle or the watermelon bomb."] = "", -- A_Space_Adventure:fruit03
--      ["You can practice moving around and using utilities in this mission.|However, it will never end!"] = "", -- A_Classic_Fairytale:epil
--      ["You can set the bounciness of grenades (and grenade-like weapons)."] = "", -- Basic_Training_-_Grenade
--      ["- You can switch between hogs at the start of your turns. (Not first one)"] = "", -- Continental_supplies
--      ["You can’t open a portal on the blue surface."] = "", -- portal
--      ["You can use the other 2 hogs to assist you."] = "", -- A_Space_Adventure:fruit02
--      ["You can use the rope to reach new places."] = "", -- Basic_Training_-_Rope
--      ["You choose well, %s!"] = "", -- A_Space_Adventure:fruit01
--      ["You completed the mission in %.3f seconds."] = "", -- A_Space_Adventure:ice02
--      ["You completed the mission in %d rounds."] = "", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
--      ["You couldn't have come to a worse time, %s!"] = "", -- A_Space_Adventure:fruit01
--      ["You couldn't possibly believe that after refusing my offer I'd just let you go!"] = "", -- A_Classic_Fairytale:journey
      ["You'd almost swear the water was rising!"] = "Могу поклясться, что вода прибывает!",
--      ["You'd better watch your steps..."] = "", -- A_Classic_Fairytale:journey
--      ["You defended yourself against Captain Lime."] = "", -- A_Space_Adventure:fruit02
--      ["You defended yourself against %s."] = "", -- A_Space_Adventure:fruit02
--      ["You did great, %s! However, we aren't out of danger yet!"] = "", -- A_Space_Adventure:cosmos
      ["You did not make it in time, try again!"] = "Время вышло, попробуй еще раз!", -- Basic_Training_-_Rope
--      ["You don't deserve my sacrifice!"] = "", -- A_Classic_Fairytale:queen
--      ["You drove Professor Hogevil away."] = "", -- A_Space_Adventure:moon01
--      ["You drove the minions away."] = "", -- A_Space_Adventure:moon01
--      ["You earned the \"Rope Master\" achievement for finishing in under 50 seconds."] = "", -- Basic_Training_-_Rope
--      ["You endangered your whole tribe, you bastard!"] = "", -- A_Classic_Fairytale:queen
--      ["You failed!"] = "", -- Basic_Training_-_Rope
--      ["You failed to kill all enemies in a single turn."] = "", -- Big_Armory
--      ["You failed to kill all enemies in this turn."] = "", -- Big_Armory
--      ["You fought bravely and you helped us win this battle!"] = "", -- A_Space_Adventure:fruit02
--      ["You give me no choice!"] = "", -- A_Classic_Fairytale:queen
--      ["You got a killer mask there, amigo!"] = "", -- A_Classic_Fairytale:epil
--      ["You got me!"] = "", -- A_Space_Adventure:moon02
      ["You had %.1fs remaining on the clock (+%d points)."] = "У вас оставалось %.1f секунд на таймере (+%d очков).", -- TargetPractice      
      ["You had %.2fs remaining on the clock (+%d points)."] = "У вас оставалось %.2f секунд на таймере (+%d очков).", -- Basic_Training_-_Sniper_Rifle
--      ["You have 7 turns until the next wave arrives.|Make sure the arriving cannibals are greeted appropriately!|If the hog dies, the cause is lost.|Hint: you might want to use some mines..."] = "", -- A_Classic_Fairytale:backstab
--      ["You have 7 turns until the next wave arrives.|Make sure the arriving cannibals are greeted appropriately!|If the hog dies, the cause is lost.|Hint: You might want to use some mines ..."] = "", -- A_Classic_Fairytale:backstab
--      ["You have acquired the last device part."] = "", -- A_Space_Adventure:death01
--      ["You have activated Switch Hedgehog!"] = "", -- Basic_Training_-_Movement
--      ["You have beaten the challenge!"] = "", -- ClimbHome
--      ["You have beaten the team record, congratulations!"] = "", -- Utils
--      ["You have been giving us out to the enemy, haven't you!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have chosen the perfect moment to leave."] = "", -- A_Classic_Fairytale:united
--      ["You have chosen to fight!"] = "", -- A_Space_Adventure:fruit01
--      ["You have chosen to flee."] = "", -- A_Space_Adventure:fruit01
      ["You have collected %d out of %d crate(s)."] = "Вы собрали %d из %d ящиков.", -- SpeedShoppa
--      ["You have collected the “Switch Hedgehog” utility!"] = "", -- Basic_Training_-_Movement
--      ["You have completed the Basic Bazooka Training!"] = "", -- Basic_Training_-_Bazooka
--      ["You have completed the Basic Grenade Training!"] = "", -- Basic_Training_-_Grenade
--      ["You have completed the Basic Movement Training!"] = "", -- Basic_Training_-_Movement
--      ["You have completed this challenge in %.2f s (+%d points)."] = "", -- User_Mission_-_Rope_Knock_Challenge
--      ["You have destroyed all targets!"] = "", -- TargetPractice
--      ["You have destroyed all the targets."] = "", -- A_Space_Adventure:desert03
      ["You have destroyed %d of %d targets (+%d points)."] = "Вы уничтожили %d из %d целей (+%d очков).", -- Basic_Training_-_Sniper_Rifle
      ["You have destroyed %d of %d targets."] = "Вы уничтожили %d из %d целей.", -- Basic_Training_-_Bazooka
      ["You have dropped %d missiles."] = "Вы запустили %d ракет.", -- User_Mission_-_RCPlane_Challenge
--      ["You have eliminated all visible enemy hedgehogs!"] = "", -- A_Space_Adventure:fruit01
--      ["You have eliminated Professor Hogevil."] = "", -- A_Space_Adventure:moon01
--      ["You have eliminated the evil minions."] = "", -- A_Space_Adventure:moon01
--      ["You have escaped successfully."] = "", -- A_Space_Adventure:desert02
--      ["You have failed to complete your task, young one!"] = "", -- A_Classic_Fairytale:journey
--      ["You have failed to save the tribe!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have finally figured it out!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have finished the Basic Rope Training!"] = "", -- Basic_Training_-_Rope
      ["You have finished the bazooka training!"] = "Вы прошли тренировку с базукой!", -- Basic_Training_-_Bazooka
      ["You have finished the challenge in %.3f s."] = "Вы прошли испытание за %.3f сек.", -- SpeedShoppa
      ["You have finished the challenge!"] = "Вы прошли испытание!", -- User_Mission_-_RCPlane_Challenge
--      ["You have finished the Flying Saucer Training!"] = "", -- Basic_Training_-_Flying_Saucer
      ["You have finished the target practice!"] = "Вы завершили учебную стрельбу!", -- TargetPractice
--      ["You have kidnapped our whole tribe!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have killed all enemies."] = "", -- Big_Armory
--      ["You have killed an innocent hedgehog!"] = "", -- A_Classic_Fairytale:backstab
--      ["You have killed %d of 16 hedgehogs (+%d points)."] = "", -- User_Mission_-_Rope_Knock_Challenge
      ["You have launched %d bazookas."] = "Вы запустили %d базук.", -- Basic_Training_-_Bazooka
      ["You have launched %d homing bees."] = "Вы запустили %d пчёлок.", -- Target_Practice_-_Homing_Bee
      ["You have made %d shots."] = "Вы сделали %d выстрелов.", -- Basic_Training_-_Sniper_Rifle
--      ["You have managed to catch the blue hedgehog in %.3f seconds."] = "", -- A_Space_Adventure:moon02
--      ["You have never worked a bit in your life!"] = "", -- A_Classic_Fairytale:queen
--      ["You have nothing to be afraid of now."] = "", -- A_Classic_Fairytale:epil
      ["You haven't rescued anyone."] = "Вы никого не спасли.", -- User_Mission_-_That_Sinking_Feeling
      ["You have perfectly beaten the challenge!"] = "Вы прекрасно прошли испытание!", -- User_Mission_-_RCPlane_Challenge
--      ["You have proven yourself worthy to see our most ancient secret!"] = "", -- A_Classic_Fairytale:first_blood
--      ["You have proven yourselves worthy!"] = "", -- A_Classic_Fairytale:enemy
--      ["You have reached the take-off area successfully!"] = "", -- A_Space_Adventure:fruit01
--      ["You have rescued H and Dr. Cornelius."] = "", -- A_Space_Adventure:death01
      ["You have SCORED!!"] = "Вы доставили флаг!!",
      ["You have shot %d times."] = "Вы выстрелили %d раз.", -- TargetPractice
--      ["You have successfully eliminated Professor Hogevil."] = "", -- A_Space_Adventure:death01
--      ["You have successfully finished the campaign!"] = "", -- A_Classic_Fairytale:epil
      ["You have successfully finished the sniper rifle training!"] = "Вы успешно завершили тренировку со снайперской винтовкой!", -- Basic_Training_-_Sniper_Rifle
--      ["You have thrown %d cluster bombs."] = "", -- Target_Practice_-_Cluster_Bomb
      ["You have thrown %d grenades."] = "Вы бросили %d гранат.", -- Target_Practice_-_Grenade_easy, Target_Practice_-_Grenade_hard
--      ["You have to be careful and must not die!"] = "", -- A_Space_Adventure:cosmos
--      ["You have to catch the other hog 3 times."] = "", -- A_Space_Adventure:moon02
--      ["You have to complete the main mission on moon in order to travel to other planets."] = "", -- A_Space_Adventure:cosmos
--      ["You have to continue alone from now on."] = "", -- A_Space_Adventure:cosmos
--      ["You have to destroy all the explosives without dying!"] = "", -- A_Space_Adventure:final
--      ["You have to destroy all the targets."] = "", -- A_Space_Adventure:desert03
--      ["You have to destroy the target above by dropping a grenade on it from your flying saucer."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You have to destroy two targets, but the previous technique would be very difficult or dangerous to use."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You have to drop the grenade from rope!"] = "", -- Basic_Training_-_Rope
--      ["You have to eliminate all the enemies."] = "", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
--      ["You have to eliminate all the visible enemies."] = "", -- A_Space_Adventure:fruit01
--      ["You have to get the weapons and rescue the PAotH researchers."] = "", -- A_Space_Adventure:moon01
--      ["You have to get to the left-most land and remove any enemy hog from there."] = "", -- A_Space_Adventure:fruit01
--      ["You have to go back to the moon!"] = "", -- A_Space_Adventure:cosmos
--      ["You have to move upwards, not downwards, %s!"] = "", -- ClimbHome
--      ["You have to reach the left-most place on the map."] = "", -- A_Space_Adventure:fruit01
--      ["You have to stand very close to him"] = "", -- A_Space_Adventure:moon02
--      ["You have to travel again"] = "", -- A_Space_Adventure:cosmos
--      ["You have to try again!"] = "", -- A_Space_Adventure:cosmos
--      ["You have triggered the secret Do-Not-Rope-to-the-Moon Defense System."] = "", -- A_Space_Adventure:cosmos
--      ["You have unlocked the target radar!"] = "", -- TargetPractice
--      ["You have used %d flying saucers."] = "", -- A_Space_Adventure:ice02
      ["You have used %d RC planes."] = "Вы использовали %d самолётов.", -- User_Mission_-_RCPlane_Challenge
      ["You have used only 1 RC plane. Outstanding!"] = "Вы использовали всего 1 самолёт. Выдающееся достижение!", -- User_Mission_-_RCPlane_Challenge
      ["You have violated PAotH regulations!"] = "Вы нарушили правила ПАЕ!", -- A_Space_Adventure:cosmos
--      ["You have won the game by proving true cooperative skills!"] = "", -- A_Classic_Fairytale:enemy
--      ["You just appeared out of thin air!"] = "", -- A_Classic_Fairytale:backstab
--      ["You just can't let it go, can you!"] = "", -- A_Classic_Fairytale:queen
--      ["You just committed suicide..."] = "", -- A_Classic_Fairytale:shadow
--      ["You just got yourself some extra health.|The more health your hedgehogs have, the better!"] = "", -- Basic_Training_-_Movement
--      ["You killed my father, you monster!"] = "", -- A_Classic_Fairytale:backstab
--      ["You know...taking a stroll."] = "", -- A_Classic_Fairytale:backstab
--      ["You know what? I don't even regret anything!"] = "", -- A_Classic_Fairytale:backstab
--      ["You'll get an extra sniper rifle every time you kill an enemy hog with a limit of max 4 rifles."] = "", -- A_Space_Adventure:fruit03
--      ["You'll get an extra teleport every time you kill an enemy hog with a limit of max 2 teleports."] = "", -- A_Space_Adventure:fruit03
--      ["You'll get extra time in case you need it when you pass a ring."] = "", -- A_Space_Adventure:ice02
--      ["You'll have only 2 watermelon bombs during the game."] = "", -- A_Space_Adventure:fruit03
--      ["You'll have only one RC plane at the start of the mission."] = "", -- A_Space_Adventure:desert03
--      ["You'll have to eliminate Captain Lime at the end."] = "", -- A_Space_Adventure:fruit02
--      ["You'll have to eliminate %s at the end."] = "", -- A_Space_Adventure:fruit02
--      ["You'll lose if you die or if your time is up."] = "", -- A_Space_Adventure:moon02
--      ["You'll see what I mean!"] = "", -- A_Classic_Fairytale:enemy
--      ["You lost your target, try again!"] = "", -- TargetPractice
--      ["You may find it handy."] = "", -- A_Space_Adventure:cosmos
      ["You may only attack from a rope!"] = "Вы можете атаковать только с верёвки!", -- WxW
--      ["You may only place 1 Extra Time crate per turn."] = "", -- Construction_Mode
--      ["You may only place %d crates per round."] = "", -- Construction_Mode
--      ["- You may only score when your flag is in your base"] = "", -- Capture_the_Flag
--      ["You meatbags are pretty slow, you know!"] = "", -- A_Classic_Fairytale:enemy
--      ["You might want to find a way to instantly kill arriving cannibals!"] = "", -- A_Classic_Fairytale:backstab
--      ["You must attack from a rope, after you collected a crate!"] = "", -- WxW
--      ["You must first collect a crate before you attack!"] = "", -- WxW
      ["You must survive the flood in order to score."] = "Вы должны пережить наводнение, чтобы заработать очки.", -- User_Mission_-_That_Sinking_Feeling
--      ["You never give me plants!"] = "", -- A_Classic_Fairytale:queen
--      ["Young one, you are telling us that they can instantly change location without a shaman?"] = "", -- A_Classic_Fairytale:united
--      ["You now have infinite fuel, grenades and bazookas for fun."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You only get 1 rope this time, don't waste it!"] = "", -- Basic_Training_-_Rope
--      ["You only have 2 flying saucers this time."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You only have one flying saucer this time."] = "", -- Basic_Training_-_Flying_Saucer
--      ["You probably know what to do next..."] = "", -- A_Classic_Fairytale:first_blood
      ["Your accuracy was %.1f%% (+%d points)."] = "Ваша точность составила %.1f%% (+%d очков).", -- TargetPractice
      ["Your accuracy was %.1f%%."] = "Ваша точность составила %.1f%%.", -- Basic_Training_-_Bazooka
      ["Your ammo is limited this time."] = "В этот раз ваши боезапасы ограничены.", -- Basic_Training_-_Bazooka
--      ["Your deaths will be avenged, %s!"] = "", -- A_Classic_Fairytale:enemy
--      ["Your death will not be in vain, Dense Cloud!"] = "", -- A_Classic_Fairytale:shadow
--      ["You're a coward!"] = "", -- A_Classic_Fairytale:queen
--      ["You're...alive!? But we saw you die!"] = "", -- A_Classic_Fairytale:backstab
--      ["You're a pathetic liar!"] = "", -- A_Classic_Fairytale:backstab
--      ["You're funny!"] = "", -- A_Classic_Fairytale:journey
--      ["You're getting pretty good! |Tip: When you shorten you rope, you move faster!|And when you lengthen it, you move slower."] = "", -- Basic_Training_-_Rope
--      ["You're on your way to freeing your tribe!"] = "", -- A_Classic_Fairytale:queen
--      ["You're pathetic! You are not worthy of my attention..."] = "", -- A_Classic_Fairytale:shadow
--      ["You're probably wondering why I bought you back..."] = "", -- A_Classic_Fairytale:backstab
--      ["You're probably wondering why I brought you back ..."] = "", -- A_Classic_Fairytale:backstab
--      ["Your escape took you %d turns."] = "", -- A_Space_Adventure:desert02
--      ["You're so brave! I feel safe with you."] = "", -- A_Classic_Fairytale:epil
--      ["You're some piece of hypocrite junkie!"] = "", -- A_Classic_Fairytale:queen
--      ["You're terrorizing the forest...We won't catch anything like this!"] = "", -- A_Classic_Fairytale:shadow
--      ["You retrieved the lost part."] = "", -- A_Space_Adventure:fruit02
--      ["Your fastest escape so far: %d turns"] = "", -- A_Space_Adventure:desert02
--      ["Your fastest victory so far: %d rounds"] = "", -- A_Space_Adventure:death02, A_Space_Adventure:fruit03
--      ["Your first destination is the moon in order to get more fuel."] = "", -- A_Space_Adventure:cosmos
      ["Your hedgehog died!"] = "Ваш ёж умер!", -- User_Mission_-_That_Sinking_Feeling
--      ["Your hedgehog has been revived!"] = "", -- Basic_Training_-_Bazooka, Basic_Training_-_Grenade, Basic_Training_-_Movement, Basic_Training_-_Rope
--      ["Your hedgehog was panicly afraid of the water and decided to go in a safe distance of %d from it."] = "", -- ClimbHome
--      ["Your height over time"] = "", -- ClimbHome
--      ["Your hogs must survive!"] = "", -- A_Classic_Fairytale:journey
--      ["Your movement skills will be evaluated now."] = "", -- A_Classic_Fairytale:first_blood
--      ["Your next task is to collect some crates by using the rope!"] = "", -- A_Classic_Fairytale:first_blood
--      ["Your personal best time so far: %.3f seconds"] = "", -- A_Space_Adventure:ice02, A_Space_Adventure:moon02
      ["Your rank: %s"] = "Ваш ранк: %s", -- User_Mission_-_RCPlane_Challenge
--      ["Your rope is gone! Try again!"] = "", -- Basic_Training_-_Rope
--      ["You saved %d of 8 hegehogs."] = "", -- User_Mission_-_That_Sinking_Feeling
--      ["You see, hedgehog spikes are very, very valuable."] = "", -- A_Classic_Fairytale:queen
--      ["You see the wind strength at the bottom right corner."] = "", -- Basic_Training_-_Bazooka
--      ["You see the wind strength at the top."] = "", -- Basic_Training_-_Bazooka
--      ["You should have known that we don't rely on meatbags!"] = "", -- A_Classic_Fairytale:queen
--      ["You should know this more than anyone, Leaks!"] = "", -- A_Classic_Fairytale:queen
--      ["You speak great truth, Hannibal. Here, take a sip!"] = "", -- A_Classic_Fairytale:epil
--      ["You've been assaulting us, we have been just defending ourselves!"] = "", -- A_Classic_Fairytale:enemy
      ["You've reached the goal!| |Time: "] = "Вы достигли цели!| |Время: ",
--      ["You will be avenged!"] = "", -- A_Classic_Fairytale:shadow
--      ["You will fail if you run out of ammo and there are still targets available."] = "", -- A_Space_Adventure:desert03
--      ["You will gain some extra ammo from the crates the next time you play the \"Getting to the device\" mission."] = "", -- A_Space_Adventure:fruit03
--      ["You will play every 3 turns."] = "", -- A_Space_Adventure:fruit01
--      ["- You will recieve 2-4 weapons on each kill! (Even on own hogs)"] = "", -- Continental_supplies
--      ["You won't believe what happened to me!"] = "", -- A_Classic_Fairytale:backstab
--      ["Yuck! I bet they'll keep worshipping her even after I save the village!"] = "", -- A_Classic_Fairytale:family
--      ["Yumme Gunpowder"] = "", -- 
--      ["Zealandia"] = "", -- Continental_supplies
--      ["Zombie"] = "", -- 
--      ["Zombi"] = "", -- portal
      ["'Zooka Team"] = "Команда Зука",
--      ["Zoom: [Pinch] with 2 fingers"] = "", -- Basic_Training_-_Movement
--      ["Zoom: [Rotate mouse wheel]"] = "", -- Basic_Training_-_Movement
--      ["Zork"] = "", -- A_Classic_Fairytale:dragon, A_Classic_Fairytale:family, A_Classic_Fairytale:queen
}
